const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-05-18";
pub const sdk_id: []const u8 = "Athena";
pub const arn_namespace: []const u8 = "athena";
pub const endpoint_prefix: []const u8 = "athena";
pub const sigv4_name: []const u8 = "athena";
pub const name: []const u8 = "AmazonAthena";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-05-18",
    sdk_id: []const u8 = "Athena",
    arn_namespace: []const u8 = "athena",
    endpoint_prefix: []const u8 = "athena",
    sigv4_name: []const u8 = "athena",
    name: []const u8 = "AmazonAthena",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const batch_get_named_query: struct {
    action_name: []const u8 = "BatchGetNamedQuery",
    Request: type = struct {
        named_query_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .named_query_ids = "NamedQueryIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_named_query) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_named_query };
        }
    },
    Response: type = struct {
        named_queries: ?[]NamedQuery = null,
        unprocessed_named_query_ids: ?[]struct {
            named_query_id: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .named_query_id = "NamedQueryId",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .named_queries = "NamedQueries",
                .unprocessed_named_query_ids = "UnprocessedNamedQueryIds",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const batch_get_query_execution: struct {
    action_name: []const u8 = "BatchGetQueryExecution",
    Request: type = struct {
        query_execution_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_execution_ids = "QueryExecutionIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_query_execution) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_query_execution };
        }
    },
    Response: type = struct {
        query_executions: ?[]QueryExecution = null,
        unprocessed_query_execution_ids: ?[]struct {
            query_execution_id: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .query_execution_id = "QueryExecutionId",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_executions = "QueryExecutions",
                .unprocessed_query_execution_ids = "UnprocessedQueryExecutionIds",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const create_data_catalog: struct {
    action_name: []const u8 = "CreateDataCatalog",
    Request: type = struct {
        name: []const u8,
        type: []const u8,
        description: ?[]const u8 = null,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .type = "Type",
                .description = "Description",
                .parameters = "Parameters",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_data_catalog) } {
            return .{ .service_metadata = service_metadata, .action = create_data_catalog };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const create_named_query: struct {
    action_name: []const u8 = "CreateNamedQuery",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        database: []const u8,
        query_string: []const u8,
        client_request_token: ?[]const u8 = null,
        work_group: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .database = "Database",
                .query_string = "QueryString",
                .client_request_token = "ClientRequestToken",
                .work_group = "WorkGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_named_query) } {
            return .{ .service_metadata = service_metadata, .action = create_named_query };
        }
    },
    Response: type = struct {
        named_query_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .named_query_id = "NamedQueryId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const create_prepared_statement: struct {
    action_name: []const u8 = "CreatePreparedStatement",
    Request: type = struct {
        statement_name: []const u8,
        work_group: []const u8,
        query_statement: []const u8,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .statement_name = "StatementName",
                .work_group = "WorkGroup",
                .query_statement = "QueryStatement",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_prepared_statement) } {
            return .{ .service_metadata = service_metadata, .action = create_prepared_statement };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const create_work_group: struct {
    action_name: []const u8 = "CreateWorkGroup",
    Request: type = struct {
        name: []const u8,
        configuration: ?WorkGroupConfiguration = null,
        description: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .configuration = "Configuration",
                .description = "Description",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_work_group) } {
            return .{ .service_metadata = service_metadata, .action = create_work_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const delete_data_catalog: struct {
    action_name: []const u8 = "DeleteDataCatalog",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_data_catalog) } {
            return .{ .service_metadata = service_metadata, .action = delete_data_catalog };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const delete_named_query: struct {
    action_name: []const u8 = "DeleteNamedQuery",
    Request: type = struct {
        named_query_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .named_query_id = "NamedQueryId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_named_query) } {
            return .{ .service_metadata = service_metadata, .action = delete_named_query };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const delete_prepared_statement: struct {
    action_name: []const u8 = "DeletePreparedStatement",
    Request: type = struct {
        statement_name: []const u8,
        work_group: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .statement_name = "StatementName",
                .work_group = "WorkGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_prepared_statement) } {
            return .{ .service_metadata = service_metadata, .action = delete_prepared_statement };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const delete_work_group: struct {
    action_name: []const u8 = "DeleteWorkGroup",
    Request: type = struct {
        work_group: []const u8,
        recursive_delete_option: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .work_group = "WorkGroup",
                .recursive_delete_option = "RecursiveDeleteOption",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_work_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_work_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const get_database: struct {
    action_name: []const u8 = "GetDatabase",
    Request: type = struct {
        catalog_name: []const u8,
        database_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_name = "CatalogName",
                .database_name = "DatabaseName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_database) } {
            return .{ .service_metadata = service_metadata, .action = get_database };
        }
    },
    Response: type = struct {
        database: ?Database = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .database = "Database",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        Metadata,
    },
} = .{};
pub const get_data_catalog: struct {
    action_name: []const u8 = "GetDataCatalog",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_data_catalog) } {
            return .{ .service_metadata = service_metadata, .action = get_data_catalog };
        }
    },
    Response: type = struct {
        data_catalog: ?struct {
            name: []const u8,
            description: ?[]const u8 = null,
            type: []const u8,
            parameters: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .description = "Description",
                    .type = "Type",
                    .parameters = "Parameters",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "parameters", field_name))
                    return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_catalog = "DataCatalog",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const get_named_query: struct {
    action_name: []const u8 = "GetNamedQuery",
    Request: type = struct {
        named_query_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .named_query_id = "NamedQueryId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_named_query) } {
            return .{ .service_metadata = service_metadata, .action = get_named_query };
        }
    },
    Response: type = struct {
        named_query: ?NamedQuery = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .named_query = "NamedQuery",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const get_prepared_statement: struct {
    action_name: []const u8 = "GetPreparedStatement",
    Request: type = struct {
        statement_name: []const u8,
        work_group: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .statement_name = "StatementName",
                .work_group = "WorkGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_prepared_statement) } {
            return .{ .service_metadata = service_metadata, .action = get_prepared_statement };
        }
    },
    Response: type = struct {
        prepared_statement: ?struct {
            statement_name: ?[]const u8 = null,
            query_statement: ?[]const u8 = null,
            work_group_name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            last_modified_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .statement_name = "StatementName",
                    .query_statement = "QueryStatement",
                    .work_group_name = "WorkGroupName",
                    .description = "Description",
                    .last_modified_time = "LastModifiedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .prepared_statement = "PreparedStatement",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const get_query_execution: struct {
    action_name: []const u8 = "GetQueryExecution",
    Request: type = struct {
        query_execution_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_execution_id = "QueryExecutionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_query_execution) } {
            return .{ .service_metadata = service_metadata, .action = get_query_execution };
        }
    },
    Response: type = struct {
        query_execution: ?QueryExecution = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_execution = "QueryExecution",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const get_query_results: struct {
    action_name: []const u8 = "GetQueryResults",
    Request: type = struct {
        query_execution_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_execution_id = "QueryExecutionId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_query_results) } {
            return .{ .service_metadata = service_metadata, .action = get_query_results };
        }
    },
    Response: type = struct {
        update_count: ?i64 = null,
        result_set: ?struct {
            rows: ?[]struct {
                data: ?[]struct {
                    var_char_value: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .var_char_value = "VarCharValue",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .data = "Data",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            result_set_metadata: ?struct {
                column_info: ?[]struct {
                    catalog_name: ?[]const u8 = null,
                    schema_name: ?[]const u8 = null,
                    table_name: ?[]const u8 = null,
                    name: []const u8,
                    label: ?[]const u8 = null,
                    type: []const u8,
                    precision: ?i64 = null,
                    scale: ?i64 = null,
                    nullable: ?[]const u8 = null,
                    case_sensitive: ?bool = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .catalog_name = "CatalogName",
                            .schema_name = "SchemaName",
                            .table_name = "TableName",
                            .name = "Name",
                            .label = "Label",
                            .type = "Type",
                            .precision = "Precision",
                            .scale = "Scale",
                            .nullable = "Nullable",
                            .case_sensitive = "CaseSensitive",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .column_info = "ColumnInfo",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .rows = "Rows",
                    .result_set_metadata = "ResultSetMetadata",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_count = "UpdateCount",
                .result_set = "ResultSet",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const get_table_metadata: struct {
    action_name: []const u8 = "GetTableMetadata",
    Request: type = struct {
        catalog_name: []const u8,
        database_name: []const u8,
        table_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_name = "CatalogName",
                .database_name = "DatabaseName",
                .table_name = "TableName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_table_metadata) } {
            return .{ .service_metadata = service_metadata, .action = get_table_metadata };
        }
    },
    Response: type = struct {
        table_metadata: ?TableMetadata = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_metadata = "TableMetadata",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        Metadata,
    },
} = .{};
pub const get_work_group: struct {
    action_name: []const u8 = "GetWorkGroup",
    Request: type = struct {
        work_group: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .work_group = "WorkGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_work_group) } {
            return .{ .service_metadata = service_metadata, .action = get_work_group };
        }
    },
    Response: type = struct {
        work_group: ?struct {
            name: []const u8,
            state: ?[]const u8 = null,
            configuration: ?WorkGroupConfiguration = null,
            description: ?[]const u8 = null,
            creation_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .state = "State",
                    .configuration = "Configuration",
                    .description = "Description",
                    .creation_time = "CreationTime",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .work_group = "WorkGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const list_databases: struct {
    action_name: []const u8 = "ListDatabases",
    Request: type = struct {
        catalog_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_name = "CatalogName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_databases) } {
            return .{ .service_metadata = service_metadata, .action = list_databases };
        }
    },
    Response: type = struct {
        database_list: ?[]Database = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .database_list = "DatabaseList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        Metadata,
    },
} = .{};
pub const list_data_catalogs: struct {
    action_name: []const u8 = "ListDataCatalogs",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_data_catalogs) } {
            return .{ .service_metadata = service_metadata, .action = list_data_catalogs };
        }
    },
    Response: type = struct {
        data_catalogs_summary: ?[]struct {
            catalog_name: ?[]const u8 = null,
            type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .catalog_name = "CatalogName",
                    .type = "Type",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_catalogs_summary = "DataCatalogsSummary",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const list_engine_versions: struct {
    action_name: []const u8 = "ListEngineVersions",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_engine_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_engine_versions };
        }
    },
    Response: type = struct {
        engine_versions: ?[]EngineVersion = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .engine_versions = "EngineVersions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const list_named_queries: struct {
    action_name: []const u8 = "ListNamedQueries",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        work_group: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .work_group = "WorkGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_named_queries) } {
            return .{ .service_metadata = service_metadata, .action = list_named_queries };
        }
    },
    Response: type = struct {
        named_query_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .named_query_ids = "NamedQueryIds",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const list_prepared_statements: struct {
    action_name: []const u8 = "ListPreparedStatements",
    Request: type = struct {
        work_group: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .work_group = "WorkGroup",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_prepared_statements) } {
            return .{ .service_metadata = service_metadata, .action = list_prepared_statements };
        }
    },
    Response: type = struct {
        prepared_statements: ?[]struct {
            statement_name: ?[]const u8 = null,
            last_modified_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .statement_name = "StatementName",
                    .last_modified_time = "LastModifiedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .prepared_statements = "PreparedStatements",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const list_query_executions: struct {
    action_name: []const u8 = "ListQueryExecutions",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        work_group: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .work_group = "WorkGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_query_executions) } {
            return .{ .service_metadata = service_metadata, .action = list_query_executions };
        }
    },
    Response: type = struct {
        query_execution_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_execution_ids = "QueryExecutionIds",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const list_table_metadata: struct {
    action_name: []const u8 = "ListTableMetadata",
    Request: type = struct {
        catalog_name: []const u8,
        database_name: []const u8,
        expression: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_name = "CatalogName",
                .database_name = "DatabaseName",
                .expression = "Expression",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_table_metadata) } {
            return .{ .service_metadata = service_metadata, .action = list_table_metadata };
        }
    },
    Response: type = struct {
        table_metadata_list: ?[]TableMetadata = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_metadata_list = "TableMetadataList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        Metadata,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const list_work_groups: struct {
    action_name: []const u8 = "ListWorkGroups",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_work_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_work_groups };
        }
    },
    Response: type = struct {
        work_groups: ?[]struct {
            name: ?[]const u8 = null,
            state: ?[]const u8 = null,
            description: ?[]const u8 = null,
            creation_time: ?i64 = null,
            engine_version: ?EngineVersion = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .state = "State",
                    .description = "Description",
                    .creation_time = "CreationTime",
                    .engine_version = "EngineVersion",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .work_groups = "WorkGroups",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const start_query_execution: struct {
    action_name: []const u8 = "StartQueryExecution",
    Request: type = struct {
        query_string: []const u8,
        client_request_token: ?[]const u8 = null,
        query_execution_context: ?QueryExecutionContext = null,
        result_configuration: ?ResultConfiguration = null,
        work_group: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_string = "QueryString",
                .client_request_token = "ClientRequestToken",
                .query_execution_context = "QueryExecutionContext",
                .result_configuration = "ResultConfiguration",
                .work_group = "WorkGroup",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_query_execution) } {
            return .{ .service_metadata = service_metadata, .action = start_query_execution };
        }
    },
    Response: type = struct {
        query_execution_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_execution_id = "QueryExecutionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        TooManyRequests,
    },
} = .{};
pub const stop_query_execution: struct {
    action_name: []const u8 = "StopQueryExecution",
    Request: type = struct {
        query_execution_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .query_execution_id = "QueryExecutionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_query_execution) } {
            return .{ .service_metadata = service_metadata, .action = stop_query_execution };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const update_data_catalog: struct {
    action_name: []const u8 = "UpdateDataCatalog",
    Request: type = struct {
        name: []const u8,
        type: []const u8,
        description: ?[]const u8 = null,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .type = "Type",
                .description = "Description",
                .parameters = "Parameters",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_data_catalog) } {
            return .{ .service_metadata = service_metadata, .action = update_data_catalog };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};
pub const update_prepared_statement: struct {
    action_name: []const u8 = "UpdatePreparedStatement",
    Request: type = struct {
        statement_name: []const u8,
        work_group: []const u8,
        query_statement: []const u8,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .statement_name = "StatementName",
                .work_group = "WorkGroup",
                .query_statement = "QueryStatement",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_prepared_statement) } {
            return .{ .service_metadata = service_metadata, .action = update_prepared_statement };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const update_work_group: struct {
    action_name: []const u8 = "UpdateWorkGroup",
    Request: type = struct {
        work_group: []const u8,
        description: ?[]const u8 = null,
        configuration_updates: ?struct {
            enforce_work_group_configuration: ?bool = null,
            result_configuration_updates: ?struct {
                output_location: ?[]const u8 = null,
                remove_output_location: ?bool = null,
                encryption_configuration: ?EncryptionConfiguration = null,
                remove_encryption_configuration: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .output_location = "OutputLocation",
                        .remove_output_location = "RemoveOutputLocation",
                        .encryption_configuration = "EncryptionConfiguration",
                        .remove_encryption_configuration = "RemoveEncryptionConfiguration",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            publish_cloud_watch_metrics_enabled: ?bool = null,
            bytes_scanned_cutoff_per_query: ?i64 = null,
            remove_bytes_scanned_cutoff_per_query: ?bool = null,
            requester_pays_enabled: ?bool = null,
            engine_version: ?EngineVersion = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .enforce_work_group_configuration = "EnforceWorkGroupConfiguration",
                    .result_configuration_updates = "ResultConfigurationUpdates",
                    .publish_cloud_watch_metrics_enabled = "PublishCloudWatchMetricsEnabled",
                    .bytes_scanned_cutoff_per_query = "BytesScannedCutoffPerQuery",
                    .remove_bytes_scanned_cutoff_per_query = "RemoveBytesScannedCutoffPerQuery",
                    .requester_pays_enabled = "RequesterPaysEnabled",
                    .engine_version = "EngineVersion",
                };
                return @field(mappings, field_name);
            }
        } = null,
        state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .work_group = "WorkGroup",
                .description = "Description",
                .configuration_updates = "ConfigurationUpdates",
                .state = "State",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_work_group) } {
            return .{ .service_metadata = service_metadata, .action = update_work_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
    },
} = .{};

pub const EngineVersion = struct {
    selected_engine_version: ?[]const u8 = null,
    effective_engine_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .selected_engine_version = "SelectedEngineVersion",
            .effective_engine_version = "EffectiveEngineVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionConfiguration = struct {
    encryption_option: []const u8,
    kms_key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encryption_option = "EncryptionOption",
            .kms_key = "KmsKey",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const ResultConfiguration = struct {
    output_location: ?[]const u8 = null,
    encryption_configuration: ?EncryptionConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .output_location = "OutputLocation",
            .encryption_configuration = "EncryptionConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const QueryExecutionContext = struct {
    database: ?[]const u8 = null,
    catalog: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .database = "Database",
            .catalog = "Catalog",
        };
        return @field(mappings, field_name);
    }
};

pub const TableMetadata = struct {
    name: []const u8,
    create_time: ?i64 = null,
    last_access_time: ?i64 = null,
    table_type: ?[]const u8 = null,
    columns: ?[]Column = null,
    partition_keys: ?[]Column = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .create_time = "CreateTime",
            .last_access_time = "LastAccessTime",
            .table_type = "TableType",
            .columns = "Columns",
            .partition_keys = "PartitionKeys",
            .parameters = "Parameters",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};

pub const Column = struct {
    name: []const u8,
    type: ?[]const u8 = null,
    comment: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .type = "Type",
            .comment = "Comment",
        };
        return @field(mappings, field_name);
    }
};

pub const Database = struct {
    name: []const u8,
    description: ?[]const u8 = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
            .parameters = "Parameters",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};

pub const WorkGroupConfiguration = struct {
    result_configuration: ?ResultConfiguration = null,
    enforce_work_group_configuration: ?bool = null,
    publish_cloud_watch_metrics_enabled: ?bool = null,
    bytes_scanned_cutoff_per_query: ?i64 = null,
    requester_pays_enabled: ?bool = null,
    engine_version: ?EngineVersion = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .result_configuration = "ResultConfiguration",
            .enforce_work_group_configuration = "EnforceWorkGroupConfiguration",
            .publish_cloud_watch_metrics_enabled = "PublishCloudWatchMetricsEnabled",
            .bytes_scanned_cutoff_per_query = "BytesScannedCutoffPerQuery",
            .requester_pays_enabled = "RequesterPaysEnabled",
            .engine_version = "EngineVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const QueryExecution = struct {
    query_execution_id: ?[]const u8 = null,
    query: ?[]const u8 = null,
    statement_type: ?[]const u8 = null,
    result_configuration: ?ResultConfiguration = null,
    query_execution_context: ?QueryExecutionContext = null,
    status: ?QueryExecutionStatus = null,
    statistics: ?QueryExecutionStatistics = null,
    work_group: ?[]const u8 = null,
    engine_version: ?EngineVersion = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .query_execution_id = "QueryExecutionId",
            .query = "Query",
            .statement_type = "StatementType",
            .result_configuration = "ResultConfiguration",
            .query_execution_context = "QueryExecutionContext",
            .status = "Status",
            .statistics = "Statistics",
            .work_group = "WorkGroup",
            .engine_version = "EngineVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const QueryExecutionStatistics = struct {
    engine_execution_time_in_millis: ?i64 = null,
    data_scanned_in_bytes: ?i64 = null,
    data_manifest_location: ?[]const u8 = null,
    total_execution_time_in_millis: ?i64 = null,
    query_queue_time_in_millis: ?i64 = null,
    query_planning_time_in_millis: ?i64 = null,
    service_processing_time_in_millis: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .engine_execution_time_in_millis = "EngineExecutionTimeInMillis",
            .data_scanned_in_bytes = "DataScannedInBytes",
            .data_manifest_location = "DataManifestLocation",
            .total_execution_time_in_millis = "TotalExecutionTimeInMillis",
            .query_queue_time_in_millis = "QueryQueueTimeInMillis",
            .query_planning_time_in_millis = "QueryPlanningTimeInMillis",
            .service_processing_time_in_millis = "ServiceProcessingTimeInMillis",
        };
        return @field(mappings, field_name);
    }
};

pub const QueryExecutionStatus = struct {
    state: ?[]const u8 = null,
    state_change_reason: ?[]const u8 = null,
    submission_date_time: ?i64 = null,
    completion_date_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "State",
            .state_change_reason = "StateChangeReason",
            .submission_date_time = "SubmissionDateTime",
            .completion_date_time = "CompletionDateTime",
        };
        return @field(mappings, field_name);
    }
};

pub const NamedQuery = struct {
    name: []const u8,
    description: ?[]const u8 = null,
    database: []const u8,
    query_string: []const u8,
    named_query_id: ?[]const u8 = null,
    work_group: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
            .database = "Database",
            .query_string = "QueryString",
            .named_query_id = "NamedQueryId",
            .work_group = "WorkGroup",
        };
        return @field(mappings, field_name);
    }
};
