const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2019-11-01";
pub const sdk_id: []const u8 = "Compute Optimizer";
pub const arn_namespace: []const u8 = "compute-optimizer";
pub const endpoint_prefix: []const u8 = "compute-optimizer";
pub const sigv4_name: []const u8 = "compute-optimizer";
pub const name: []const u8 = "ComputeOptimizerService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0;

pub const service_metadata: struct {
    version: []const u8 = "2019-11-01",
    sdk_id: []const u8 = "Compute Optimizer",
    arn_namespace: []const u8 = "compute-optimizer",
    endpoint_prefix: []const u8 = "compute-optimizer",
    sigv4_name: []const u8 = "compute-optimizer",
    name: []const u8 = "ComputeOptimizerService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0,
} = .{};
pub const describe_recommendation_export_jobs: struct {
    action_name: []const u8 = "DescribeRecommendationExportJobs",
    Request: type = struct {
        job_ids: ?[][]const u8 = null,
        filters: ?[]struct {
            name: ?[]const u8 = null,
            values: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .values = "values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_ids = "jobIds",
                .filters = "filters",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_recommendation_export_jobs) } {
            return .{ .service_metadata = service_metadata, .action = describe_recommendation_export_jobs };
        }
    },
    Response: type = struct {
        recommendation_export_jobs: ?[]struct {
            job_id: ?[]const u8 = null,
            destination: ?struct {
                s3: ?S3Destination = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .s3 = "s3",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            resource_type: ?[]const u8 = null,
            status: ?[]const u8 = null,
            creation_timestamp: ?i64 = null,
            last_updated_timestamp: ?i64 = null,
            failure_reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_id = "jobId",
                    .destination = "destination",
                    .resource_type = "resourceType",
                    .status = "status",
                    .creation_timestamp = "creationTimestamp",
                    .last_updated_timestamp = "lastUpdatedTimestamp",
                    .failure_reason = "failureReason",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommendation_export_jobs = "recommendationExportJobs",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        MissingAuthenticationToken,
        OptInRequired,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const export_auto_scaling_group_recommendations: struct {
    action_name: []const u8 = "ExportAutoScalingGroupRecommendations",
    Request: type = struct {
        account_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        fields_to_export: ?[][]const u8 = null,
        s3_destination_config: S3DestinationConfig,
        file_format: ?[]const u8 = null,
        include_member_accounts: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "accountIds",
                .filters = "filters",
                .fields_to_export = "fieldsToExport",
                .s3_destination_config = "s3DestinationConfig",
                .file_format = "fileFormat",
                .include_member_accounts = "includeMemberAccounts",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(export_auto_scaling_group_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = export_auto_scaling_group_recommendations };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,
        s3_destination: ?S3Destination = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .s3_destination = "s3Destination",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        LimitExceeded,
        MissingAuthenticationToken,
        OptInRequired,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const export_ebs_volume_recommendations: struct {
    action_name: []const u8 = "ExportEBSVolumeRecommendations",
    Request: type = struct {
        account_ids: ?[][]const u8 = null,
        filters: ?[]EBSFilter = null,
        fields_to_export: ?[][]const u8 = null,
        s3_destination_config: S3DestinationConfig,
        file_format: ?[]const u8 = null,
        include_member_accounts: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "accountIds",
                .filters = "filters",
                .fields_to_export = "fieldsToExport",
                .s3_destination_config = "s3DestinationConfig",
                .file_format = "fileFormat",
                .include_member_accounts = "includeMemberAccounts",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(export_ebs_volume_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = export_ebs_volume_recommendations };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,
        s3_destination: ?S3Destination = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .s3_destination = "s3Destination",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        LimitExceeded,
        MissingAuthenticationToken,
        OptInRequired,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const export_ec2_instance_recommendations: struct {
    action_name: []const u8 = "ExportEC2InstanceRecommendations",
    Request: type = struct {
        account_ids: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        fields_to_export: ?[][]const u8 = null,
        s3_destination_config: S3DestinationConfig,
        file_format: ?[]const u8 = null,
        include_member_accounts: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "accountIds",
                .filters = "filters",
                .fields_to_export = "fieldsToExport",
                .s3_destination_config = "s3DestinationConfig",
                .file_format = "fileFormat",
                .include_member_accounts = "includeMemberAccounts",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(export_ec2_instance_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = export_ec2_instance_recommendations };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,
        s3_destination: ?S3Destination = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .s3_destination = "s3Destination",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        LimitExceeded,
        MissingAuthenticationToken,
        OptInRequired,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const export_lambda_function_recommendations: struct {
    action_name: []const u8 = "ExportLambdaFunctionRecommendations",
    Request: type = struct {
        account_ids: ?[][]const u8 = null,
        filters: ?[]LambdaFunctionRecommendationFilter = null,
        fields_to_export: ?[][]const u8 = null,
        s3_destination_config: S3DestinationConfig,
        file_format: ?[]const u8 = null,
        include_member_accounts: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "accountIds",
                .filters = "filters",
                .fields_to_export = "fieldsToExport",
                .s3_destination_config = "s3DestinationConfig",
                .file_format = "fileFormat",
                .include_member_accounts = "includeMemberAccounts",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(export_lambda_function_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = export_lambda_function_recommendations };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,
        s3_destination: ?S3Destination = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .s3_destination = "s3Destination",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        LimitExceeded,
        MissingAuthenticationToken,
        OptInRequired,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const get_auto_scaling_group_recommendations: struct {
    action_name: []const u8 = "GetAutoScalingGroupRecommendations",
    Request: type = struct {
        account_ids: ?[][]const u8 = null,
        auto_scaling_group_arns: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "accountIds",
                .auto_scaling_group_arns = "autoScalingGroupArns",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .filters = "filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_auto_scaling_group_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = get_auto_scaling_group_recommendations };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        auto_scaling_group_recommendations: ?[]struct {
            account_id: ?[]const u8 = null,
            auto_scaling_group_arn: ?[]const u8 = null,
            auto_scaling_group_name: ?[]const u8 = null,
            finding: ?[]const u8 = null,
            utilization_metrics: ?[]UtilizationMetric = null,
            look_back_period_in_days: ?f64 = null,
            current_configuration: ?AutoScalingGroupConfiguration = null,
            recommendation_options: ?[]struct {
                configuration: ?AutoScalingGroupConfiguration = null,
                projected_utilization_metrics: ?[]UtilizationMetric = null,
                performance_risk: ?f64 = null,
                rank: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .configuration = "configuration",
                        .projected_utilization_metrics = "projectedUtilizationMetrics",
                        .performance_risk = "performanceRisk",
                        .rank = "rank",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            last_refresh_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "accountId",
                    .auto_scaling_group_arn = "autoScalingGroupArn",
                    .auto_scaling_group_name = "autoScalingGroupName",
                    .finding = "finding",
                    .utilization_metrics = "utilizationMetrics",
                    .look_back_period_in_days = "lookBackPeriodInDays",
                    .current_configuration = "currentConfiguration",
                    .recommendation_options = "recommendationOptions",
                    .last_refresh_timestamp = "lastRefreshTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        errors: ?[]GetRecommendationError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .auto_scaling_group_recommendations = "autoScalingGroupRecommendations",
                .errors = "errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        MissingAuthenticationToken,
        OptInRequired,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const get_ebs_volume_recommendations: struct {
    action_name: []const u8 = "GetEBSVolumeRecommendations",
    Request: type = struct {
        volume_arns: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]EBSFilter = null,
        account_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .volume_arns = "volumeArns",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .filters = "filters",
                .account_ids = "accountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ebs_volume_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = get_ebs_volume_recommendations };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        volume_recommendations: ?[]struct {
            volume_arn: ?[]const u8 = null,
            account_id: ?[]const u8 = null,
            current_configuration: ?VolumeConfiguration = null,
            finding: ?[]const u8 = null,
            utilization_metrics: ?[]struct {
                name: ?[]const u8 = null,
                statistic: ?[]const u8 = null,
                value: ?f64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .statistic = "statistic",
                        .value = "value",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            look_back_period_in_days: ?f64 = null,
            volume_recommendation_options: ?[]struct {
                configuration: ?VolumeConfiguration = null,
                performance_risk: ?f64 = null,
                rank: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .configuration = "configuration",
                        .performance_risk = "performanceRisk",
                        .rank = "rank",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            last_refresh_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .volume_arn = "volumeArn",
                    .account_id = "accountId",
                    .current_configuration = "currentConfiguration",
                    .finding = "finding",
                    .utilization_metrics = "utilizationMetrics",
                    .look_back_period_in_days = "lookBackPeriodInDays",
                    .volume_recommendation_options = "volumeRecommendationOptions",
                    .last_refresh_timestamp = "lastRefreshTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        errors: ?[]GetRecommendationError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .volume_recommendations = "volumeRecommendations",
                .errors = "errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        MissingAuthenticationToken,
        OptInRequired,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const get_ec2_instance_recommendations: struct {
    action_name: []const u8 = "GetEC2InstanceRecommendations",
    Request: type = struct {
        instance_arns: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]Filter = null,
        account_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arns = "instanceArns",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .filters = "filters",
                .account_ids = "accountIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ec2_instance_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = get_ec2_instance_recommendations };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        instance_recommendations: ?[]struct {
            instance_arn: ?[]const u8 = null,
            account_id: ?[]const u8 = null,
            instance_name: ?[]const u8 = null,
            current_instance_type: ?[]const u8 = null,
            finding: ?[]const u8 = null,
            finding_reason_codes: ?[][]const u8 = null,
            utilization_metrics: ?[]UtilizationMetric = null,
            look_back_period_in_days: ?f64 = null,
            recommendation_options: ?[]struct {
                instance_type: ?[]const u8 = null,
                projected_utilization_metrics: ?[]UtilizationMetric = null,
                platform_differences: ?[][]const u8 = null,
                performance_risk: ?f64 = null,
                rank: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .instance_type = "instanceType",
                        .projected_utilization_metrics = "projectedUtilizationMetrics",
                        .platform_differences = "platformDifferences",
                        .performance_risk = "performanceRisk",
                        .rank = "rank",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            recommendation_sources: ?[]struct {
                recommendation_source_arn: ?[]const u8 = null,
                recommendation_source_type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .recommendation_source_arn = "recommendationSourceArn",
                        .recommendation_source_type = "recommendationSourceType",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            last_refresh_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .instance_arn = "instanceArn",
                    .account_id = "accountId",
                    .instance_name = "instanceName",
                    .current_instance_type = "currentInstanceType",
                    .finding = "finding",
                    .finding_reason_codes = "findingReasonCodes",
                    .utilization_metrics = "utilizationMetrics",
                    .look_back_period_in_days = "lookBackPeriodInDays",
                    .recommendation_options = "recommendationOptions",
                    .recommendation_sources = "recommendationSources",
                    .last_refresh_timestamp = "lastRefreshTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        errors: ?[]GetRecommendationError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .instance_recommendations = "instanceRecommendations",
                .errors = "errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        MissingAuthenticationToken,
        OptInRequired,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const get_ec2_recommendation_projected_metrics: struct {
    action_name: []const u8 = "GetEC2RecommendationProjectedMetrics",
    Request: type = struct {
        instance_arn: []const u8,
        stat: []const u8,
        period: i64,
        start_time: i64,
        end_time: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .instance_arn = "instanceArn",
                .stat = "stat",
                .period = "period",
                .start_time = "startTime",
                .end_time = "endTime",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ec2_recommendation_projected_metrics) } {
            return .{ .service_metadata = service_metadata, .action = get_ec2_recommendation_projected_metrics };
        }
    },
    Response: type = struct {
        recommended_option_projected_metrics: ?[]struct {
            recommended_instance_type: ?[]const u8 = null,
            rank: ?i64 = null,
            projected_metrics: ?[]struct {
                name: ?[]const u8 = null,
                timestamps: ?[]i64 = null,
                values: ?[]f64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .timestamps = "timestamps",
                        .values = "values",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .recommended_instance_type = "recommendedInstanceType",
                    .rank = "rank",
                    .projected_metrics = "projectedMetrics",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommended_option_projected_metrics = "recommendedOptionProjectedMetrics",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        MissingAuthenticationToken,
        OptInRequired,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const get_enrollment_status: struct {
    action_name: []const u8 = "GetEnrollmentStatus",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_enrollment_status) } {
            return .{ .service_metadata = service_metadata, .action = get_enrollment_status };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,
        status_reason: ?[]const u8 = null,
        member_accounts_enrolled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
                .status_reason = "statusReason",
                .member_accounts_enrolled = "memberAccountsEnrolled",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        MissingAuthenticationToken,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const get_lambda_function_recommendations: struct {
    action_name: []const u8 = "GetLambdaFunctionRecommendations",
    Request: type = struct {
        function_arns: ?[][]const u8 = null,
        account_ids: ?[][]const u8 = null,
        filters: ?[]LambdaFunctionRecommendationFilter = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_arns = "functionArns",
                .account_ids = "accountIds",
                .filters = "filters",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_lambda_function_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = get_lambda_function_recommendations };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        lambda_function_recommendations: ?[]struct {
            function_arn: ?[]const u8 = null,
            function_version: ?[]const u8 = null,
            account_id: ?[]const u8 = null,
            current_memory_size: ?i64 = null,
            number_of_invocations: ?i64 = null,
            utilization_metrics: ?[]struct {
                name: ?[]const u8 = null,
                statistic: ?[]const u8 = null,
                value: ?f64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .statistic = "statistic",
                        .value = "value",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            lookback_period_in_days: ?f64 = null,
            last_refresh_timestamp: ?i64 = null,
            finding: ?[]const u8 = null,
            finding_reason_codes: ?[][]const u8 = null,
            memory_size_recommendation_options: ?[]struct {
                rank: ?i64 = null,
                memory_size: ?i64 = null,
                projected_utilization_metrics: ?[]struct {
                    name: ?[]const u8 = null,
                    statistic: ?[]const u8 = null,
                    value: ?f64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "name",
                            .statistic = "statistic",
                            .value = "value",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .rank = "rank",
                        .memory_size = "memorySize",
                        .projected_utilization_metrics = "projectedUtilizationMetrics",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .function_arn = "functionArn",
                    .function_version = "functionVersion",
                    .account_id = "accountId",
                    .current_memory_size = "currentMemorySize",
                    .number_of_invocations = "numberOfInvocations",
                    .utilization_metrics = "utilizationMetrics",
                    .lookback_period_in_days = "lookbackPeriodInDays",
                    .last_refresh_timestamp = "lastRefreshTimestamp",
                    .finding = "finding",
                    .finding_reason_codes = "findingReasonCodes",
                    .memory_size_recommendation_options = "memorySizeRecommendationOptions",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .lambda_function_recommendations = "lambdaFunctionRecommendations",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        LimitExceeded,
        MissingAuthenticationToken,
        OptInRequired,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const get_recommendation_summaries: struct {
    action_name: []const u8 = "GetRecommendationSummaries",
    Request: type = struct {
        account_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_ids = "accountIds",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_recommendation_summaries) } {
            return .{ .service_metadata = service_metadata, .action = get_recommendation_summaries };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        recommendation_summaries: ?[]struct {
            summaries: ?[]struct {
                name: ?[]const u8 = null,
                value: ?f64 = null,
                reason_code_summaries: ?[]struct {
                    name: ?[]const u8 = null,
                    value: ?f64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "name",
                            .value = "value",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .value = "value",
                        .reason_code_summaries = "reasonCodeSummaries",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            recommendation_resource_type: ?[]const u8 = null,
            account_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .summaries = "summaries",
                    .recommendation_resource_type = "recommendationResourceType",
                    .account_id = "accountId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .recommendation_summaries = "recommendationSummaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        MissingAuthenticationToken,
        OptInRequired,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const update_enrollment_status: struct {
    action_name: []const u8 = "UpdateEnrollmentStatus",
    Request: type = struct {
        status: []const u8,
        include_member_accounts: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
                .include_member_accounts = "includeMemberAccounts",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_enrollment_status) } {
            return .{ .service_metadata = service_metadata, .action = update_enrollment_status };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,
        status_reason: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
                .status_reason = "statusReason",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        InvalidParameterValue,
        MissingAuthenticationToken,
        ServiceUnavailable,
        Throttling,
    },
} = .{};

pub const LambdaFunctionRecommendationFilter = struct {
    name: ?[]const u8 = null,
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .values = "values",
        };
        return @field(mappings, field_name);
    }
};

pub const GetRecommendationError = struct {
    identifier: ?[]const u8 = null,
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .identifier = "identifier",
            .code = "code",
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const UtilizationMetric = struct {
    name: ?[]const u8 = null,
    statistic: ?[]const u8 = null,
    value: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .statistic = "statistic",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const Filter = struct {
    name: ?[]const u8 = null,
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .values = "values",
        };
        return @field(mappings, field_name);
    }
};

pub const VolumeConfiguration = struct {
    volume_type: ?[]const u8 = null,
    volume_size: ?i64 = null,
    volume_baseline_iops: ?i64 = null,
    volume_burst_iops: ?i64 = null,
    volume_baseline_throughput: ?i64 = null,
    volume_burst_throughput: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .volume_type = "volumeType",
            .volume_size = "volumeSize",
            .volume_baseline_iops = "volumeBaselineIOPS",
            .volume_burst_iops = "volumeBurstIOPS",
            .volume_baseline_throughput = "volumeBaselineThroughput",
            .volume_burst_throughput = "volumeBurstThroughput",
        };
        return @field(mappings, field_name);
    }
};

pub const EBSFilter = struct {
    name: ?[]const u8 = null,
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .values = "values",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoScalingGroupConfiguration = struct {
    desired_capacity: ?i64 = null,
    min_size: ?i64 = null,
    max_size: ?i64 = null,
    instance_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .desired_capacity = "desiredCapacity",
            .min_size = "minSize",
            .max_size = "maxSize",
            .instance_type = "instanceType",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Destination = struct {
    bucket: ?[]const u8 = null,
    key: ?[]const u8 = null,
    metadata_key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "bucket",
            .key = "key",
            .metadata_key = "metadataKey",
        };
        return @field(mappings, field_name);
    }
};

pub const S3DestinationConfig = struct {
    bucket: ?[]const u8 = null,
    key_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "bucket",
            .key_prefix = "keyPrefix",
        };
        return @field(mappings, field_name);
    }
};
