const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-11-09";
pub const sdk_id: []const u8 = "DataSync";
pub const arn_namespace: []const u8 = "datasync";
pub const endpoint_prefix: []const u8 = "datasync";
pub const sigv4_name: []const u8 = "datasync";
pub const name: []const u8 = "FmrsService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-11-09",
    sdk_id: []const u8 = "DataSync",
    arn_namespace: []const u8 = "datasync",
    endpoint_prefix: []const u8 = "datasync",
    sigv4_name: []const u8 = "datasync",
    name: []const u8 = "FmrsService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const cancel_task_execution: struct {
    action_name: []const u8 = "CancelTaskExecution",
    Request: type = struct {
        task_execution_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_execution_arn = "TaskExecutionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_task_execution) } {
            return .{ .service_metadata = service_metadata, .action = cancel_task_execution };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const create_agent: struct {
    action_name: []const u8 = "CreateAgent",
    Request: type = struct {
        activation_key: []const u8,
        agent_name: ?[]const u8 = null,
        tags: ?[]TagListEntry = null,
        vpc_endpoint_id: ?[]const u8 = null,
        subnet_arns: ?[][]const u8 = null,
        security_group_arns: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .activation_key = "ActivationKey",
                .agent_name = "AgentName",
                .tags = "Tags",
                .vpc_endpoint_id = "VpcEndpointId",
                .subnet_arns = "SubnetArns",
                .security_group_arns = "SecurityGroupArns",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_agent) } {
            return .{ .service_metadata = service_metadata, .action = create_agent };
        }
    },
    Response: type = struct {
        agent_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .agent_arn = "AgentArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const create_location_efs: struct {
    action_name: []const u8 = "CreateLocationEfs",
    Request: type = struct {
        subdirectory: ?[]const u8 = null,
        efs_filesystem_arn: []const u8,
        ec2_config: Ec2Config,
        tags: ?[]TagListEntry = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subdirectory = "Subdirectory",
                .efs_filesystem_arn = "EfsFilesystemArn",
                .ec2_config = "Ec2Config",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_location_efs) } {
            return .{ .service_metadata = service_metadata, .action = create_location_efs };
        }
    },
    Response: type = struct {
        location_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const create_location_fsx_windows: struct {
    action_name: []const u8 = "CreateLocationFsxWindows",
    Request: type = struct {
        subdirectory: ?[]const u8 = null,
        fsx_filesystem_arn: []const u8,
        security_group_arns: [][]const u8,
        tags: ?[]TagListEntry = null,
        user: []const u8,
        domain: ?[]const u8 = null,
        password: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subdirectory = "Subdirectory",
                .fsx_filesystem_arn = "FsxFilesystemArn",
                .security_group_arns = "SecurityGroupArns",
                .tags = "Tags",
                .user = "User",
                .domain = "Domain",
                .password = "Password",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_location_fsx_windows) } {
            return .{ .service_metadata = service_metadata, .action = create_location_fsx_windows };
        }
    },
    Response: type = struct {
        location_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const create_location_nfs: struct {
    action_name: []const u8 = "CreateLocationNfs",
    Request: type = struct {
        subdirectory: []const u8,
        server_hostname: []const u8,
        on_prem_config: OnPremConfig,
        mount_options: ?NfsMountOptions = null,
        tags: ?[]TagListEntry = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subdirectory = "Subdirectory",
                .server_hostname = "ServerHostname",
                .on_prem_config = "OnPremConfig",
                .mount_options = "MountOptions",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_location_nfs) } {
            return .{ .service_metadata = service_metadata, .action = create_location_nfs };
        }
    },
    Response: type = struct {
        location_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const create_location_object_storage: struct {
    action_name: []const u8 = "CreateLocationObjectStorage",
    Request: type = struct {
        server_hostname: []const u8,
        server_port: ?i64 = null,
        server_protocol: ?[]const u8 = null,
        subdirectory: ?[]const u8 = null,
        bucket_name: []const u8,
        access_key: ?[]const u8 = null,
        secret_key: ?[]const u8 = null,
        agent_arns: [][]const u8,
        tags: ?[]TagListEntry = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_hostname = "ServerHostname",
                .server_port = "ServerPort",
                .server_protocol = "ServerProtocol",
                .subdirectory = "Subdirectory",
                .bucket_name = "BucketName",
                .access_key = "AccessKey",
                .secret_key = "SecretKey",
                .agent_arns = "AgentArns",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_location_object_storage) } {
            return .{ .service_metadata = service_metadata, .action = create_location_object_storage };
        }
    },
    Response: type = struct {
        location_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const create_location_s3: struct {
    action_name: []const u8 = "CreateLocationS3",
    Request: type = struct {
        subdirectory: ?[]const u8 = null,
        s3_bucket_arn: []const u8,
        s3_storage_class: ?[]const u8 = null,
        s3_config: S3Config,
        agent_arns: ?[][]const u8 = null,
        tags: ?[]TagListEntry = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subdirectory = "Subdirectory",
                .s3_bucket_arn = "S3BucketArn",
                .s3_storage_class = "S3StorageClass",
                .s3_config = "S3Config",
                .agent_arns = "AgentArns",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_location_s3) } {
            return .{ .service_metadata = service_metadata, .action = create_location_s3 };
        }
    },
    Response: type = struct {
        location_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const create_location_smb: struct {
    action_name: []const u8 = "CreateLocationSmb",
    Request: type = struct {
        subdirectory: []const u8,
        server_hostname: []const u8,
        user: []const u8,
        domain: ?[]const u8 = null,
        password: []const u8,
        agent_arns: [][]const u8,
        mount_options: ?SmbMountOptions = null,
        tags: ?[]TagListEntry = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subdirectory = "Subdirectory",
                .server_hostname = "ServerHostname",
                .user = "User",
                .domain = "Domain",
                .password = "Password",
                .agent_arns = "AgentArns",
                .mount_options = "MountOptions",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_location_smb) } {
            return .{ .service_metadata = service_metadata, .action = create_location_smb };
        }
    },
    Response: type = struct {
        location_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const create_task: struct {
    action_name: []const u8 = "CreateTask",
    Request: type = struct {
        source_location_arn: []const u8,
        destination_location_arn: []const u8,
        cloud_watch_log_group_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        options: ?Options = null,
        excludes: ?[]FilterRule = null,
        schedule: ?TaskSchedule = null,
        tags: ?[]TagListEntry = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_location_arn = "SourceLocationArn",
                .destination_location_arn = "DestinationLocationArn",
                .cloud_watch_log_group_arn = "CloudWatchLogGroupArn",
                .name = "Name",
                .options = "Options",
                .excludes = "Excludes",
                .schedule = "Schedule",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_task) } {
            return .{ .service_metadata = service_metadata, .action = create_task };
        }
    },
    Response: type = struct {
        task_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_arn = "TaskArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const delete_agent: struct {
    action_name: []const u8 = "DeleteAgent",
    Request: type = struct {
        agent_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .agent_arn = "AgentArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_agent) } {
            return .{ .service_metadata = service_metadata, .action = delete_agent };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const delete_location: struct {
    action_name: []const u8 = "DeleteLocation",
    Request: type = struct {
        location_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_location) } {
            return .{ .service_metadata = service_metadata, .action = delete_location };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const delete_task: struct {
    action_name: []const u8 = "DeleteTask",
    Request: type = struct {
        task_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_arn = "TaskArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_task) } {
            return .{ .service_metadata = service_metadata, .action = delete_task };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const describe_agent: struct {
    action_name: []const u8 = "DescribeAgent",
    Request: type = struct {
        agent_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .agent_arn = "AgentArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_agent) } {
            return .{ .service_metadata = service_metadata, .action = describe_agent };
        }
    },
    Response: type = struct {
        agent_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        status: ?[]const u8 = null,
        last_connection_time: ?i64 = null,
        creation_time: ?i64 = null,
        endpoint_type: ?[]const u8 = null,
        private_link_config: ?struct {
            vpc_endpoint_id: ?[]const u8 = null,
            private_link_endpoint: ?[]const u8 = null,
            subnet_arns: ?[][]const u8 = null,
            security_group_arns: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .vpc_endpoint_id = "VpcEndpointId",
                    .private_link_endpoint = "PrivateLinkEndpoint",
                    .subnet_arns = "SubnetArns",
                    .security_group_arns = "SecurityGroupArns",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .agent_arn = "AgentArn",
                .name = "Name",
                .status = "Status",
                .last_connection_time = "LastConnectionTime",
                .creation_time = "CreationTime",
                .endpoint_type = "EndpointType",
                .private_link_config = "PrivateLinkConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const describe_location_efs: struct {
    action_name: []const u8 = "DescribeLocationEfs",
    Request: type = struct {
        location_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_location_efs) } {
            return .{ .service_metadata = service_metadata, .action = describe_location_efs };
        }
    },
    Response: type = struct {
        location_arn: ?[]const u8 = null,
        location_uri: ?[]const u8 = null,
        ec2_config: ?Ec2Config = null,
        creation_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
                .location_uri = "LocationUri",
                .ec2_config = "Ec2Config",
                .creation_time = "CreationTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const describe_location_fsx_windows: struct {
    action_name: []const u8 = "DescribeLocationFsxWindows",
    Request: type = struct {
        location_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_location_fsx_windows) } {
            return .{ .service_metadata = service_metadata, .action = describe_location_fsx_windows };
        }
    },
    Response: type = struct {
        location_arn: ?[]const u8 = null,
        location_uri: ?[]const u8 = null,
        security_group_arns: ?[][]const u8 = null,
        creation_time: ?i64 = null,
        user: ?[]const u8 = null,
        domain: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
                .location_uri = "LocationUri",
                .security_group_arns = "SecurityGroupArns",
                .creation_time = "CreationTime",
                .user = "User",
                .domain = "Domain",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const describe_location_nfs: struct {
    action_name: []const u8 = "DescribeLocationNfs",
    Request: type = struct {
        location_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_location_nfs) } {
            return .{ .service_metadata = service_metadata, .action = describe_location_nfs };
        }
    },
    Response: type = struct {
        location_arn: ?[]const u8 = null,
        location_uri: ?[]const u8 = null,
        on_prem_config: ?OnPremConfig = null,
        mount_options: ?NfsMountOptions = null,
        creation_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
                .location_uri = "LocationUri",
                .on_prem_config = "OnPremConfig",
                .mount_options = "MountOptions",
                .creation_time = "CreationTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const describe_location_object_storage: struct {
    action_name: []const u8 = "DescribeLocationObjectStorage",
    Request: type = struct {
        location_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_location_object_storage) } {
            return .{ .service_metadata = service_metadata, .action = describe_location_object_storage };
        }
    },
    Response: type = struct {
        location_arn: ?[]const u8 = null,
        location_uri: ?[]const u8 = null,
        access_key: ?[]const u8 = null,
        server_port: ?i64 = null,
        server_protocol: ?[]const u8 = null,
        agent_arns: ?[][]const u8 = null,
        creation_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
                .location_uri = "LocationUri",
                .access_key = "AccessKey",
                .server_port = "ServerPort",
                .server_protocol = "ServerProtocol",
                .agent_arns = "AgentArns",
                .creation_time = "CreationTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const describe_location_s3: struct {
    action_name: []const u8 = "DescribeLocationS3",
    Request: type = struct {
        location_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_location_s3) } {
            return .{ .service_metadata = service_metadata, .action = describe_location_s3 };
        }
    },
    Response: type = struct {
        location_arn: ?[]const u8 = null,
        location_uri: ?[]const u8 = null,
        s3_storage_class: ?[]const u8 = null,
        s3_config: ?S3Config = null,
        agent_arns: ?[][]const u8 = null,
        creation_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
                .location_uri = "LocationUri",
                .s3_storage_class = "S3StorageClass",
                .s3_config = "S3Config",
                .agent_arns = "AgentArns",
                .creation_time = "CreationTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const describe_location_smb: struct {
    action_name: []const u8 = "DescribeLocationSmb",
    Request: type = struct {
        location_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_location_smb) } {
            return .{ .service_metadata = service_metadata, .action = describe_location_smb };
        }
    },
    Response: type = struct {
        location_arn: ?[]const u8 = null,
        location_uri: ?[]const u8 = null,
        agent_arns: ?[][]const u8 = null,
        user: ?[]const u8 = null,
        domain: ?[]const u8 = null,
        mount_options: ?SmbMountOptions = null,
        creation_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
                .location_uri = "LocationUri",
                .agent_arns = "AgentArns",
                .user = "User",
                .domain = "Domain",
                .mount_options = "MountOptions",
                .creation_time = "CreationTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const describe_task: struct {
    action_name: []const u8 = "DescribeTask",
    Request: type = struct {
        task_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_arn = "TaskArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_task) } {
            return .{ .service_metadata = service_metadata, .action = describe_task };
        }
    },
    Response: type = struct {
        task_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,
        name: ?[]const u8 = null,
        current_task_execution_arn: ?[]const u8 = null,
        source_location_arn: ?[]const u8 = null,
        destination_location_arn: ?[]const u8 = null,
        cloud_watch_log_group_arn: ?[]const u8 = null,
        source_network_interface_arns: ?[][]const u8 = null,
        destination_network_interface_arns: ?[][]const u8 = null,
        options: ?Options = null,
        excludes: ?[]FilterRule = null,
        schedule: ?TaskSchedule = null,
        error_code: ?[]const u8 = null,
        error_detail: ?[]const u8 = null,
        creation_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_arn = "TaskArn",
                .status = "Status",
                .name = "Name",
                .current_task_execution_arn = "CurrentTaskExecutionArn",
                .source_location_arn = "SourceLocationArn",
                .destination_location_arn = "DestinationLocationArn",
                .cloud_watch_log_group_arn = "CloudWatchLogGroupArn",
                .source_network_interface_arns = "SourceNetworkInterfaceArns",
                .destination_network_interface_arns = "DestinationNetworkInterfaceArns",
                .options = "Options",
                .excludes = "Excludes",
                .schedule = "Schedule",
                .error_code = "ErrorCode",
                .error_detail = "ErrorDetail",
                .creation_time = "CreationTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const describe_task_execution: struct {
    action_name: []const u8 = "DescribeTaskExecution",
    Request: type = struct {
        task_execution_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_execution_arn = "TaskExecutionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_task_execution) } {
            return .{ .service_metadata = service_metadata, .action = describe_task_execution };
        }
    },
    Response: type = struct {
        task_execution_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,
        options: ?Options = null,
        excludes: ?[]FilterRule = null,
        includes: ?[]FilterRule = null,
        start_time: ?i64 = null,
        estimated_files_to_transfer: ?i64 = null,
        estimated_bytes_to_transfer: ?i64 = null,
        files_transferred: ?i64 = null,
        bytes_written: ?i64 = null,
        bytes_transferred: ?i64 = null,
        result: ?struct {
            prepare_duration: ?i64 = null,
            prepare_status: ?[]const u8 = null,
            total_duration: ?i64 = null,
            transfer_duration: ?i64 = null,
            transfer_status: ?[]const u8 = null,
            verify_duration: ?i64 = null,
            verify_status: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_detail: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .prepare_duration = "PrepareDuration",
                    .prepare_status = "PrepareStatus",
                    .total_duration = "TotalDuration",
                    .transfer_duration = "TransferDuration",
                    .transfer_status = "TransferStatus",
                    .verify_duration = "VerifyDuration",
                    .verify_status = "VerifyStatus",
                    .error_code = "ErrorCode",
                    .error_detail = "ErrorDetail",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_execution_arn = "TaskExecutionArn",
                .status = "Status",
                .options = "Options",
                .excludes = "Excludes",
                .includes = "Includes",
                .start_time = "StartTime",
                .estimated_files_to_transfer = "EstimatedFilesToTransfer",
                .estimated_bytes_to_transfer = "EstimatedBytesToTransfer",
                .files_transferred = "FilesTransferred",
                .bytes_written = "BytesWritten",
                .bytes_transferred = "BytesTransferred",
                .result = "Result",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const list_agents: struct {
    action_name: []const u8 = "ListAgents",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_agents) } {
            return .{ .service_metadata = service_metadata, .action = list_agents };
        }
    },
    Response: type = struct {
        agents: ?[]struct {
            agent_arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .agent_arn = "AgentArn",
                    .name = "Name",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .agents = "Agents",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const list_locations: struct {
    action_name: []const u8 = "ListLocations",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,
            operator: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .values = "Values",
                    .operator = "Operator",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_locations) } {
            return .{ .service_metadata = service_metadata, .action = list_locations };
        }
    },
    Response: type = struct {
        locations: ?[]struct {
            location_arn: ?[]const u8 = null,
            location_uri: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .location_arn = "LocationArn",
                    .location_uri = "LocationUri",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .locations = "Locations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]TagListEntry = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const list_task_executions: struct {
    action_name: []const u8 = "ListTaskExecutions",
    Request: type = struct {
        task_arn: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_arn = "TaskArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_task_executions) } {
            return .{ .service_metadata = service_metadata, .action = list_task_executions };
        }
    },
    Response: type = struct {
        task_executions: ?[]struct {
            task_execution_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .task_execution_arn = "TaskExecutionArn",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_executions = "TaskExecutions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const list_tasks: struct {
    action_name: []const u8 = "ListTasks",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,
            operator: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .values = "Values",
                    .operator = "Operator",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tasks) } {
            return .{ .service_metadata = service_metadata, .action = list_tasks };
        }
    },
    Response: type = struct {
        tasks: ?[]struct {
            task_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .task_arn = "TaskArn",
                    .status = "Status",
                    .name = "Name",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tasks = "Tasks",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const start_task_execution: struct {
    action_name: []const u8 = "StartTaskExecution",
    Request: type = struct {
        task_arn: []const u8,
        override_options: ?Options = null,
        includes: ?[]FilterRule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_arn = "TaskArn",
                .override_options = "OverrideOptions",
                .includes = "Includes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_task_execution) } {
            return .{ .service_metadata = service_metadata, .action = start_task_execution };
        }
    },
    Response: type = struct {
        task_execution_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_execution_arn = "TaskExecutionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []TagListEntry,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .keys = "Keys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const update_agent: struct {
    action_name: []const u8 = "UpdateAgent",
    Request: type = struct {
        agent_arn: []const u8,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .agent_arn = "AgentArn",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_agent) } {
            return .{ .service_metadata = service_metadata, .action = update_agent };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const update_location_nfs: struct {
    action_name: []const u8 = "UpdateLocationNfs",
    Request: type = struct {
        location_arn: []const u8,
        subdirectory: ?[]const u8 = null,
        on_prem_config: ?OnPremConfig = null,
        mount_options: ?NfsMountOptions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
                .subdirectory = "Subdirectory",
                .on_prem_config = "OnPremConfig",
                .mount_options = "MountOptions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_location_nfs) } {
            return .{ .service_metadata = service_metadata, .action = update_location_nfs };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const update_location_object_storage: struct {
    action_name: []const u8 = "UpdateLocationObjectStorage",
    Request: type = struct {
        location_arn: []const u8,
        server_port: ?i64 = null,
        server_protocol: ?[]const u8 = null,
        subdirectory: ?[]const u8 = null,
        access_key: ?[]const u8 = null,
        secret_key: ?[]const u8 = null,
        agent_arns: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
                .server_port = "ServerPort",
                .server_protocol = "ServerProtocol",
                .subdirectory = "Subdirectory",
                .access_key = "AccessKey",
                .secret_key = "SecretKey",
                .agent_arns = "AgentArns",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_location_object_storage) } {
            return .{ .service_metadata = service_metadata, .action = update_location_object_storage };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const update_location_smb: struct {
    action_name: []const u8 = "UpdateLocationSmb",
    Request: type = struct {
        location_arn: []const u8,
        subdirectory: ?[]const u8 = null,
        user: ?[]const u8 = null,
        domain: ?[]const u8 = null,
        password: ?[]const u8 = null,
        agent_arns: ?[][]const u8 = null,
        mount_options: ?SmbMountOptions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location_arn = "LocationArn",
                .subdirectory = "Subdirectory",
                .user = "User",
                .domain = "Domain",
                .password = "Password",
                .agent_arns = "AgentArns",
                .mount_options = "MountOptions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_location_smb) } {
            return .{ .service_metadata = service_metadata, .action = update_location_smb };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const update_task: struct {
    action_name: []const u8 = "UpdateTask",
    Request: type = struct {
        task_arn: []const u8,
        options: ?Options = null,
        excludes: ?[]FilterRule = null,
        schedule: ?TaskSchedule = null,
        name: ?[]const u8 = null,
        cloud_watch_log_group_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_arn = "TaskArn",
                .options = "Options",
                .excludes = "Excludes",
                .schedule = "Schedule",
                .name = "Name",
                .cloud_watch_log_group_arn = "CloudWatchLogGroupArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_task) } {
            return .{ .service_metadata = service_metadata, .action = update_task };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};
pub const update_task_execution: struct {
    action_name: []const u8 = "UpdateTaskExecution",
    Request: type = struct {
        task_execution_arn: []const u8,
        options: Options,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_execution_arn = "TaskExecutionArn",
                .options = "Options",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_task_execution) } {
            return .{ .service_metadata = service_metadata, .action = update_task_execution };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidRequest,
    },
} = .{};

pub const Options = struct {
    verify_mode: ?[]const u8 = null,
    overwrite_mode: ?[]const u8 = null,
    atime: ?[]const u8 = null,
    mtime: ?[]const u8 = null,
    uid: ?[]const u8 = null,
    gid: ?[]const u8 = null,
    preserve_deleted_files: ?[]const u8 = null,
    preserve_devices: ?[]const u8 = null,
    posix_permissions: ?[]const u8 = null,
    bytes_per_second: ?i64 = null,
    task_queueing: ?[]const u8 = null,
    log_level: ?[]const u8 = null,
    transfer_mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .verify_mode = "VerifyMode",
            .overwrite_mode = "OverwriteMode",
            .atime = "Atime",
            .mtime = "Mtime",
            .uid = "Uid",
            .gid = "Gid",
            .preserve_deleted_files = "PreserveDeletedFiles",
            .preserve_devices = "PreserveDevices",
            .posix_permissions = "PosixPermissions",
            .bytes_per_second = "BytesPerSecond",
            .task_queueing = "TaskQueueing",
            .log_level = "LogLevel",
            .transfer_mode = "TransferMode",
        };
        return @field(mappings, field_name);
    }
};

pub const TaskSchedule = struct {
    schedule_expression: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .schedule_expression = "ScheduleExpression",
        };
        return @field(mappings, field_name);
    }
};

pub const FilterRule = struct {
    filter_type: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filter_type = "FilterType",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const SmbMountOptions = struct {
    version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .version = "Version",
        };
        return @field(mappings, field_name);
    }
};

pub const NfsMountOptions = struct {
    version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .version = "Version",
        };
        return @field(mappings, field_name);
    }
};

pub const OnPremConfig = struct {
    agent_arns: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .agent_arns = "AgentArns",
        };
        return @field(mappings, field_name);
    }
};

pub const TagListEntry = struct {
    key: []const u8,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Config = struct {
    bucket_access_role_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_access_role_arn = "BucketAccessRoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const Ec2Config = struct {
    subnet_arn: []const u8,
    security_group_arns: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_arn = "SubnetArn",
            .security_group_arns = "SecurityGroupArns",
        };
        return @field(mappings, field_name);
    }
};
