const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-12-01";
pub const sdk_id: []const u8 = "DevOps Guru";
pub const arn_namespace: []const u8 = "devops-guru";
pub const endpoint_prefix: []const u8 = "devops-guru";
pub const sigv4_name: []const u8 = "devops-guru";
pub const name: []const u8 = "CapstoneControlPlaneService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-12-01",
    sdk_id: []const u8 = "DevOps Guru",
    arn_namespace: []const u8 = "devops-guru",
    endpoint_prefix: []const u8 = "devops-guru",
    sigv4_name: []const u8 = "devops-guru",
    name: []const u8 = "CapstoneControlPlaneService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const add_notification_channel: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/channels",
        .success_code = 200,
    };

    action_name: []const u8 = "AddNotificationChannel",
    Request: type = struct {
        config: NotificationChannelConfig,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .config = "Config",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_notification_channel) } {
            return .{ .service_metadata = service_metadata, .action = add_notification_channel };
        }
    },
    Response: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_account_health: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/health",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAccountHealth",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_account_health) } {
            return .{ .service_metadata = service_metadata, .action = describe_account_health };
        }
    },
    Response: type = struct {
        open_reactive_insights: i64,
        open_proactive_insights: i64,
        metrics_analyzed: i64,
        resource_hours: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .open_reactive_insights = "OpenReactiveInsights",
                .open_proactive_insights = "OpenProactiveInsights",
                .metrics_analyzed = "MetricsAnalyzed",
                .resource_hours = "ResourceHours",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_account_overview: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/overview",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAccountOverview",
    Request: type = struct {
        from_time: i64,
        to_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .from_time = "FromTime",
                .to_time = "ToTime",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_account_overview) } {
            return .{ .service_metadata = service_metadata, .action = describe_account_overview };
        }
    },
    Response: type = struct {
        reactive_insights: i64,
        proactive_insights: i64,
        mean_time_to_recover_in_milliseconds: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reactive_insights = "ReactiveInsights",
                .proactive_insights = "ProactiveInsights",
                .mean_time_to_recover_in_milliseconds = "MeanTimeToRecoverInMilliseconds",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_anomaly: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/anomalies/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAnomaly",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_anomaly) } {
            return .{ .service_metadata = service_metadata, .action = describe_anomaly };
        }
    },
    Response: type = struct {
        proactive_anomaly: ?struct {
            id: ?[]const u8 = null,
            severity: ?[]const u8 = null,
            status: ?[]const u8 = null,
            update_time: ?i64 = null,
            anomaly_time_range: ?AnomalyTimeRange = null,
            prediction_time_range: ?PredictionTimeRange = null,
            source_details: ?AnomalySourceDetails = null,
            associated_insight_id: ?[]const u8 = null,
            resource_collection: ?ResourceCollection = null,
            limit: ?f64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .severity = "Severity",
                    .status = "Status",
                    .update_time = "UpdateTime",
                    .anomaly_time_range = "AnomalyTimeRange",
                    .prediction_time_range = "PredictionTimeRange",
                    .source_details = "SourceDetails",
                    .associated_insight_id = "AssociatedInsightId",
                    .resource_collection = "ResourceCollection",
                    .limit = "Limit",
                };
                return @field(mappings, field_name);
            }
        } = null,
        reactive_anomaly: ?struct {
            id: ?[]const u8 = null,
            severity: ?[]const u8 = null,
            status: ?[]const u8 = null,
            anomaly_time_range: ?AnomalyTimeRange = null,
            source_details: ?AnomalySourceDetails = null,
            associated_insight_id: ?[]const u8 = null,
            resource_collection: ?ResourceCollection = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .severity = "Severity",
                    .status = "Status",
                    .anomaly_time_range = "AnomalyTimeRange",
                    .source_details = "SourceDetails",
                    .associated_insight_id = "AssociatedInsightId",
                    .resource_collection = "ResourceCollection",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .proactive_anomaly = "ProactiveAnomaly",
                .reactive_anomaly = "ReactiveAnomaly",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_feedback: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/feedback",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeFeedback",
    Request: type = struct {
        insight_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insight_id = "InsightId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_feedback) } {
            return .{ .service_metadata = service_metadata, .action = describe_feedback };
        }
    },
    Response: type = struct {
        insight_feedback: ?InsightFeedback = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insight_feedback = "InsightFeedback",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_insight: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/insights/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeInsight",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_insight) } {
            return .{ .service_metadata = service_metadata, .action = describe_insight };
        }
    },
    Response: type = struct {
        proactive_insight: ?struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            severity: ?[]const u8 = null,
            status: ?[]const u8 = null,
            insight_time_range: ?InsightTimeRange = null,
            prediction_time_range: ?PredictionTimeRange = null,
            resource_collection: ?ResourceCollection = null,
            ssm_ops_item_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .name = "Name",
                    .severity = "Severity",
                    .status = "Status",
                    .insight_time_range = "InsightTimeRange",
                    .prediction_time_range = "PredictionTimeRange",
                    .resource_collection = "ResourceCollection",
                    .ssm_ops_item_id = "SsmOpsItemId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        reactive_insight: ?struct {
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            severity: ?[]const u8 = null,
            status: ?[]const u8 = null,
            insight_time_range: ?InsightTimeRange = null,
            resource_collection: ?ResourceCollection = null,
            ssm_ops_item_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .name = "Name",
                    .severity = "Severity",
                    .status = "Status",
                    .insight_time_range = "InsightTimeRange",
                    .resource_collection = "ResourceCollection",
                    .ssm_ops_item_id = "SsmOpsItemId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .proactive_insight = "ProactiveInsight",
                .reactive_insight = "ReactiveInsight",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_resource_collection_health: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/health/resource-collection/{ResourceCollectionType}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeResourceCollectionHealth",
    Request: type = struct {
        resource_collection_type: []const u8,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_collection_type = "ResourceCollectionType",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_resource_collection_health) } {
            return .{ .service_metadata = service_metadata, .action = describe_resource_collection_health };
        }
    },
    Response: type = struct {
        cloud_formation: []struct {
            stack_name: ?[]const u8 = null,
            insight: ?struct {
                open_proactive_insights: ?i64 = null,
                open_reactive_insights: ?i64 = null,
                mean_time_to_recover_in_milliseconds: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .open_proactive_insights = "OpenProactiveInsights",
                        .open_reactive_insights = "OpenReactiveInsights",
                        .mean_time_to_recover_in_milliseconds = "MeanTimeToRecoverInMilliseconds",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .stack_name = "StackName",
                    .insight = "Insight",
                };
                return @field(mappings, field_name);
            }
        },
        service: ?[]struct {
            service_name: ?[]const u8 = null,
            insight: ?struct {
                open_proactive_insights: ?i64 = null,
                open_reactive_insights: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .open_proactive_insights = "OpenProactiveInsights",
                        .open_reactive_insights = "OpenReactiveInsights",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .service_name = "ServiceName",
                    .insight = "Insight",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cloud_formation = "CloudFormation",
                .service = "Service",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_service_integration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/service-integrations",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeServiceIntegration",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_service_integration) } {
            return .{ .service_metadata = service_metadata, .action = describe_service_integration };
        }
    },
    Response: type = struct {
        service_integration: ?struct {
            ops_center: ?struct {
                opt_in_status: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .opt_in_status = "OptInStatus",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .ops_center = "OpsCenter",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_integration = "ServiceIntegration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const get_cost_estimation: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/cost-estimation",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCostEstimation",
    Request: type = struct {
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_cost_estimation) } {
            return .{ .service_metadata = service_metadata, .action = get_cost_estimation };
        }
    },
    Response: type = struct {
        resource_collection: ?CostEstimationResourceCollectionFilter = null,
        status: ?[]const u8 = null,
        costs: ?[]struct {
            type: ?[]const u8 = null,
            state: ?[]const u8 = null,
            count: ?i64 = null,
            unit_cost: ?f64 = null,
            cost: ?f64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "Type",
                    .state = "State",
                    .count = "Count",
                    .unit_cost = "UnitCost",
                    .cost = "Cost",
                };
                return @field(mappings, field_name);
            }
        } = null,
        time_range: ?struct {
            start_time: ?i64 = null,
            end_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .start_time = "StartTime",
                    .end_time = "EndTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        total_cost: ?f64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_collection = "ResourceCollection",
                .status = "Status",
                .costs = "Costs",
                .time_range = "TimeRange",
                .total_cost = "TotalCost",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_resource_collection: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/resource-collections/{ResourceCollectionType}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetResourceCollection",
    Request: type = struct {
        resource_collection_type: []const u8,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_collection_type = "ResourceCollectionType",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_collection) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_collection };
        }
    },
    Response: type = struct {
        resource_collection: ?struct {
            cloud_formation: ?struct {
                stack_names: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .stack_names = "StackNames",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .cloud_formation = "CloudFormation",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_collection = "ResourceCollection",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_anomalies_for_insight: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/anomalies/insight/{InsightId}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAnomaliesForInsight",
    Request: type = struct {
        insight_id: []const u8,
        start_time_range: ?StartTimeRange = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insight_id = "InsightId",
                .start_time_range = "StartTimeRange",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_anomalies_for_insight) } {
            return .{ .service_metadata = service_metadata, .action = list_anomalies_for_insight };
        }
    },
    Response: type = struct {
        proactive_anomalies: ?[]struct {
            id: ?[]const u8 = null,
            severity: ?[]const u8 = null,
            status: ?[]const u8 = null,
            update_time: ?i64 = null,
            anomaly_time_range: ?AnomalyTimeRange = null,
            prediction_time_range: ?PredictionTimeRange = null,
            source_details: ?AnomalySourceDetails = null,
            associated_insight_id: ?[]const u8 = null,
            resource_collection: ?ResourceCollection = null,
            limit: ?f64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .severity = "Severity",
                    .status = "Status",
                    .update_time = "UpdateTime",
                    .anomaly_time_range = "AnomalyTimeRange",
                    .prediction_time_range = "PredictionTimeRange",
                    .source_details = "SourceDetails",
                    .associated_insight_id = "AssociatedInsightId",
                    .resource_collection = "ResourceCollection",
                    .limit = "Limit",
                };
                return @field(mappings, field_name);
            }
        } = null,
        reactive_anomalies: ?[]struct {
            id: ?[]const u8 = null,
            severity: ?[]const u8 = null,
            status: ?[]const u8 = null,
            anomaly_time_range: ?AnomalyTimeRange = null,
            source_details: ?AnomalySourceDetails = null,
            associated_insight_id: ?[]const u8 = null,
            resource_collection: ?ResourceCollection = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .severity = "Severity",
                    .status = "Status",
                    .anomaly_time_range = "AnomalyTimeRange",
                    .source_details = "SourceDetails",
                    .associated_insight_id = "AssociatedInsightId",
                    .resource_collection = "ResourceCollection",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .proactive_anomalies = "ProactiveAnomalies",
                .reactive_anomalies = "ReactiveAnomalies",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_events: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/events",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEvents",
    Request: type = struct {
        filters: struct {
            insight_id: ?[]const u8 = null,
            event_time_range: ?struct {
                from_time: i64,
                to_time: i64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .from_time = "FromTime",
                        .to_time = "ToTime",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            event_class: ?[]const u8 = null,
            event_source: ?[]const u8 = null,
            data_source: ?[]const u8 = null,
            resource_collection: ?ResourceCollection = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .insight_id = "InsightId",
                    .event_time_range = "EventTimeRange",
                    .event_class = "EventClass",
                    .event_source = "EventSource",
                    .data_source = "DataSource",
                    .resource_collection = "ResourceCollection",
                };
                return @field(mappings, field_name);
            }
        },
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_events) } {
            return .{ .service_metadata = service_metadata, .action = list_events };
        }
    },
    Response: type = struct {
        events: []struct {
            resource_collection: ?ResourceCollection = null,
            id: ?[]const u8 = null,
            time: ?i64 = null,
            event_source: ?[]const u8 = null,
            name: ?[]const u8 = null,
            data_source: ?[]const u8 = null,
            event_class: ?[]const u8 = null,
            resources: ?[]struct {
                type: ?[]const u8 = null,
                name: ?[]const u8 = null,
                arn: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .type = "Type",
                        .name = "Name",
                        .arn = "Arn",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_collection = "ResourceCollection",
                    .id = "Id",
                    .time = "Time",
                    .event_source = "EventSource",
                    .name = "Name",
                    .data_source = "DataSource",
                    .event_class = "EventClass",
                    .resources = "Resources",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .events = "Events",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_insights: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/insights",
        .success_code = 200,
    };

    action_name: []const u8 = "ListInsights",
    Request: type = struct {
        status_filter: struct {
            ongoing: ?struct {
                type: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .type = "Type",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            closed: ?struct {
                type: []const u8,
                end_time_range: struct {
                    from_time: ?i64 = null,
                    to_time: ?i64 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .from_time = "FromTime",
                            .to_time = "ToTime",
                        };
                        return @field(mappings, field_name);
                    }
                },

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .type = "Type",
                        .end_time_range = "EndTimeRange",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            any: ?struct {
                type: []const u8,
                start_time_range: StartTimeRange,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .type = "Type",
                        .start_time_range = "StartTimeRange",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .ongoing = "Ongoing",
                    .closed = "Closed",
                    .any = "Any",
                };
                return @field(mappings, field_name);
            }
        },
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status_filter = "StatusFilter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_insights) } {
            return .{ .service_metadata = service_metadata, .action = list_insights };
        }
    },
    Response: type = struct {
        proactive_insights: ?[]ProactiveInsightSummary = null,
        reactive_insights: ?[]ReactiveInsightSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .proactive_insights = "ProactiveInsights",
                .reactive_insights = "ReactiveInsights",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_notification_channels: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/channels",
        .success_code = 200,
    };

    action_name: []const u8 = "ListNotificationChannels",
    Request: type = struct {
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_notification_channels) } {
            return .{ .service_metadata = service_metadata, .action = list_notification_channels };
        }
    },
    Response: type = struct {
        channels: ?[]struct {
            id: ?[]const u8 = null,
            config: ?NotificationChannelConfig = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .config = "Config",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channels = "Channels",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_recommendations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/recommendations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRecommendations",
    Request: type = struct {
        insight_id: []const u8,
        next_token: ?[]const u8 = null,
        locale: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insight_id = "InsightId",
                .next_token = "NextToken",
                .locale = "Locale",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_recommendations) } {
            return .{ .service_metadata = service_metadata, .action = list_recommendations };
        }
    },
    Response: type = struct {
        recommendations: ?[]struct {
            description: ?[]const u8 = null,
            link: ?[]const u8 = null,
            name: ?[]const u8 = null,
            reason: ?[]const u8 = null,
            related_events: ?[]struct {
                name: ?[]const u8 = null,
                resources: ?[]struct {
                    name: ?[]const u8 = null,
                    type: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "Name",
                            .type = "Type",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .resources = "Resources",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            related_anomalies: ?[]struct {
                resources: ?[]struct {
                    name: ?[]const u8 = null,
                    type: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "Name",
                            .type = "Type",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                source_details: ?[]struct {
                    cloud_watch_metrics: ?[]struct {
                        metric_name: ?[]const u8 = null,
                        namespace: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .metric_name = "MetricName",
                                .namespace = "Namespace",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .cloud_watch_metrics = "CloudWatchMetrics",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .resources = "Resources",
                        .source_details = "SourceDetails",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .description = "Description",
                    .link = "Link",
                    .name = "Name",
                    .reason = "Reason",
                    .related_events = "RelatedEvents",
                    .related_anomalies = "RelatedAnomalies",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .recommendations = "Recommendations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const put_feedback: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/feedback",
        .success_code = 200,
    };

    action_name: []const u8 = "PutFeedback",
    Request: type = struct {
        insight_feedback: ?InsightFeedback = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .insight_feedback = "InsightFeedback",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_feedback) } {
            return .{ .service_metadata = service_metadata, .action = put_feedback };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const remove_notification_channel: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/channels/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "RemoveNotificationChannel",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_notification_channel) } {
            return .{ .service_metadata = service_metadata, .action = remove_notification_channel };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const search_insights: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/insights/search",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchInsights",
    Request: type = struct {
        start_time_range: StartTimeRange,
        filters: ?struct {
            severities: ?[][]const u8 = null,
            statuses: ?[][]const u8 = null,
            resource_collection: ?ResourceCollection = null,
            service_collection: ?ServiceCollection = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .severities = "Severities",
                    .statuses = "Statuses",
                    .resource_collection = "ResourceCollection",
                    .service_collection = "ServiceCollection",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .start_time_range = "StartTimeRange",
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .type = "Type",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_insights) } {
            return .{ .service_metadata = service_metadata, .action = search_insights };
        }
    },
    Response: type = struct {
        proactive_insights: ?[]ProactiveInsightSummary = null,
        reactive_insights: ?[]ReactiveInsightSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .proactive_insights = "ProactiveInsights",
                .reactive_insights = "ReactiveInsights",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const start_cost_estimation: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/cost-estimation",
        .success_code = 200,
    };

    action_name: []const u8 = "StartCostEstimation",
    Request: type = struct {
        resource_collection: CostEstimationResourceCollectionFilter,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_collection = "ResourceCollection",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_cost_estimation) } {
            return .{ .service_metadata = service_metadata, .action = start_cost_estimation };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_resource_collection: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/resource-collections",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateResourceCollection",
    Request: type = struct {
        action: []const u8,
        resource_collection: struct {
            cloud_formation: ?struct {
                stack_names: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .stack_names = "StackNames",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .cloud_formation = "CloudFormation",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action = "Action",
                .resource_collection = "ResourceCollection",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_resource_collection) } {
            return .{ .service_metadata = service_metadata, .action = update_resource_collection };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const update_service_integration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/service-integrations",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateServiceIntegration",
    Request: type = struct {
        service_integration: struct {
            ops_center: ?struct {
                opt_in_status: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .opt_in_status = "OptInStatus",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .ops_center = "OpsCenter",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_integration = "ServiceIntegration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_service_integration) } {
            return .{ .service_metadata = service_metadata, .action = update_service_integration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};

pub const CostEstimationResourceCollectionFilter = struct {
    cloud_formation: ?CloudFormationCostEstimationResourceCollectionFilter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_formation = "CloudFormation",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudFormationCostEstimationResourceCollectionFilter = struct {
    stack_names: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stack_names = "StackNames",
        };
        return @field(mappings, field_name);
    }
};

pub const ReactiveInsightSummary = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    severity: ?[]const u8 = null,
    status: ?[]const u8 = null,
    insight_time_range: ?InsightTimeRange = null,
    resource_collection: ?ResourceCollection = null,
    service_collection: ?ServiceCollection = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .name = "Name",
            .severity = "Severity",
            .status = "Status",
            .insight_time_range = "InsightTimeRange",
            .resource_collection = "ResourceCollection",
            .service_collection = "ServiceCollection",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceCollection = struct {
    service_names: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_names = "ServiceNames",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceCollection = struct {
    cloud_formation: ?CloudFormationCollection = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_formation = "CloudFormation",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudFormationCollection = struct {
    stack_names: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stack_names = "StackNames",
        };
        return @field(mappings, field_name);
    }
};

pub const InsightTimeRange = struct {
    start_time: i64,
    end_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_time = "StartTime",
            .end_time = "EndTime",
        };
        return @field(mappings, field_name);
    }
};

pub const ProactiveInsightSummary = struct {
    id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    severity: ?[]const u8 = null,
    status: ?[]const u8 = null,
    insight_time_range: ?InsightTimeRange = null,
    prediction_time_range: ?PredictionTimeRange = null,
    resource_collection: ?ResourceCollection = null,
    service_collection: ?ServiceCollection = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .name = "Name",
            .severity = "Severity",
            .status = "Status",
            .insight_time_range = "InsightTimeRange",
            .prediction_time_range = "PredictionTimeRange",
            .resource_collection = "ResourceCollection",
            .service_collection = "ServiceCollection",
        };
        return @field(mappings, field_name);
    }
};

pub const PredictionTimeRange = struct {
    start_time: i64,
    end_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_time = "StartTime",
            .end_time = "EndTime",
        };
        return @field(mappings, field_name);
    }
};

pub const StartTimeRange = struct {
    from_time: ?i64 = null,
    to_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .from_time = "FromTime",
            .to_time = "ToTime",
        };
        return @field(mappings, field_name);
    }
};

pub const InsightFeedback = struct {
    id: ?[]const u8 = null,
    feedback: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .feedback = "Feedback",
        };
        return @field(mappings, field_name);
    }
};

pub const NotificationChannelConfig = struct {
    sns: SnsChannelConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sns = "Sns",
        };
        return @field(mappings, field_name);
    }
};

pub const SnsChannelConfig = struct {
    topic_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .topic_arn = "TopicArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AnomalySourceDetails = struct {
    cloud_watch_metrics: ?[]CloudWatchMetricsDetail = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_watch_metrics = "CloudWatchMetrics",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudWatchMetricsDetail = struct {
    metric_name: ?[]const u8 = null,
    namespace: ?[]const u8 = null,
    dimensions: ?[]CloudWatchMetricsDimension = null,
    stat: ?[]const u8 = null,
    unit: ?[]const u8 = null,
    period: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metric_name = "MetricName",
            .namespace = "Namespace",
            .dimensions = "Dimensions",
            .stat = "Stat",
            .unit = "Unit",
            .period = "Period",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudWatchMetricsDimension = struct {
    name: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const AnomalyTimeRange = struct {
    start_time: i64,
    end_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_time = "StartTime",
            .end_time = "EndTime",
        };
        return @field(mappings, field_name);
    }
};
