const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2021-03-12";
pub const sdk_id: []const u8 = "finspace";
pub const arn_namespace: []const u8 = "finspace";
pub const endpoint_prefix: []const u8 = "finspace";
pub const sigv4_name: []const u8 = "finspace";
pub const name: []const u8 = "AWSHabaneroManagementService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2021-03-12",
    sdk_id: []const u8 = "finspace",
    arn_namespace: []const u8 = "finspace",
    endpoint_prefix: []const u8 = "finspace",
    sigv4_name: []const u8 = "finspace",
    name: []const u8 = "AWSHabaneroManagementService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_environment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/environment",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateEnvironment",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        federation_mode: ?[]const u8 = null,
        federation_parameters: ?FederationParameters = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .kms_key_id = "kmsKeyId",
                .tags = "tags",
                .federation_mode = "federationMode",
                .federation_parameters = "federationParameters",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_environment) } {
            return .{ .service_metadata = service_metadata, .action = create_environment };
        }
    },
    Response: type = struct {
        environment_id: ?[]const u8 = null,
        environment_arn: ?[]const u8 = null,
        environment_url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .environment_arn = "environmentArn",
                .environment_url = "environmentUrl",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        LimitExceeded,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_environment: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/environment/{environmentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteEnvironment",
    Request: type = struct {
        environment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_environment) } {
            return .{ .service_metadata = service_metadata, .action = delete_environment };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_environment: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/environment/{environmentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEnvironment",
    Request: type = struct {
        environment_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_environment) } {
            return .{ .service_metadata = service_metadata, .action = get_environment };
        }
    },
    Response: type = struct {
        environment: ?Environment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment = "environment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_environments: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/environment",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEnvironments",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_environments) } {
            return .{ .service_metadata = service_metadata, .action = list_environments };
        }
    },
    Response: type = struct {
        environments: ?[]Environment = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environments = "environments",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        InvalidRequest,
        ResourceNotFound,
    },
} = .{};
pub const update_environment: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/environment/{environmentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateEnvironment",
    Request: type = struct {
        environment_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        federation_mode: ?[]const u8 = null,
        federation_parameters: ?FederationParameters = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment_id = "environmentId",
                .name = "name",
                .description = "description",
                .federation_mode = "federationMode",
                .federation_parameters = "federationParameters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_environment) } {
            return .{ .service_metadata = service_metadata, .action = update_environment };
        }
    },
    Response: type = struct {
        environment: ?Environment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .environment = "environment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const Environment = struct {
    name: ?[]const u8 = null,
    environment_id: ?[]const u8 = null,
    aws_account_id: ?[]const u8 = null,
    status: ?[]const u8 = null,
    environment_url: ?[]const u8 = null,
    description: ?[]const u8 = null,
    environment_arn: ?[]const u8 = null,
    sage_maker_studio_domain_url: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,
    dedicated_service_account_id: ?[]const u8 = null,
    federation_mode: ?[]const u8 = null,
    federation_parameters: ?FederationParameters = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .environment_id = "environmentId",
            .aws_account_id = "awsAccountId",
            .status = "status",
            .environment_url = "environmentUrl",
            .description = "description",
            .environment_arn = "environmentArn",
            .sage_maker_studio_domain_url = "sageMakerStudioDomainUrl",
            .kms_key_id = "kmsKeyId",
            .dedicated_service_account_id = "dedicatedServiceAccountId",
            .federation_mode = "federationMode",
            .federation_parameters = "federationParameters",
        };
        return @field(mappings, field_name);
    }
};

pub const FederationParameters = struct {
    saml_metadata_document: ?[]const u8 = null,
    saml_metadata_url: ?[]const u8 = null,
    application_call_back_url: ?[]const u8 = null,
    federation_urn: ?[]const u8 = null,
    federation_provider_name: ?[]const u8 = null,
    attribute_map: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .saml_metadata_document = "samlMetadataDocument",
            .saml_metadata_url = "samlMetadataURL",
            .application_call_back_url = "applicationCallBackURL",
            .federation_urn = "federationURN",
            .federation_provider_name = "federationProviderName",
            .attribute_map = "attributeMap",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "attribute_map", field_name))
            return try serializeMap(self.attribute_map, self.fieldNameFor("attribute_map"), options, out_stream);
        return false;
    }
};
