const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-03-01";
pub const sdk_id: []const u8 = "FSx";
pub const arn_namespace: []const u8 = "fsx";
pub const endpoint_prefix: []const u8 = "fsx";
pub const sigv4_name: []const u8 = "fsx";
pub const name: []const u8 = "AWSSimbaAPIService_v20180301";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-03-01",
    sdk_id: []const u8 = "FSx",
    arn_namespace: []const u8 = "fsx",
    endpoint_prefix: []const u8 = "fsx",
    sigv4_name: []const u8 = "fsx",
    name: []const u8 = "AWSSimbaAPIService_v20180301",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const associate_file_system_aliases: struct {
    action_name: []const u8 = "AssociateFileSystemAliases",
    Request: type = struct {
        client_request_token: ?[]const u8 = null,
        file_system_id: []const u8,
        aliases: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "ClientRequestToken",
                .file_system_id = "FileSystemId",
                .aliases = "Aliases",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_file_system_aliases) } {
            return .{ .service_metadata = service_metadata, .action = associate_file_system_aliases };
        }
    },
    Response: type = struct {
        aliases: ?[]Alias = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aliases = "Aliases",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        FileSystemNotFound,
        InternalServerError,
    },
} = .{};
pub const cancel_data_repository_task: struct {
    action_name: []const u8 = "CancelDataRepositoryTask",
    Request: type = struct {
        task_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_id = "TaskId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_data_repository_task) } {
            return .{ .service_metadata = service_metadata, .action = cancel_data_repository_task };
        }
    },
    Response: type = struct {
        lifecycle: ?[]const u8 = null,
        task_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lifecycle = "Lifecycle",
                .task_id = "TaskId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        DataRepositoryTaskEnded,
        DataRepositoryTaskNotFound,
        InternalServerError,
        UnsupportedOperation,
    },
} = .{};
pub const copy_backup: struct {
    action_name: []const u8 = "CopyBackup",
    Request: type = struct {
        client_request_token: ?[]const u8 = null,
        source_backup_id: []const u8,
        source_region: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        copy_tags: ?bool = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "ClientRequestToken",
                .source_backup_id = "SourceBackupId",
                .source_region = "SourceRegion",
                .kms_key_id = "KmsKeyId",
                .copy_tags = "CopyTags",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(copy_backup) } {
            return .{ .service_metadata = service_metadata, .action = copy_backup };
        }
    },
    Response: type = struct {
        backup: ?Backup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup = "Backup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BackupNotFound,
        BadRequest,
        IncompatibleParameterError,
        IncompatibleRegionForMultiAZ,
        InternalServerError,
        InvalidDestinationKmsKey,
        InvalidRegion,
        InvalidSourceKmsKey,
        ServiceLimitExceeded,
        SourceBackupUnavailable,
        UnsupportedOperation,
    },
} = .{};
pub const create_backup: struct {
    action_name: []const u8 = "CreateBackup",
    Request: type = struct {
        file_system_id: []const u8,
        client_request_token: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system_id = "FileSystemId",
                .client_request_token = "ClientRequestToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_backup) } {
            return .{ .service_metadata = service_metadata, .action = create_backup };
        }
    },
    Response: type = struct {
        backup: ?Backup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup = "Backup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BackupInProgress,
        BadRequest,
        FileSystemNotFound,
        IncompatibleParameterError,
        InternalServerError,
        ServiceLimitExceeded,
        UnsupportedOperation,
    },
} = .{};
pub const create_data_repository_task: struct {
    action_name: []const u8 = "CreateDataRepositoryTask",
    Request: type = struct {
        type: []const u8,
        paths: ?[][]const u8 = null,
        file_system_id: []const u8,
        report: CompletionReport,
        client_request_token: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .type = "Type",
                .paths = "Paths",
                .file_system_id = "FileSystemId",
                .report = "Report",
                .client_request_token = "ClientRequestToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_data_repository_task) } {
            return .{ .service_metadata = service_metadata, .action = create_data_repository_task };
        }
    },
    Response: type = struct {
        data_repository_task: ?DataRepositoryTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_repository_task = "DataRepositoryTask",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        DataRepositoryTaskExecuting,
        FileSystemNotFound,
        IncompatibleParameterError,
        InternalServerError,
        ServiceLimitExceeded,
        UnsupportedOperation,
    },
} = .{};
pub const create_file_system: struct {
    action_name: []const u8 = "CreateFileSystem",
    Request: type = struct {
        client_request_token: ?[]const u8 = null,
        file_system_type: []const u8,
        storage_capacity: i64,
        storage_type: ?[]const u8 = null,
        subnet_ids: [][]const u8,
        security_group_ids: ?[][]const u8 = null,
        tags: ?[]Tag = null,
        kms_key_id: ?[]const u8 = null,
        windows_configuration: ?CreateFileSystemWindowsConfiguration = null,
        lustre_configuration: ?CreateFileSystemLustreConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "ClientRequestToken",
                .file_system_type = "FileSystemType",
                .storage_capacity = "StorageCapacity",
                .storage_type = "StorageType",
                .subnet_ids = "SubnetIds",
                .security_group_ids = "SecurityGroupIds",
                .tags = "Tags",
                .kms_key_id = "KmsKeyId",
                .windows_configuration = "WindowsConfiguration",
                .lustre_configuration = "LustreConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_file_system) } {
            return .{ .service_metadata = service_metadata, .action = create_file_system };
        }
    },
    Response: type = struct {
        file_system: ?FileSystem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system = "FileSystem",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ActiveDirectoryError,
        BadRequest,
        IncompatibleParameterError,
        InternalServerError,
        InvalidExportPath,
        InvalidImportPath,
        InvalidNetworkSettings,
        InvalidPerUnitStorageThroughput,
        MissingFileSystemConfiguration,
        ServiceLimitExceeded,
    },
} = .{};
pub const create_file_system_from_backup: struct {
    action_name: []const u8 = "CreateFileSystemFromBackup",
    Request: type = struct {
        backup_id: []const u8,
        client_request_token: ?[]const u8 = null,
        subnet_ids: [][]const u8,
        security_group_ids: ?[][]const u8 = null,
        tags: ?[]Tag = null,
        windows_configuration: ?CreateFileSystemWindowsConfiguration = null,
        lustre_configuration: ?CreateFileSystemLustreConfiguration = null,
        storage_type: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_id = "BackupId",
                .client_request_token = "ClientRequestToken",
                .subnet_ids = "SubnetIds",
                .security_group_ids = "SecurityGroupIds",
                .tags = "Tags",
                .windows_configuration = "WindowsConfiguration",
                .lustre_configuration = "LustreConfiguration",
                .storage_type = "StorageType",
                .kms_key_id = "KmsKeyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_file_system_from_backup) } {
            return .{ .service_metadata = service_metadata, .action = create_file_system_from_backup };
        }
    },
    Response: type = struct {
        file_system: ?FileSystem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system = "FileSystem",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ActiveDirectoryError,
        BackupNotFound,
        BadRequest,
        IncompatibleParameterError,
        InternalServerError,
        InvalidNetworkSettings,
        InvalidPerUnitStorageThroughput,
        MissingFileSystemConfiguration,
        ServiceLimitExceeded,
    },
} = .{};
pub const delete_backup: struct {
    action_name: []const u8 = "DeleteBackup",
    Request: type = struct {
        backup_id: []const u8,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_id = "BackupId",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_backup) } {
            return .{ .service_metadata = service_metadata, .action = delete_backup };
        }
    },
    Response: type = struct {
        backup_id: ?[]const u8 = null,
        lifecycle: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_id = "BackupId",
                .lifecycle = "Lifecycle",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BackupBeingCopied,
        BackupInProgress,
        BackupNotFound,
        BackupRestoring,
        BadRequest,
        IncompatibleParameterError,
        InternalServerError,
    },
} = .{};
pub const delete_file_system: struct {
    action_name: []const u8 = "DeleteFileSystem",
    Request: type = struct {
        file_system_id: []const u8,
        client_request_token: ?[]const u8 = null,
        windows_configuration: ?struct {
            skip_final_backup: ?bool = null,
            final_backup_tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .skip_final_backup = "SkipFinalBackup",
                    .final_backup_tags = "FinalBackupTags",
                };
                return @field(mappings, field_name);
            }
        } = null,
        lustre_configuration: ?struct {
            skip_final_backup: ?bool = null,
            final_backup_tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .skip_final_backup = "SkipFinalBackup",
                    .final_backup_tags = "FinalBackupTags",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system_id = "FileSystemId",
                .client_request_token = "ClientRequestToken",
                .windows_configuration = "WindowsConfiguration",
                .lustre_configuration = "LustreConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_file_system) } {
            return .{ .service_metadata = service_metadata, .action = delete_file_system };
        }
    },
    Response: type = struct {
        file_system_id: ?[]const u8 = null,
        lifecycle: ?[]const u8 = null,
        windows_response: ?struct {
            final_backup_id: ?[]const u8 = null,
            final_backup_tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .final_backup_id = "FinalBackupId",
                    .final_backup_tags = "FinalBackupTags",
                };
                return @field(mappings, field_name);
            }
        } = null,
        lustre_response: ?struct {
            final_backup_id: ?[]const u8 = null,
            final_backup_tags: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .final_backup_id = "FinalBackupId",
                    .final_backup_tags = "FinalBackupTags",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system_id = "FileSystemId",
                .lifecycle = "Lifecycle",
                .windows_response = "WindowsResponse",
                .lustre_response = "LustreResponse",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        FileSystemNotFound,
        IncompatibleParameterError,
        InternalServerError,
        ServiceLimitExceeded,
    },
} = .{};
pub const describe_backups: struct {
    action_name: []const u8 = "DescribeBackups",
    Request: type = struct {
        backup_ids: ?[][]const u8 = null,
        filters: ?[]struct {
            name: ?[]const u8 = null,
            values: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backup_ids = "BackupIds",
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_backups) } {
            return .{ .service_metadata = service_metadata, .action = describe_backups };
        }
    },
    Response: type = struct {
        backups: ?[]Backup = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .backups = "Backups",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BackupNotFound,
        BadRequest,
        FileSystemNotFound,
        InternalServerError,
    },
} = .{};
pub const describe_data_repository_tasks: struct {
    action_name: []const u8 = "DescribeDataRepositoryTasks",
    Request: type = struct {
        task_ids: ?[][]const u8 = null,
        filters: ?[]struct {
            name: ?[]const u8 = null,
            values: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .values = "Values",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_ids = "TaskIds",
                .filters = "Filters",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_data_repository_tasks) } {
            return .{ .service_metadata = service_metadata, .action = describe_data_repository_tasks };
        }
    },
    Response: type = struct {
        data_repository_tasks: ?[]DataRepositoryTask = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_repository_tasks = "DataRepositoryTasks",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        DataRepositoryTaskNotFound,
        FileSystemNotFound,
        InternalServerError,
    },
} = .{};
pub const describe_file_system_aliases: struct {
    action_name: []const u8 = "DescribeFileSystemAliases",
    Request: type = struct {
        client_request_token: ?[]const u8 = null,
        file_system_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "ClientRequestToken",
                .file_system_id = "FileSystemId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_file_system_aliases) } {
            return .{ .service_metadata = service_metadata, .action = describe_file_system_aliases };
        }
    },
    Response: type = struct {
        aliases: ?[]Alias = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aliases = "Aliases",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        FileSystemNotFound,
        InternalServerError,
    },
} = .{};
pub const describe_file_systems: struct {
    action_name: []const u8 = "DescribeFileSystems",
    Request: type = struct {
        file_system_ids: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system_ids = "FileSystemIds",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_file_systems) } {
            return .{ .service_metadata = service_metadata, .action = describe_file_systems };
        }
    },
    Response: type = struct {
        file_systems: ?[]FileSystem = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_systems = "FileSystems",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        FileSystemNotFound,
        InternalServerError,
    },
} = .{};
pub const disassociate_file_system_aliases: struct {
    action_name: []const u8 = "DisassociateFileSystemAliases",
    Request: type = struct {
        client_request_token: ?[]const u8 = null,
        file_system_id: []const u8,
        aliases: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_request_token = "ClientRequestToken",
                .file_system_id = "FileSystemId",
                .aliases = "Aliases",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_file_system_aliases) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_file_system_aliases };
        }
    },
    Response: type = struct {
        aliases: ?[]Alias = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aliases = "Aliases",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        FileSystemNotFound,
        InternalServerError,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
        NotServiceResourceError,
        ResourceDoesNotSupportTagging,
        ResourceNotFound,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
        NotServiceResourceError,
        ResourceDoesNotSupportTagging,
        ResourceNotFound,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
        NotServiceResourceError,
        ResourceDoesNotSupportTagging,
        ResourceNotFound,
    },
} = .{};
pub const update_file_system: struct {
    action_name: []const u8 = "UpdateFileSystem",
    Request: type = struct {
        file_system_id: []const u8,
        client_request_token: ?[]const u8 = null,
        storage_capacity: ?i64 = null,
        windows_configuration: ?struct {
            weekly_maintenance_start_time: ?[]const u8 = null,
            daily_automatic_backup_start_time: ?[]const u8 = null,
            automatic_backup_retention_days: ?i64 = null,
            throughput_capacity: ?i64 = null,
            self_managed_active_directory_configuration: ?struct {
                user_name: ?[]const u8 = null,
                password: ?[]const u8 = null,
                dns_ips: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .user_name = "UserName",
                        .password = "Password",
                        .dns_ips = "DnsIps",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .weekly_maintenance_start_time = "WeeklyMaintenanceStartTime",
                    .daily_automatic_backup_start_time = "DailyAutomaticBackupStartTime",
                    .automatic_backup_retention_days = "AutomaticBackupRetentionDays",
                    .throughput_capacity = "ThroughputCapacity",
                    .self_managed_active_directory_configuration = "SelfManagedActiveDirectoryConfiguration",
                };
                return @field(mappings, field_name);
            }
        } = null,
        lustre_configuration: ?struct {
            weekly_maintenance_start_time: ?[]const u8 = null,
            daily_automatic_backup_start_time: ?[]const u8 = null,
            automatic_backup_retention_days: ?i64 = null,
            auto_import_policy: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .weekly_maintenance_start_time = "WeeklyMaintenanceStartTime",
                    .daily_automatic_backup_start_time = "DailyAutomaticBackupStartTime",
                    .automatic_backup_retention_days = "AutomaticBackupRetentionDays",
                    .auto_import_policy = "AutoImportPolicy",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system_id = "FileSystemId",
                .client_request_token = "ClientRequestToken",
                .storage_capacity = "StorageCapacity",
                .windows_configuration = "WindowsConfiguration",
                .lustre_configuration = "LustreConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_file_system) } {
            return .{ .service_metadata = service_metadata, .action = update_file_system };
        }
    },
    Response: type = struct {
        file_system: ?FileSystem = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .file_system = "FileSystem",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        FileSystemNotFound,
        IncompatibleParameterError,
        InternalServerError,
        MissingFileSystemConfiguration,
        ServiceLimitExceeded,
        UnsupportedOperation,
    },
} = .{};

pub const FileSystem = struct {
    owner_id: ?[]const u8 = null,
    creation_time: ?i64 = null,
    file_system_id: ?[]const u8 = null,
    file_system_type: ?[]const u8 = null,
    lifecycle: ?[]const u8 = null,
    failure_details: ?FileSystemFailureDetails = null,
    storage_capacity: ?i64 = null,
    storage_type: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    subnet_ids: ?[][]const u8 = null,
    network_interface_ids: ?[][]const u8 = null,
    dns_name: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,
    resource_arn: ?[]const u8 = null,
    tags: ?[]Tag = null,
    windows_configuration: ?WindowsFileSystemConfiguration = null,
    lustre_configuration: ?LustreFileSystemConfiguration = null,
    administrative_actions: ?[]AdministrativeAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .owner_id = "OwnerId",
            .creation_time = "CreationTime",
            .file_system_id = "FileSystemId",
            .file_system_type = "FileSystemType",
            .lifecycle = "Lifecycle",
            .failure_details = "FailureDetails",
            .storage_capacity = "StorageCapacity",
            .storage_type = "StorageType",
            .vpc_id = "VpcId",
            .subnet_ids = "SubnetIds",
            .network_interface_ids = "NetworkInterfaceIds",
            .dns_name = "DNSName",
            .kms_key_id = "KmsKeyId",
            .resource_arn = "ResourceARN",
            .tags = "Tags",
            .windows_configuration = "WindowsConfiguration",
            .lustre_configuration = "LustreConfiguration",
            .administrative_actions = "AdministrativeActions",
        };
        return @field(mappings, field_name);
    }
};

pub const AdministrativeAction = struct {
    administrative_action_type: ?[]const u8 = null,
    progress_percent: ?i64 = null,
    request_time: ?i64 = null,
    status: ?[]const u8 = null,
    target_file_system_values: ?FileSystem = null,
    failure_details: ?AdministrativeActionFailureDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .administrative_action_type = "AdministrativeActionType",
            .progress_percent = "ProgressPercent",
            .request_time = "RequestTime",
            .status = "Status",
            .target_file_system_values = "TargetFileSystemValues",
            .failure_details = "FailureDetails",
        };
        return @field(mappings, field_name);
    }
};

pub const AdministrativeActionFailureDetails = struct {
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const LustreFileSystemConfiguration = struct {
    weekly_maintenance_start_time: ?[]const u8 = null,
    data_repository_configuration: ?DataRepositoryConfiguration = null,
    deployment_type: ?[]const u8 = null,
    per_unit_storage_throughput: ?i64 = null,
    mount_name: ?[]const u8 = null,
    daily_automatic_backup_start_time: ?[]const u8 = null,
    automatic_backup_retention_days: ?i64 = null,
    copy_tags_to_backups: ?bool = null,
    drive_cache_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .weekly_maintenance_start_time = "WeeklyMaintenanceStartTime",
            .data_repository_configuration = "DataRepositoryConfiguration",
            .deployment_type = "DeploymentType",
            .per_unit_storage_throughput = "PerUnitStorageThroughput",
            .mount_name = "MountName",
            .daily_automatic_backup_start_time = "DailyAutomaticBackupStartTime",
            .automatic_backup_retention_days = "AutomaticBackupRetentionDays",
            .copy_tags_to_backups = "CopyTagsToBackups",
            .drive_cache_type = "DriveCacheType",
        };
        return @field(mappings, field_name);
    }
};

pub const DataRepositoryConfiguration = struct {
    lifecycle: ?[]const u8 = null,
    import_path: ?[]const u8 = null,
    export_path: ?[]const u8 = null,
    imported_file_chunk_size: ?i64 = null,
    auto_import_policy: ?[]const u8 = null,
    failure_details: ?DataRepositoryFailureDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lifecycle = "Lifecycle",
            .import_path = "ImportPath",
            .export_path = "ExportPath",
            .imported_file_chunk_size = "ImportedFileChunkSize",
            .auto_import_policy = "AutoImportPolicy",
            .failure_details = "FailureDetails",
        };
        return @field(mappings, field_name);
    }
};

pub const DataRepositoryFailureDetails = struct {
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const WindowsFileSystemConfiguration = struct {
    active_directory_id: ?[]const u8 = null,
    self_managed_active_directory_configuration: ?SelfManagedActiveDirectoryAttributes = null,
    deployment_type: ?[]const u8 = null,
    remote_administration_endpoint: ?[]const u8 = null,
    preferred_subnet_id: ?[]const u8 = null,
    preferred_file_server_ip: ?[]const u8 = null,
    throughput_capacity: ?i64 = null,
    maintenance_operations_in_progress: ?[][]const u8 = null,
    weekly_maintenance_start_time: ?[]const u8 = null,
    daily_automatic_backup_start_time: ?[]const u8 = null,
    automatic_backup_retention_days: ?i64 = null,
    copy_tags_to_backups: ?bool = null,
    aliases: ?[]Alias = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .active_directory_id = "ActiveDirectoryId",
            .self_managed_active_directory_configuration = "SelfManagedActiveDirectoryConfiguration",
            .deployment_type = "DeploymentType",
            .remote_administration_endpoint = "RemoteAdministrationEndpoint",
            .preferred_subnet_id = "PreferredSubnetId",
            .preferred_file_server_ip = "PreferredFileServerIp",
            .throughput_capacity = "ThroughputCapacity",
            .maintenance_operations_in_progress = "MaintenanceOperationsInProgress",
            .weekly_maintenance_start_time = "WeeklyMaintenanceStartTime",
            .daily_automatic_backup_start_time = "DailyAutomaticBackupStartTime",
            .automatic_backup_retention_days = "AutomaticBackupRetentionDays",
            .copy_tags_to_backups = "CopyTagsToBackups",
            .aliases = "Aliases",
        };
        return @field(mappings, field_name);
    }
};

pub const Alias = struct {
    name: ?[]const u8 = null,
    lifecycle: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .lifecycle = "Lifecycle",
        };
        return @field(mappings, field_name);
    }
};

pub const SelfManagedActiveDirectoryAttributes = struct {
    domain_name: ?[]const u8 = null,
    organizational_unit_distinguished_name: ?[]const u8 = null,
    file_system_administrators_group: ?[]const u8 = null,
    user_name: ?[]const u8 = null,
    dns_ips: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain_name = "DomainName",
            .organizational_unit_distinguished_name = "OrganizationalUnitDistinguishedName",
            .file_system_administrators_group = "FileSystemAdministratorsGroup",
            .user_name = "UserName",
            .dns_ips = "DnsIps",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const FileSystemFailureDetails = struct {
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const DataRepositoryTask = struct {
    task_id: []const u8,
    lifecycle: []const u8,
    type: []const u8,
    creation_time: i64,
    start_time: ?i64 = null,
    end_time: ?i64 = null,
    resource_arn: ?[]const u8 = null,
    tags: ?[]Tag = null,
    file_system_id: []const u8,
    paths: ?[][]const u8 = null,
    failure_details: ?DataRepositoryTaskFailureDetails = null,
    status: ?DataRepositoryTaskStatus = null,
    report: ?CompletionReport = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .task_id = "TaskId",
            .lifecycle = "Lifecycle",
            .type = "Type",
            .creation_time = "CreationTime",
            .start_time = "StartTime",
            .end_time = "EndTime",
            .resource_arn = "ResourceARN",
            .tags = "Tags",
            .file_system_id = "FileSystemId",
            .paths = "Paths",
            .failure_details = "FailureDetails",
            .status = "Status",
            .report = "Report",
        };
        return @field(mappings, field_name);
    }
};

pub const CompletionReport = struct {
    enabled: bool,
    path: ?[]const u8 = null,
    format: ?[]const u8 = null,
    scope: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
            .path = "Path",
            .format = "Format",
            .scope = "Scope",
        };
        return @field(mappings, field_name);
    }
};

pub const DataRepositoryTaskStatus = struct {
    total_count: ?i64 = null,
    succeeded_count: ?i64 = null,
    failed_count: ?i64 = null,
    last_updated_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .total_count = "TotalCount",
            .succeeded_count = "SucceededCount",
            .failed_count = "FailedCount",
            .last_updated_time = "LastUpdatedTime",
        };
        return @field(mappings, field_name);
    }
};

pub const DataRepositoryTaskFailureDetails = struct {
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const Backup = struct {
    backup_id: []const u8,
    lifecycle: []const u8,
    failure_details: ?BackupFailureDetails = null,
    type: []const u8,
    progress_percent: ?i64 = null,
    creation_time: i64,
    kms_key_id: ?[]const u8 = null,
    resource_arn: ?[]const u8 = null,
    tags: ?[]Tag = null,
    file_system: FileSystem,
    directory_information: ?ActiveDirectoryBackupAttributes = null,
    owner_id: ?[]const u8 = null,
    source_backup_id: ?[]const u8 = null,
    source_backup_region: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .backup_id = "BackupId",
            .lifecycle = "Lifecycle",
            .failure_details = "FailureDetails",
            .type = "Type",
            .progress_percent = "ProgressPercent",
            .creation_time = "CreationTime",
            .kms_key_id = "KmsKeyId",
            .resource_arn = "ResourceARN",
            .tags = "Tags",
            .file_system = "FileSystem",
            .directory_information = "DirectoryInformation",
            .owner_id = "OwnerId",
            .source_backup_id = "SourceBackupId",
            .source_backup_region = "SourceBackupRegion",
        };
        return @field(mappings, field_name);
    }
};

pub const ActiveDirectoryBackupAttributes = struct {
    domain_name: ?[]const u8 = null,
    active_directory_id: ?[]const u8 = null,
    resource_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain_name = "DomainName",
            .active_directory_id = "ActiveDirectoryId",
            .resource_arn = "ResourceARN",
        };
        return @field(mappings, field_name);
    }
};

pub const BackupFailureDetails = struct {
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const CreateFileSystemLustreConfiguration = struct {
    weekly_maintenance_start_time: ?[]const u8 = null,
    import_path: ?[]const u8 = null,
    export_path: ?[]const u8 = null,
    imported_file_chunk_size: ?i64 = null,
    deployment_type: ?[]const u8 = null,
    auto_import_policy: ?[]const u8 = null,
    per_unit_storage_throughput: ?i64 = null,
    daily_automatic_backup_start_time: ?[]const u8 = null,
    automatic_backup_retention_days: ?i64 = null,
    copy_tags_to_backups: ?bool = null,
    drive_cache_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .weekly_maintenance_start_time = "WeeklyMaintenanceStartTime",
            .import_path = "ImportPath",
            .export_path = "ExportPath",
            .imported_file_chunk_size = "ImportedFileChunkSize",
            .deployment_type = "DeploymentType",
            .auto_import_policy = "AutoImportPolicy",
            .per_unit_storage_throughput = "PerUnitStorageThroughput",
            .daily_automatic_backup_start_time = "DailyAutomaticBackupStartTime",
            .automatic_backup_retention_days = "AutomaticBackupRetentionDays",
            .copy_tags_to_backups = "CopyTagsToBackups",
            .drive_cache_type = "DriveCacheType",
        };
        return @field(mappings, field_name);
    }
};

pub const CreateFileSystemWindowsConfiguration = struct {
    active_directory_id: ?[]const u8 = null,
    self_managed_active_directory_configuration: ?SelfManagedActiveDirectoryConfiguration = null,
    deployment_type: ?[]const u8 = null,
    preferred_subnet_id: ?[]const u8 = null,
    throughput_capacity: i64,
    weekly_maintenance_start_time: ?[]const u8 = null,
    daily_automatic_backup_start_time: ?[]const u8 = null,
    automatic_backup_retention_days: ?i64 = null,
    copy_tags_to_backups: ?bool = null,
    aliases: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .active_directory_id = "ActiveDirectoryId",
            .self_managed_active_directory_configuration = "SelfManagedActiveDirectoryConfiguration",
            .deployment_type = "DeploymentType",
            .preferred_subnet_id = "PreferredSubnetId",
            .throughput_capacity = "ThroughputCapacity",
            .weekly_maintenance_start_time = "WeeklyMaintenanceStartTime",
            .daily_automatic_backup_start_time = "DailyAutomaticBackupStartTime",
            .automatic_backup_retention_days = "AutomaticBackupRetentionDays",
            .copy_tags_to_backups = "CopyTagsToBackups",
            .aliases = "Aliases",
        };
        return @field(mappings, field_name);
    }
};

pub const SelfManagedActiveDirectoryConfiguration = struct {
    domain_name: []const u8,
    organizational_unit_distinguished_name: ?[]const u8 = null,
    file_system_administrators_group: ?[]const u8 = null,
    user_name: []const u8,
    password: []const u8,
    dns_ips: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain_name = "DomainName",
            .organizational_unit_distinguished_name = "OrganizationalUnitDistinguishedName",
            .file_system_administrators_group = "FileSystemAdministratorsGroup",
            .user_name = "UserName",
            .password = "Password",
            .dns_ips = "DnsIps",
        };
        return @field(mappings, field_name);
    }
};
