const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-06-15";
pub const sdk_id: []const u8 = "identitystore";
pub const arn_namespace: []const u8 = "identitystore";
pub const endpoint_prefix: []const u8 = "identitystore";
pub const sigv4_name: []const u8 = "identitystore";
pub const name: []const u8 = "AWSIdentityStore";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-06-15",
    sdk_id: []const u8 = "identitystore",
    arn_namespace: []const u8 = "identitystore",
    endpoint_prefix: []const u8 = "identitystore",
    sigv4_name: []const u8 = "identitystore",
    name: []const u8 = "AWSIdentityStore",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const describe_group: struct {
    action_name: []const u8 = "DescribeGroup",
    Request: type = struct {
        identity_store_id: []const u8,
        group_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_store_id = "IdentityStoreId",
                .group_id = "GroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_group) } {
            return .{ .service_metadata = service_metadata, .action = describe_group };
        }
    },
    Response: type = struct {
        group_id: []const u8,
        display_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_id = "GroupId",
                .display_name = "DisplayName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_user: struct {
    action_name: []const u8 = "DescribeUser",
    Request: type = struct {
        identity_store_id: []const u8,
        user_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_store_id = "IdentityStoreId",
                .user_id = "UserId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_user) } {
            return .{ .service_metadata = service_metadata, .action = describe_user };
        }
    },
    Response: type = struct {
        user_name: []const u8,
        user_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_name = "UserName",
                .user_id = "UserId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_groups: struct {
    action_name: []const u8 = "ListGroups",
    Request: type = struct {
        identity_store_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_store_id = "IdentityStoreId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_groups };
        }
    },
    Response: type = struct {
        groups: []struct {
            group_id: []const u8,
            display_name: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .group_id = "GroupId",
                    .display_name = "DisplayName",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .groups = "Groups",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_users: struct {
    action_name: []const u8 = "ListUsers",
    Request: type = struct {
        identity_store_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_store_id = "IdentityStoreId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_users) } {
            return .{ .service_metadata = service_metadata, .action = list_users };
        }
    },
    Response: type = struct {
        users: []struct {
            user_name: []const u8,
            user_id: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .user_name = "UserName",
                    .user_id = "UserId",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .users = "Users",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const Filter = struct {
    attribute_path: []const u8,
    attribute_value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute_path = "AttributePath",
            .attribute_value = "AttributeValue",
        };
        return @field(mappings, field_name);
    }
};
