const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-10-23";
pub const sdk_id: []const u8 = "IoT Events Data";
pub const arn_namespace: []const u8 = "ioteventsdata";
pub const endpoint_prefix: []const u8 = "data.iotevents";
pub const sigv4_name: []const u8 = "ioteventsdata";
pub const name: []const u8 = "IotColumboDataService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-10-23",
    sdk_id: []const u8 = "IoT Events Data",
    arn_namespace: []const u8 = "ioteventsdata",
    endpoint_prefix: []const u8 = "data.iotevents",
    sigv4_name: []const u8 = "ioteventsdata",
    name: []const u8 = "IotColumboDataService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const batch_put_message: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/inputs/messages",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchPutMessage",
    Request: type = struct {
        messages: []struct {
            message_id: []const u8,
            input_name: []const u8,
            payload: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .message_id = "messageId",
                    .input_name = "inputName",
                    .payload = "payload",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .messages = "messages",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_put_message) } {
            return .{ .service_metadata = service_metadata, .action = batch_put_message };
        }
    },
    Response: type = struct {
        batch_put_message_error_entries: ?[]struct {
            message_id: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .message_id = "messageId",
                    .error_code = "errorCode",
                    .error_message = "errorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .batch_put_message_error_entries = "BatchPutMessageErrorEntries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const batch_update_detector: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/detectors",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchUpdateDetector",
    Request: type = struct {
        detectors: []struct {
            message_id: []const u8,
            detector_model_name: []const u8,
            key_value: ?[]const u8 = null,
            state: struct {
                state_name: []const u8,
                variables: []struct {
                    name: []const u8,
                    value: []const u8,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "name",
                            .value = "value",
                        };
                        return @field(mappings, field_name);
                    }
                },
                timers: []struct {
                    name: []const u8,
                    seconds: i64,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "name",
                            .seconds = "seconds",
                        };
                        return @field(mappings, field_name);
                    }
                },

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .state_name = "stateName",
                        .variables = "variables",
                        .timers = "timers",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .message_id = "messageId",
                    .detector_model_name = "detectorModelName",
                    .key_value = "keyValue",
                    .state = "state",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detectors = "detectors",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_update_detector) } {
            return .{ .service_metadata = service_metadata, .action = batch_update_detector };
        }
    },
    Response: type = struct {
        batch_update_detector_error_entries: ?[]struct {
            message_id: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .message_id = "messageId",
                    .error_code = "errorCode",
                    .error_message = "errorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .batch_update_detector_error_entries = "batchUpdateDetectorErrorEntries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const describe_detector: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/detectors/{detectorModelName}/keyValues",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDetector",
    Request: type = struct {
        detector_model_name: []const u8,
        key_value: ?[]const u8 = null,

        pub const http_query = .{
            .key_value = "keyValue",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_model_name = "detectorModelName",
                .key_value = "keyValue",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_detector) } {
            return .{ .service_metadata = service_metadata, .action = describe_detector };
        }
    },
    Response: type = struct {
        detector: ?struct {
            detector_model_name: ?[]const u8 = null,
            key_value: ?[]const u8 = null,
            detector_model_version: ?[]const u8 = null,
            state: ?struct {
                state_name: []const u8,
                variables: []struct {
                    name: []const u8,
                    value: []const u8,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "name",
                            .value = "value",
                        };
                        return @field(mappings, field_name);
                    }
                },
                timers: []struct {
                    name: []const u8,
                    timestamp: i64,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .name = "name",
                            .timestamp = "timestamp",
                        };
                        return @field(mappings, field_name);
                    }
                },

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .state_name = "stateName",
                        .variables = "variables",
                        .timers = "timers",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            creation_time: ?i64 = null,
            last_update_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .detector_model_name = "detectorModelName",
                    .key_value = "keyValue",
                    .detector_model_version = "detectorModelVersion",
                    .state = "state",
                    .creation_time = "creationTime",
                    .last_update_time = "lastUpdateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector = "detector",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const list_detectors: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/detectors/{detectorModelName}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDetectors",
    Request: type = struct {
        detector_model_name: []const u8,
        state_name: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .state_name = "stateName",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_model_name = "detectorModelName",
                .state_name = "stateName",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_detectors) } {
            return .{ .service_metadata = service_metadata, .action = list_detectors };
        }
    },
    Response: type = struct {
        detector_summaries: ?[]struct {
            detector_model_name: ?[]const u8 = null,
            key_value: ?[]const u8 = null,
            detector_model_version: ?[]const u8 = null,
            state: ?struct {
                state_name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .state_name = "stateName",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            creation_time: ?i64 = null,
            last_update_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .detector_model_name = "detectorModelName",
                    .key_value = "keyValue",
                    .detector_model_version = "detectorModelVersion",
                    .state = "state",
                    .creation_time = "creationTime",
                    .last_update_time = "lastUpdateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .detector_summaries = "detectorSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
