const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-12-19";
pub const sdk_id: []const u8 = "Macie";
pub const arn_namespace: []const u8 = "macie";
pub const endpoint_prefix: []const u8 = "macie";
pub const sigv4_name: []const u8 = "macie";
pub const name: []const u8 = "MacieService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-12-19",
    sdk_id: []const u8 = "Macie",
    arn_namespace: []const u8 = "macie",
    endpoint_prefix: []const u8 = "macie",
    sigv4_name: []const u8 = "macie",
    name: []const u8 = "MacieService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const associate_member_account: struct {
    action_name: []const u8 = "AssociateMemberAccount",
    Request: type = struct {
        member_account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .member_account_id = "memberAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_member_account) } {
            return .{ .service_metadata = service_metadata, .action = associate_member_account };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        Internal,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const associate_s3_resources: struct {
    action_name: []const u8 = "AssociateS3Resources",
    Request: type = struct {
        member_account_id: ?[]const u8 = null,
        s3_resources: []S3ResourceClassification,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .member_account_id = "memberAccountId",
                .s3_resources = "s3Resources",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_s3_resources) } {
            return .{ .service_metadata = service_metadata, .action = associate_s3_resources };
        }
    },
    Response: type = struct {
        failed_s3_resources: ?[]FailedS3Resource = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_s3_resources = "failedS3Resources",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidInput,
        LimitExceeded,
    },
} = .{};
pub const disassociate_member_account: struct {
    action_name: []const u8 = "DisassociateMemberAccount",
    Request: type = struct {
        member_account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .member_account_id = "memberAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_member_account) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_member_account };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        Internal,
        InvalidInput,
    },
} = .{};
pub const disassociate_s3_resources: struct {
    action_name: []const u8 = "DisassociateS3Resources",
    Request: type = struct {
        member_account_id: ?[]const u8 = null,
        associated_s3_resources: []S3Resource,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .member_account_id = "memberAccountId",
                .associated_s3_resources = "associatedS3Resources",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_s3_resources) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_s3_resources };
        }
    },
    Response: type = struct {
        failed_s3_resources: ?[]FailedS3Resource = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_s3_resources = "failedS3Resources",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidInput,
    },
} = .{};
pub const list_member_accounts: struct {
    action_name: []const u8 = "ListMemberAccounts",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_member_accounts) } {
            return .{ .service_metadata = service_metadata, .action = list_member_accounts };
        }
    },
    Response: type = struct {
        member_accounts: ?[]struct {
            account_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_id = "accountId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .member_accounts = "memberAccounts",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Internal,
        InvalidInput,
    },
} = .{};
pub const list_s3_resources: struct {
    action_name: []const u8 = "ListS3Resources",
    Request: type = struct {
        member_account_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .member_account_id = "memberAccountId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_s3_resources) } {
            return .{ .service_metadata = service_metadata, .action = list_s3_resources };
        }
    },
    Response: type = struct {
        s3_resources: ?[]S3ResourceClassification = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .s3_resources = "s3Resources",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidInput,
    },
} = .{};
pub const update_s3_resources: struct {
    action_name: []const u8 = "UpdateS3Resources",
    Request: type = struct {
        member_account_id: ?[]const u8 = null,
        s3_resources_update: []struct {
            bucket_name: []const u8,
            prefix: ?[]const u8 = null,
            classification_type_update: struct {
                one_time: ?[]const u8 = null,
                continuous: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .one_time = "oneTime",
                        .continuous = "continuous",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bucket_name = "bucketName",
                    .prefix = "prefix",
                    .classification_type_update = "classificationTypeUpdate",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .member_account_id = "memberAccountId",
                .s3_resources_update = "s3ResourcesUpdate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_s3_resources) } {
            return .{ .service_metadata = service_metadata, .action = update_s3_resources };
        }
    },
    Response: type = struct {
        failed_s3_resources: ?[]FailedS3Resource = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_s3_resources = "failedS3Resources",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Internal,
        InvalidInput,
    },
} = .{};

pub const FailedS3Resource = struct {
    failed_item: ?S3Resource = null,
    error_code: ?[]const u8 = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .failed_item = "failedItem",
            .error_code = "errorCode",
            .error_message = "errorMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Resource = struct {
    bucket_name: []const u8,
    prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_name = "bucketName",
            .prefix = "prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const S3ResourceClassification = struct {
    bucket_name: []const u8,
    prefix: ?[]const u8 = null,
    classification_type: ClassificationType,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket_name = "bucketName",
            .prefix = "prefix",
            .classification_type = "classificationType",
        };
        return @field(mappings, field_name);
    }
};

pub const ClassificationType = struct {
    one_time: []const u8,
    continuous: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .one_time = "oneTime",
            .continuous = "continuous",
        };
        return @field(mappings, field_name);
    }
};
