const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2016-06-27";
pub const sdk_id: []const u8 = "Rekognition";
pub const arn_namespace: []const u8 = "rekognition";
pub const endpoint_prefix: []const u8 = "rekognition";
pub const sigv4_name: []const u8 = "rekognition";
pub const name: []const u8 = "RekognitionService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2016-06-27",
    sdk_id: []const u8 = "Rekognition",
    arn_namespace: []const u8 = "rekognition",
    endpoint_prefix: []const u8 = "rekognition",
    sigv4_name: []const u8 = "rekognition",
    name: []const u8 = "RekognitionService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const compare_faces: struct {
    action_name: []const u8 = "CompareFaces",
    Request: type = struct {
        source_image: Image,
        target_image: Image,
        similarity_threshold: ?f32 = null,
        quality_filter: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_image = "SourceImage",
                .target_image = "TargetImage",
                .similarity_threshold = "SimilarityThreshold",
                .quality_filter = "QualityFilter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(compare_faces) } {
            return .{ .service_metadata = service_metadata, .action = compare_faces };
        }
    },
    Response: type = struct {
        source_image_face: ?struct {
            bounding_box: ?BoundingBox = null,
            confidence: ?f32 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bounding_box = "BoundingBox",
                    .confidence = "Confidence",
                };
                return @field(mappings, field_name);
            }
        } = null,
        face_matches: ?[]struct {
            similarity: ?f32 = null,
            face: ?ComparedFace = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .similarity = "Similarity",
                    .face = "Face",
                };
                return @field(mappings, field_name);
            }
        } = null,
        unmatched_faces: ?[]ComparedFace = null,
        source_image_orientation_correction: ?[]const u8 = null,
        target_image_orientation_correction: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_image_face = "SourceImageFace",
                .face_matches = "FaceMatches",
                .unmatched_faces = "UnmatchedFaces",
                .source_image_orientation_correction = "SourceImageOrientationCorrection",
                .target_image_orientation_correction = "TargetImageOrientationCorrection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ImageTooLarge,
        InternalServerError,
        InvalidImageFormat,
        InvalidParameter,
        InvalidS3Object,
        ProvisionedThroughputExceeded,
        Throttling,
    },
} = .{};
pub const create_collection: struct {
    action_name: []const u8 = "CreateCollection",
    Request: type = struct {
        collection_id: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .collection_id = "CollectionId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_collection) } {
            return .{ .service_metadata = service_metadata, .action = create_collection };
        }
    },
    Response: type = struct {
        status_code: ?i64 = null,
        collection_arn: ?[]const u8 = null,
        face_model_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status_code = "StatusCode",
                .collection_arn = "CollectionArn",
                .face_model_version = "FaceModelVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceAlreadyExists,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const create_project: struct {
    action_name: []const u8 = "CreateProject",
    Request: type = struct {
        project_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_name = "ProjectName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_project) } {
            return .{ .service_metadata = service_metadata, .action = create_project };
        }
    },
    Response: type = struct {
        project_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_arn = "ProjectArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        ResourceInUse,
        Throttling,
    },
} = .{};
pub const create_project_version: struct {
    action_name: []const u8 = "CreateProjectVersion",
    Request: type = struct {
        project_arn: []const u8,
        version_name: []const u8,
        output_config: OutputConfig,
        training_data: TrainingData,
        testing_data: TestingData,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        kms_key_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_arn = "ProjectArn",
                .version_name = "VersionName",
                .output_config = "OutputConfig",
                .training_data = "TrainingData",
                .testing_data = "TestingData",
                .tags = "Tags",
                .kms_key_id = "KmsKeyId",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_project_version) } {
            return .{ .service_metadata = service_metadata, .action = create_project_version };
        }
    },
    Response: type = struct {
        project_version_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_version_arn = "ProjectVersionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        ResourceInUse,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const create_stream_processor: struct {
    action_name: []const u8 = "CreateStreamProcessor",
    Request: type = struct {
        input: StreamProcessorInput,
        output: StreamProcessorOutput,
        name: []const u8,
        settings: StreamProcessorSettings,
        role_arn: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .input = "Input",
                .output = "Output",
                .name = "Name",
                .settings = "Settings",
                .role_arn = "RoleArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_stream_processor) } {
            return .{ .service_metadata = service_metadata, .action = create_stream_processor };
        }
    },
    Response: type = struct {
        stream_processor_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream_processor_arn = "StreamProcessorArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        ResourceInUse,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const delete_collection: struct {
    action_name: []const u8 = "DeleteCollection",
    Request: type = struct {
        collection_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .collection_id = "CollectionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_collection) } {
            return .{ .service_metadata = service_metadata, .action = delete_collection };
        }
    },
    Response: type = struct {
        status_code: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status_code = "StatusCode",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_faces: struct {
    action_name: []const u8 = "DeleteFaces",
    Request: type = struct {
        collection_id: []const u8,
        face_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .collection_id = "CollectionId",
                .face_ids = "FaceIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_faces) } {
            return .{ .service_metadata = service_metadata, .action = delete_faces };
        }
    },
    Response: type = struct {
        deleted_faces: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .deleted_faces = "DeletedFaces",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_project: struct {
    action_name: []const u8 = "DeleteProject",
    Request: type = struct {
        project_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_arn = "ProjectArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_project) } {
            return .{ .service_metadata = service_metadata, .action = delete_project };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_project_version: struct {
    action_name: []const u8 = "DeleteProjectVersion",
    Request: type = struct {
        project_version_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_version_arn = "ProjectVersionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_project_version) } {
            return .{ .service_metadata = service_metadata, .action = delete_project_version };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_stream_processor: struct {
    action_name: []const u8 = "DeleteStreamProcessor",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_stream_processor) } {
            return .{ .service_metadata = service_metadata, .action = delete_stream_processor };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_collection: struct {
    action_name: []const u8 = "DescribeCollection",
    Request: type = struct {
        collection_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .collection_id = "CollectionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_collection) } {
            return .{ .service_metadata = service_metadata, .action = describe_collection };
        }
    },
    Response: type = struct {
        face_count: ?i64 = null,
        face_model_version: ?[]const u8 = null,
        collection_arn: ?[]const u8 = null,
        creation_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .face_count = "FaceCount",
                .face_model_version = "FaceModelVersion",
                .collection_arn = "CollectionARN",
                .creation_timestamp = "CreationTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_projects: struct {
    action_name: []const u8 = "DescribeProjects",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_projects) } {
            return .{ .service_metadata = service_metadata, .action = describe_projects };
        }
    },
    Response: type = struct {
        project_descriptions: ?[]struct {
            project_arn: ?[]const u8 = null,
            creation_timestamp: ?i64 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .project_arn = "ProjectArn",
                    .creation_timestamp = "CreationTimestamp",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_descriptions = "ProjectDescriptions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidPaginationToken,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        Throttling,
    },
} = .{};
pub const describe_project_versions: struct {
    action_name: []const u8 = "DescribeProjectVersions",
    Request: type = struct {
        project_arn: []const u8,
        version_names: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_arn = "ProjectArn",
                .version_names = "VersionNames",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_project_versions) } {
            return .{ .service_metadata = service_metadata, .action = describe_project_versions };
        }
    },
    Response: type = struct {
        project_version_descriptions: ?[]struct {
            project_version_arn: ?[]const u8 = null,
            creation_timestamp: ?i64 = null,
            min_inference_units: ?i64 = null,
            status: ?[]const u8 = null,
            status_message: ?[]const u8 = null,
            billable_training_time_in_seconds: ?i64 = null,
            training_end_timestamp: ?i64 = null,
            output_config: ?OutputConfig = null,
            training_data_result: ?struct {
                input: ?TrainingData = null,
                output: ?TrainingData = null,
                validation: ?ValidationData = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .input = "Input",
                        .output = "Output",
                        .validation = "Validation",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            testing_data_result: ?struct {
                input: ?TestingData = null,
                output: ?TestingData = null,
                validation: ?ValidationData = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .input = "Input",
                        .output = "Output",
                        .validation = "Validation",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            evaluation_result: ?struct {
                f1_score: ?f32 = null,
                summary: ?struct {
                    s3_object: ?S3Object = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .s3_object = "S3Object",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .f1_score = "F1Score",
                        .summary = "Summary",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            manifest_summary: ?GroundTruthManifest = null,
            kms_key_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .project_version_arn = "ProjectVersionArn",
                    .creation_timestamp = "CreationTimestamp",
                    .min_inference_units = "MinInferenceUnits",
                    .status = "Status",
                    .status_message = "StatusMessage",
                    .billable_training_time_in_seconds = "BillableTrainingTimeInSeconds",
                    .training_end_timestamp = "TrainingEndTimestamp",
                    .output_config = "OutputConfig",
                    .training_data_result = "TrainingDataResult",
                    .testing_data_result = "TestingDataResult",
                    .evaluation_result = "EvaluationResult",
                    .manifest_summary = "ManifestSummary",
                    .kms_key_id = "KmsKeyId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_version_descriptions = "ProjectVersionDescriptions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidPaginationToken,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_stream_processor: struct {
    action_name: []const u8 = "DescribeStreamProcessor",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_stream_processor) } {
            return .{ .service_metadata = service_metadata, .action = describe_stream_processor };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        stream_processor_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,
        status_message: ?[]const u8 = null,
        creation_timestamp: ?i64 = null,
        last_update_timestamp: ?i64 = null,
        input: ?StreamProcessorInput = null,
        output: ?StreamProcessorOutput = null,
        role_arn: ?[]const u8 = null,
        settings: ?StreamProcessorSettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .stream_processor_arn = "StreamProcessorArn",
                .status = "Status",
                .status_message = "StatusMessage",
                .creation_timestamp = "CreationTimestamp",
                .last_update_timestamp = "LastUpdateTimestamp",
                .input = "Input",
                .output = "Output",
                .role_arn = "RoleArn",
                .settings = "Settings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const detect_custom_labels: struct {
    action_name: []const u8 = "DetectCustomLabels",
    Request: type = struct {
        project_version_arn: []const u8,
        image: Image,
        max_results: ?i64 = null,
        min_confidence: ?f32 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_version_arn = "ProjectVersionArn",
                .image = "Image",
                .max_results = "MaxResults",
                .min_confidence = "MinConfidence",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detect_custom_labels) } {
            return .{ .service_metadata = service_metadata, .action = detect_custom_labels };
        }
    },
    Response: type = struct {
        custom_labels: ?[]struct {
            name: ?[]const u8 = null,
            confidence: ?f32 = null,
            geometry: ?Geometry = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .confidence = "Confidence",
                    .geometry = "Geometry",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .custom_labels = "CustomLabels",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ImageTooLarge,
        InternalServerError,
        InvalidImageFormat,
        InvalidParameter,
        InvalidS3Object,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        ResourceNotReady,
        Throttling,
    },
} = .{};
pub const detect_faces: struct {
    action_name: []const u8 = "DetectFaces",
    Request: type = struct {
        image: Image,
        attributes: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image = "Image",
                .attributes = "Attributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detect_faces) } {
            return .{ .service_metadata = service_metadata, .action = detect_faces };
        }
    },
    Response: type = struct {
        face_details: ?[]FaceDetail = null,
        orientation_correction: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .face_details = "FaceDetails",
                .orientation_correction = "OrientationCorrection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ImageTooLarge,
        InternalServerError,
        InvalidImageFormat,
        InvalidParameter,
        InvalidS3Object,
        ProvisionedThroughputExceeded,
        Throttling,
    },
} = .{};
pub const detect_labels: struct {
    action_name: []const u8 = "DetectLabels",
    Request: type = struct {
        image: Image,
        max_labels: ?i64 = null,
        min_confidence: ?f32 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image = "Image",
                .max_labels = "MaxLabels",
                .min_confidence = "MinConfidence",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detect_labels) } {
            return .{ .service_metadata = service_metadata, .action = detect_labels };
        }
    },
    Response: type = struct {
        labels: ?[]Label = null,
        orientation_correction: ?[]const u8 = null,
        label_model_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .labels = "Labels",
                .orientation_correction = "OrientationCorrection",
                .label_model_version = "LabelModelVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ImageTooLarge,
        InternalServerError,
        InvalidImageFormat,
        InvalidParameter,
        InvalidS3Object,
        ProvisionedThroughputExceeded,
        Throttling,
    },
} = .{};
pub const detect_moderation_labels: struct {
    action_name: []const u8 = "DetectModerationLabels",
    Request: type = struct {
        image: Image,
        min_confidence: ?f32 = null,
        human_loop_config: ?struct {
            human_loop_name: []const u8,
            flow_definition_arn: []const u8,
            data_attributes: ?struct {
                content_classifiers: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .content_classifiers = "ContentClassifiers",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .human_loop_name = "HumanLoopName",
                    .flow_definition_arn = "FlowDefinitionArn",
                    .data_attributes = "DataAttributes",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image = "Image",
                .min_confidence = "MinConfidence",
                .human_loop_config = "HumanLoopConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detect_moderation_labels) } {
            return .{ .service_metadata = service_metadata, .action = detect_moderation_labels };
        }
    },
    Response: type = struct {
        moderation_labels: ?[]ModerationLabel = null,
        moderation_model_version: ?[]const u8 = null,
        human_loop_activation_output: ?struct {
            human_loop_arn: ?[]const u8 = null,
            human_loop_activation_reasons: ?[][]const u8 = null,
            human_loop_activation_conditions_evaluation_results: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .human_loop_arn = "HumanLoopArn",
                    .human_loop_activation_reasons = "HumanLoopActivationReasons",
                    .human_loop_activation_conditions_evaluation_results = "HumanLoopActivationConditionsEvaluationResults",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .moderation_labels = "ModerationLabels",
                .moderation_model_version = "ModerationModelVersion",
                .human_loop_activation_output = "HumanLoopActivationOutput",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        HumanLoopQuotaExceeded,
        ImageTooLarge,
        InternalServerError,
        InvalidImageFormat,
        InvalidParameter,
        InvalidS3Object,
        ProvisionedThroughputExceeded,
        Throttling,
    },
} = .{};
pub const detect_protective_equipment: struct {
    action_name: []const u8 = "DetectProtectiveEquipment",
    Request: type = struct {
        image: Image,
        summarization_attributes: ?struct {
            min_confidence: f32,
            required_equipment_types: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .min_confidence = "MinConfidence",
                    .required_equipment_types = "RequiredEquipmentTypes",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image = "Image",
                .summarization_attributes = "SummarizationAttributes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detect_protective_equipment) } {
            return .{ .service_metadata = service_metadata, .action = detect_protective_equipment };
        }
    },
    Response: type = struct {
        protective_equipment_model_version: ?[]const u8 = null,
        persons: ?[]struct {
            body_parts: ?[]struct {
                name: ?[]const u8 = null,
                confidence: ?f32 = null,
                equipment_detections: ?[]struct {
                    bounding_box: ?BoundingBox = null,
                    confidence: ?f32 = null,
                    type: ?[]const u8 = null,
                    covers_body_part: ?struct {
                        confidence: ?f32 = null,
                        value: ?bool = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .confidence = "Confidence",
                                .value = "Value",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .bounding_box = "BoundingBox",
                            .confidence = "Confidence",
                            .type = "Type",
                            .covers_body_part = "CoversBodyPart",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .confidence = "Confidence",
                        .equipment_detections = "EquipmentDetections",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            bounding_box: ?BoundingBox = null,
            confidence: ?f32 = null,
            id: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .body_parts = "BodyParts",
                    .bounding_box = "BoundingBox",
                    .confidence = "Confidence",
                    .id = "Id",
                };
                return @field(mappings, field_name);
            }
        } = null,
        summary: ?struct {
            persons_with_required_equipment: ?[]i64 = null,
            persons_without_required_equipment: ?[]i64 = null,
            persons_indeterminate: ?[]i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .persons_with_required_equipment = "PersonsWithRequiredEquipment",
                    .persons_without_required_equipment = "PersonsWithoutRequiredEquipment",
                    .persons_indeterminate = "PersonsIndeterminate",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .protective_equipment_model_version = "ProtectiveEquipmentModelVersion",
                .persons = "Persons",
                .summary = "Summary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ImageTooLarge,
        InternalServerError,
        InvalidImageFormat,
        InvalidParameter,
        InvalidS3Object,
        ProvisionedThroughputExceeded,
        Throttling,
    },
} = .{};
pub const detect_text: struct {
    action_name: []const u8 = "DetectText",
    Request: type = struct {
        image: Image,
        filters: ?struct {
            word_filter: ?DetectionFilter = null,
            regions_of_interest: ?[]RegionOfInterest = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .word_filter = "WordFilter",
                    .regions_of_interest = "RegionsOfInterest",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image = "Image",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detect_text) } {
            return .{ .service_metadata = service_metadata, .action = detect_text };
        }
    },
    Response: type = struct {
        text_detections: ?[]TextDetection = null,
        text_model_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .text_detections = "TextDetections",
                .text_model_version = "TextModelVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ImageTooLarge,
        InternalServerError,
        InvalidImageFormat,
        InvalidParameter,
        InvalidS3Object,
        ProvisionedThroughputExceeded,
        Throttling,
    },
} = .{};
pub const get_celebrity_info: struct {
    action_name: []const u8 = "GetCelebrityInfo",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_celebrity_info) } {
            return .{ .service_metadata = service_metadata, .action = get_celebrity_info };
        }
    },
    Response: type = struct {
        urls: ?[][]const u8 = null,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .urls = "Urls",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_celebrity_recognition: struct {
    action_name: []const u8 = "GetCelebrityRecognition",
    Request: type = struct {
        job_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .sort_by = "SortBy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_celebrity_recognition) } {
            return .{ .service_metadata = service_metadata, .action = get_celebrity_recognition };
        }
    },
    Response: type = struct {
        job_status: ?[]const u8 = null,
        status_message: ?[]const u8 = null,
        video_metadata: ?VideoMetadata = null,
        next_token: ?[]const u8 = null,
        celebrities: ?[]struct {
            timestamp: ?i64 = null,
            celebrity: ?struct {
                urls: ?[][]const u8 = null,
                name: ?[]const u8 = null,
                id: ?[]const u8 = null,
                confidence: ?f32 = null,
                bounding_box: ?BoundingBox = null,
                face: ?FaceDetail = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .urls = "Urls",
                        .name = "Name",
                        .id = "Id",
                        .confidence = "Confidence",
                        .bounding_box = "BoundingBox",
                        .face = "Face",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .timestamp = "Timestamp",
                    .celebrity = "Celebrity",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_status = "JobStatus",
                .status_message = "StatusMessage",
                .video_metadata = "VideoMetadata",
                .next_token = "NextToken",
                .celebrities = "Celebrities",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidPaginationToken,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_content_moderation: struct {
    action_name: []const u8 = "GetContentModeration",
    Request: type = struct {
        job_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .sort_by = "SortBy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_content_moderation) } {
            return .{ .service_metadata = service_metadata, .action = get_content_moderation };
        }
    },
    Response: type = struct {
        job_status: ?[]const u8 = null,
        status_message: ?[]const u8 = null,
        video_metadata: ?VideoMetadata = null,
        moderation_labels: ?[]struct {
            timestamp: ?i64 = null,
            moderation_label: ?ModerationLabel = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .timestamp = "Timestamp",
                    .moderation_label = "ModerationLabel",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        moderation_model_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_status = "JobStatus",
                .status_message = "StatusMessage",
                .video_metadata = "VideoMetadata",
                .moderation_labels = "ModerationLabels",
                .next_token = "NextToken",
                .moderation_model_version = "ModerationModelVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidPaginationToken,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_face_detection: struct {
    action_name: []const u8 = "GetFaceDetection",
    Request: type = struct {
        job_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_face_detection) } {
            return .{ .service_metadata = service_metadata, .action = get_face_detection };
        }
    },
    Response: type = struct {
        job_status: ?[]const u8 = null,
        status_message: ?[]const u8 = null,
        video_metadata: ?VideoMetadata = null,
        next_token: ?[]const u8 = null,
        faces: ?[]struct {
            timestamp: ?i64 = null,
            face: ?FaceDetail = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .timestamp = "Timestamp",
                    .face = "Face",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_status = "JobStatus",
                .status_message = "StatusMessage",
                .video_metadata = "VideoMetadata",
                .next_token = "NextToken",
                .faces = "Faces",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidPaginationToken,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_face_search: struct {
    action_name: []const u8 = "GetFaceSearch",
    Request: type = struct {
        job_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .sort_by = "SortBy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_face_search) } {
            return .{ .service_metadata = service_metadata, .action = get_face_search };
        }
    },
    Response: type = struct {
        job_status: ?[]const u8 = null,
        status_message: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        video_metadata: ?VideoMetadata = null,
        persons: ?[]struct {
            timestamp: ?i64 = null,
            person: ?PersonDetail = null,
            face_matches: ?[]FaceMatch = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .timestamp = "Timestamp",
                    .person = "Person",
                    .face_matches = "FaceMatches",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_status = "JobStatus",
                .status_message = "StatusMessage",
                .next_token = "NextToken",
                .video_metadata = "VideoMetadata",
                .persons = "Persons",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidPaginationToken,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_label_detection: struct {
    action_name: []const u8 = "GetLabelDetection",
    Request: type = struct {
        job_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .sort_by = "SortBy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_label_detection) } {
            return .{ .service_metadata = service_metadata, .action = get_label_detection };
        }
    },
    Response: type = struct {
        job_status: ?[]const u8 = null,
        status_message: ?[]const u8 = null,
        video_metadata: ?VideoMetadata = null,
        next_token: ?[]const u8 = null,
        labels: ?[]struct {
            timestamp: ?i64 = null,
            label: ?Label = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .timestamp = "Timestamp",
                    .label = "Label",
                };
                return @field(mappings, field_name);
            }
        } = null,
        label_model_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_status = "JobStatus",
                .status_message = "StatusMessage",
                .video_metadata = "VideoMetadata",
                .next_token = "NextToken",
                .labels = "Labels",
                .label_model_version = "LabelModelVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidPaginationToken,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_person_tracking: struct {
    action_name: []const u8 = "GetPersonTracking",
    Request: type = struct {
        job_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .sort_by = "SortBy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_person_tracking) } {
            return .{ .service_metadata = service_metadata, .action = get_person_tracking };
        }
    },
    Response: type = struct {
        job_status: ?[]const u8 = null,
        status_message: ?[]const u8 = null,
        video_metadata: ?VideoMetadata = null,
        next_token: ?[]const u8 = null,
        persons: ?[]struct {
            timestamp: ?i64 = null,
            person: ?PersonDetail = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .timestamp = "Timestamp",
                    .person = "Person",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_status = "JobStatus",
                .status_message = "StatusMessage",
                .video_metadata = "VideoMetadata",
                .next_token = "NextToken",
                .persons = "Persons",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidPaginationToken,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_segment_detection: struct {
    action_name: []const u8 = "GetSegmentDetection",
    Request: type = struct {
        job_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_segment_detection) } {
            return .{ .service_metadata = service_metadata, .action = get_segment_detection };
        }
    },
    Response: type = struct {
        job_status: ?[]const u8 = null,
        status_message: ?[]const u8 = null,
        video_metadata: ?[]VideoMetadata = null,
        audio_metadata: ?[]struct {
            codec: ?[]const u8 = null,
            duration_millis: ?i64 = null,
            sample_rate: ?i64 = null,
            number_of_channels: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .codec = "Codec",
                    .duration_millis = "DurationMillis",
                    .sample_rate = "SampleRate",
                    .number_of_channels = "NumberOfChannels",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        segments: ?[]struct {
            type: ?[]const u8 = null,
            start_timestamp_millis: ?i64 = null,
            end_timestamp_millis: ?i64 = null,
            duration_millis: ?i64 = null,
            start_timecode_smpte: ?[]const u8 = null,
            end_timecode_smpte: ?[]const u8 = null,
            duration_smpte: ?[]const u8 = null,
            technical_cue_segment: ?struct {
                type: ?[]const u8 = null,
                confidence: ?f32 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .type = "Type",
                        .confidence = "Confidence",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            shot_segment: ?struct {
                index: ?i64 = null,
                confidence: ?f32 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .index = "Index",
                        .confidence = "Confidence",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "Type",
                    .start_timestamp_millis = "StartTimestampMillis",
                    .end_timestamp_millis = "EndTimestampMillis",
                    .duration_millis = "DurationMillis",
                    .start_timecode_smpte = "StartTimecodeSMPTE",
                    .end_timecode_smpte = "EndTimecodeSMPTE",
                    .duration_smpte = "DurationSMPTE",
                    .technical_cue_segment = "TechnicalCueSegment",
                    .shot_segment = "ShotSegment",
                };
                return @field(mappings, field_name);
            }
        } = null,
        selected_segment_types: ?[]struct {
            type: ?[]const u8 = null,
            model_version: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .type = "Type",
                    .model_version = "ModelVersion",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_status = "JobStatus",
                .status_message = "StatusMessage",
                .video_metadata = "VideoMetadata",
                .audio_metadata = "AudioMetadata",
                .next_token = "NextToken",
                .segments = "Segments",
                .selected_segment_types = "SelectedSegmentTypes",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidPaginationToken,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_text_detection: struct {
    action_name: []const u8 = "GetTextDetection",
    Request: type = struct {
        job_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_text_detection) } {
            return .{ .service_metadata = service_metadata, .action = get_text_detection };
        }
    },
    Response: type = struct {
        job_status: ?[]const u8 = null,
        status_message: ?[]const u8 = null,
        video_metadata: ?VideoMetadata = null,
        text_detections: ?[]struct {
            timestamp: ?i64 = null,
            text_detection: ?TextDetection = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .timestamp = "Timestamp",
                    .text_detection = "TextDetection",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        text_model_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_status = "JobStatus",
                .status_message = "StatusMessage",
                .video_metadata = "VideoMetadata",
                .text_detections = "TextDetections",
                .next_token = "NextToken",
                .text_model_version = "TextModelVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidPaginationToken,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const index_faces: struct {
    action_name: []const u8 = "IndexFaces",
    Request: type = struct {
        collection_id: []const u8,
        image: Image,
        external_image_id: ?[]const u8 = null,
        detection_attributes: ?[][]const u8 = null,
        max_faces: ?i64 = null,
        quality_filter: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .collection_id = "CollectionId",
                .image = "Image",
                .external_image_id = "ExternalImageId",
                .detection_attributes = "DetectionAttributes",
                .max_faces = "MaxFaces",
                .quality_filter = "QualityFilter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(index_faces) } {
            return .{ .service_metadata = service_metadata, .action = index_faces };
        }
    },
    Response: type = struct {
        face_records: ?[]struct {
            face: ?Face = null,
            face_detail: ?FaceDetail = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .face = "Face",
                    .face_detail = "FaceDetail",
                };
                return @field(mappings, field_name);
            }
        } = null,
        orientation_correction: ?[]const u8 = null,
        face_model_version: ?[]const u8 = null,
        unindexed_faces: ?[]struct {
            reasons: ?[][]const u8 = null,
            face_detail: ?FaceDetail = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .reasons = "Reasons",
                    .face_detail = "FaceDetail",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .face_records = "FaceRecords",
                .orientation_correction = "OrientationCorrection",
                .face_model_version = "FaceModelVersion",
                .unindexed_faces = "UnindexedFaces",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ImageTooLarge,
        InternalServerError,
        InvalidImageFormat,
        InvalidParameter,
        InvalidS3Object,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const list_collections: struct {
    action_name: []const u8 = "ListCollections",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_collections) } {
            return .{ .service_metadata = service_metadata, .action = list_collections };
        }
    },
    Response: type = struct {
        collection_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        face_model_versions: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .collection_ids = "CollectionIds",
                .next_token = "NextToken",
                .face_model_versions = "FaceModelVersions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidPaginationToken,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_faces: struct {
    action_name: []const u8 = "ListFaces",
    Request: type = struct {
        collection_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .collection_id = "CollectionId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_faces) } {
            return .{ .service_metadata = service_metadata, .action = list_faces };
        }
    },
    Response: type = struct {
        faces: ?[]Face = null,
        next_token: ?[]const u8 = null,
        face_model_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .faces = "Faces",
                .next_token = "NextToken",
                .face_model_version = "FaceModelVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidPaginationToken,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_stream_processors: struct {
    action_name: []const u8 = "ListStreamProcessors",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_stream_processors) } {
            return .{ .service_metadata = service_metadata, .action = list_stream_processors };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        stream_processors: ?[]struct {
            name: ?[]const u8 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .stream_processors = "StreamProcessors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidPaginationToken,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        Throttling,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const recognize_celebrities: struct {
    action_name: []const u8 = "RecognizeCelebrities",
    Request: type = struct {
        image: Image,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image = "Image",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(recognize_celebrities) } {
            return .{ .service_metadata = service_metadata, .action = recognize_celebrities };
        }
    },
    Response: type = struct {
        celebrity_faces: ?[]struct {
            urls: ?[][]const u8 = null,
            name: ?[]const u8 = null,
            id: ?[]const u8 = null,
            face: ?ComparedFace = null,
            match_confidence: ?f32 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .urls = "Urls",
                    .name = "Name",
                    .id = "Id",
                    .face = "Face",
                    .match_confidence = "MatchConfidence",
                };
                return @field(mappings, field_name);
            }
        } = null,
        unrecognized_faces: ?[]ComparedFace = null,
        orientation_correction: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .celebrity_faces = "CelebrityFaces",
                .unrecognized_faces = "UnrecognizedFaces",
                .orientation_correction = "OrientationCorrection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ImageTooLarge,
        InternalServerError,
        InvalidImageFormat,
        InvalidParameter,
        InvalidS3Object,
        ProvisionedThroughputExceeded,
        Throttling,
    },
} = .{};
pub const search_faces: struct {
    action_name: []const u8 = "SearchFaces",
    Request: type = struct {
        collection_id: []const u8,
        face_id: []const u8,
        max_faces: ?i64 = null,
        face_match_threshold: ?f32 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .collection_id = "CollectionId",
                .face_id = "FaceId",
                .max_faces = "MaxFaces",
                .face_match_threshold = "FaceMatchThreshold",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_faces) } {
            return .{ .service_metadata = service_metadata, .action = search_faces };
        }
    },
    Response: type = struct {
        searched_face_id: ?[]const u8 = null,
        face_matches: ?[]FaceMatch = null,
        face_model_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .searched_face_id = "SearchedFaceId",
                .face_matches = "FaceMatches",
                .face_model_version = "FaceModelVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const search_faces_by_image: struct {
    action_name: []const u8 = "SearchFacesByImage",
    Request: type = struct {
        collection_id: []const u8,
        image: Image,
        max_faces: ?i64 = null,
        face_match_threshold: ?f32 = null,
        quality_filter: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .collection_id = "CollectionId",
                .image = "Image",
                .max_faces = "MaxFaces",
                .face_match_threshold = "FaceMatchThreshold",
                .quality_filter = "QualityFilter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_faces_by_image) } {
            return .{ .service_metadata = service_metadata, .action = search_faces_by_image };
        }
    },
    Response: type = struct {
        searched_face_bounding_box: ?BoundingBox = null,
        searched_face_confidence: ?f32 = null,
        face_matches: ?[]FaceMatch = null,
        face_model_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .searched_face_bounding_box = "SearchedFaceBoundingBox",
                .searched_face_confidence = "SearchedFaceConfidence",
                .face_matches = "FaceMatches",
                .face_model_version = "FaceModelVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ImageTooLarge,
        InternalServerError,
        InvalidImageFormat,
        InvalidParameter,
        InvalidS3Object,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const start_celebrity_recognition: struct {
    action_name: []const u8 = "StartCelebrityRecognition",
    Request: type = struct {
        video: Video,
        client_request_token: ?[]const u8 = null,
        notification_channel: ?NotificationChannel = null,
        job_tag: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .video = "Video",
                .client_request_token = "ClientRequestToken",
                .notification_channel = "NotificationChannel",
                .job_tag = "JobTag",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_celebrity_recognition) } {
            return .{ .service_metadata = service_metadata, .action = start_celebrity_recognition };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IdempotentParameterMismatch,
        InternalServerError,
        InvalidParameter,
        InvalidS3Object,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        Throttling,
        VideoTooLarge,
    },
} = .{};
pub const start_content_moderation: struct {
    action_name: []const u8 = "StartContentModeration",
    Request: type = struct {
        video: Video,
        min_confidence: ?f32 = null,
        client_request_token: ?[]const u8 = null,
        notification_channel: ?NotificationChannel = null,
        job_tag: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .video = "Video",
                .min_confidence = "MinConfidence",
                .client_request_token = "ClientRequestToken",
                .notification_channel = "NotificationChannel",
                .job_tag = "JobTag",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_content_moderation) } {
            return .{ .service_metadata = service_metadata, .action = start_content_moderation };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IdempotentParameterMismatch,
        InternalServerError,
        InvalidParameter,
        InvalidS3Object,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        Throttling,
        VideoTooLarge,
    },
} = .{};
pub const start_face_detection: struct {
    action_name: []const u8 = "StartFaceDetection",
    Request: type = struct {
        video: Video,
        client_request_token: ?[]const u8 = null,
        notification_channel: ?NotificationChannel = null,
        face_attributes: ?[]const u8 = null,
        job_tag: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .video = "Video",
                .client_request_token = "ClientRequestToken",
                .notification_channel = "NotificationChannel",
                .face_attributes = "FaceAttributes",
                .job_tag = "JobTag",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_face_detection) } {
            return .{ .service_metadata = service_metadata, .action = start_face_detection };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IdempotentParameterMismatch,
        InternalServerError,
        InvalidParameter,
        InvalidS3Object,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        Throttling,
        VideoTooLarge,
    },
} = .{};
pub const start_face_search: struct {
    action_name: []const u8 = "StartFaceSearch",
    Request: type = struct {
        video: Video,
        client_request_token: ?[]const u8 = null,
        face_match_threshold: ?f32 = null,
        collection_id: []const u8,
        notification_channel: ?NotificationChannel = null,
        job_tag: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .video = "Video",
                .client_request_token = "ClientRequestToken",
                .face_match_threshold = "FaceMatchThreshold",
                .collection_id = "CollectionId",
                .notification_channel = "NotificationChannel",
                .job_tag = "JobTag",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_face_search) } {
            return .{ .service_metadata = service_metadata, .action = start_face_search };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IdempotentParameterMismatch,
        InternalServerError,
        InvalidParameter,
        InvalidS3Object,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
        VideoTooLarge,
    },
} = .{};
pub const start_label_detection: struct {
    action_name: []const u8 = "StartLabelDetection",
    Request: type = struct {
        video: Video,
        client_request_token: ?[]const u8 = null,
        min_confidence: ?f32 = null,
        notification_channel: ?NotificationChannel = null,
        job_tag: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .video = "Video",
                .client_request_token = "ClientRequestToken",
                .min_confidence = "MinConfidence",
                .notification_channel = "NotificationChannel",
                .job_tag = "JobTag",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_label_detection) } {
            return .{ .service_metadata = service_metadata, .action = start_label_detection };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IdempotentParameterMismatch,
        InternalServerError,
        InvalidParameter,
        InvalidS3Object,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        Throttling,
        VideoTooLarge,
    },
} = .{};
pub const start_person_tracking: struct {
    action_name: []const u8 = "StartPersonTracking",
    Request: type = struct {
        video: Video,
        client_request_token: ?[]const u8 = null,
        notification_channel: ?NotificationChannel = null,
        job_tag: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .video = "Video",
                .client_request_token = "ClientRequestToken",
                .notification_channel = "NotificationChannel",
                .job_tag = "JobTag",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_person_tracking) } {
            return .{ .service_metadata = service_metadata, .action = start_person_tracking };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IdempotentParameterMismatch,
        InternalServerError,
        InvalidParameter,
        InvalidS3Object,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        Throttling,
        VideoTooLarge,
    },
} = .{};
pub const start_project_version: struct {
    action_name: []const u8 = "StartProjectVersion",
    Request: type = struct {
        project_version_arn: []const u8,
        min_inference_units: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_version_arn = "ProjectVersionArn",
                .min_inference_units = "MinInferenceUnits",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_project_version) } {
            return .{ .service_metadata = service_metadata, .action = start_project_version };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const start_segment_detection: struct {
    action_name: []const u8 = "StartSegmentDetection",
    Request: type = struct {
        video: Video,
        client_request_token: ?[]const u8 = null,
        notification_channel: ?NotificationChannel = null,
        job_tag: ?[]const u8 = null,
        filters: ?struct {
            technical_cue_filter: ?struct {
                min_segment_confidence: ?f32 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .min_segment_confidence = "MinSegmentConfidence",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            shot_filter: ?struct {
                min_segment_confidence: ?f32 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .min_segment_confidence = "MinSegmentConfidence",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .technical_cue_filter = "TechnicalCueFilter",
                    .shot_filter = "ShotFilter",
                };
                return @field(mappings, field_name);
            }
        } = null,
        segment_types: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .video = "Video",
                .client_request_token = "ClientRequestToken",
                .notification_channel = "NotificationChannel",
                .job_tag = "JobTag",
                .filters = "Filters",
                .segment_types = "SegmentTypes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_segment_detection) } {
            return .{ .service_metadata = service_metadata, .action = start_segment_detection };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IdempotentParameterMismatch,
        InternalServerError,
        InvalidParameter,
        InvalidS3Object,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        Throttling,
        VideoTooLarge,
    },
} = .{};
pub const start_stream_processor: struct {
    action_name: []const u8 = "StartStreamProcessor",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_stream_processor) } {
            return .{ .service_metadata = service_metadata, .action = start_stream_processor };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const start_text_detection: struct {
    action_name: []const u8 = "StartTextDetection",
    Request: type = struct {
        video: Video,
        client_request_token: ?[]const u8 = null,
        notification_channel: ?NotificationChannel = null,
        job_tag: ?[]const u8 = null,
        filters: ?struct {
            word_filter: ?DetectionFilter = null,
            regions_of_interest: ?[]RegionOfInterest = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .word_filter = "WordFilter",
                    .regions_of_interest = "RegionsOfInterest",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .video = "Video",
                .client_request_token = "ClientRequestToken",
                .notification_channel = "NotificationChannel",
                .job_tag = "JobTag",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_text_detection) } {
            return .{ .service_metadata = service_metadata, .action = start_text_detection };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        IdempotentParameterMismatch,
        InternalServerError,
        InvalidParameter,
        InvalidS3Object,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        Throttling,
        VideoTooLarge,
    },
} = .{};
pub const stop_project_version: struct {
    action_name: []const u8 = "StopProjectVersion",
    Request: type = struct {
        project_version_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_version_arn = "ProjectVersionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_project_version) } {
            return .{ .service_metadata = service_metadata, .action = stop_project_version };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const stop_stream_processor: struct {
    action_name: []const u8 = "StopStreamProcessor",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_stream_processor) } {
            return .{ .service_metadata = service_metadata, .action = stop_stream_processor };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidParameter,
        ProvisionedThroughputExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};

pub const RegionOfInterest = struct {
    bounding_box: ?BoundingBox = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bounding_box = "BoundingBox",
        };
        return @field(mappings, field_name);
    }
};

pub const BoundingBox = struct {
    width: ?f32 = null,
    height: ?f32 = null,
    left: ?f32 = null,
    top: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .width = "Width",
            .height = "Height",
            .left = "Left",
            .top = "Top",
        };
        return @field(mappings, field_name);
    }
};

pub const DetectionFilter = struct {
    min_confidence: ?f32 = null,
    min_bounding_box_height: ?f32 = null,
    min_bounding_box_width: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min_confidence = "MinConfidence",
            .min_bounding_box_height = "MinBoundingBoxHeight",
            .min_bounding_box_width = "MinBoundingBoxWidth",
        };
        return @field(mappings, field_name);
    }
};

pub const NotificationChannel = struct {
    sns_topic_arn: []const u8,
    role_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sns_topic_arn = "SNSTopicArn",
            .role_arn = "RoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const Video = struct {
    s3_object: ?S3Object = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_object = "S3Object",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Object = struct {
    bucket: ?[]const u8 = null,
    name: ?[]const u8 = null,
    version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .name = "Name",
            .version = "Version",
        };
        return @field(mappings, field_name);
    }
};

pub const FaceMatch = struct {
    similarity: ?f32 = null,
    face: ?Face = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .similarity = "Similarity",
            .face = "Face",
        };
        return @field(mappings, field_name);
    }
};

pub const Face = struct {
    face_id: ?[]const u8 = null,
    bounding_box: ?BoundingBox = null,
    image_id: ?[]const u8 = null,
    external_image_id: ?[]const u8 = null,
    confidence: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .face_id = "FaceId",
            .bounding_box = "BoundingBox",
            .image_id = "ImageId",
            .external_image_id = "ExternalImageId",
            .confidence = "Confidence",
        };
        return @field(mappings, field_name);
    }
};

pub const Image = struct {
    bytes: ?[]const u8 = null,
    s3_object: ?S3Object = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bytes = "Bytes",
            .s3_object = "S3Object",
        };
        return @field(mappings, field_name);
    }
};

pub const ComparedFace = struct {
    bounding_box: ?BoundingBox = null,
    confidence: ?f32 = null,
    landmarks: ?[]Landmark = null,
    pose: ?Pose = null,
    quality: ?ImageQuality = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bounding_box = "BoundingBox",
            .confidence = "Confidence",
            .landmarks = "Landmarks",
            .pose = "Pose",
            .quality = "Quality",
        };
        return @field(mappings, field_name);
    }
};

pub const ImageQuality = struct {
    brightness: ?f32 = null,
    sharpness: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .brightness = "Brightness",
            .sharpness = "Sharpness",
        };
        return @field(mappings, field_name);
    }
};

pub const Pose = struct {
    roll: ?f32 = null,
    yaw: ?f32 = null,
    pitch: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .roll = "Roll",
            .yaw = "Yaw",
            .pitch = "Pitch",
        };
        return @field(mappings, field_name);
    }
};

pub const Landmark = struct {
    type: ?[]const u8 = null,
    x: ?f32 = null,
    y: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .x = "X",
            .y = "Y",
        };
        return @field(mappings, field_name);
    }
};

pub const FaceDetail = struct {
    bounding_box: ?BoundingBox = null,
    age_range: ?AgeRange = null,
    smile: ?Smile = null,
    eyeglasses: ?Eyeglasses = null,
    sunglasses: ?Sunglasses = null,
    gender: ?Gender = null,
    beard: ?Beard = null,
    mustache: ?Mustache = null,
    eyes_open: ?EyeOpen = null,
    mouth_open: ?MouthOpen = null,
    emotions: ?[]Emotion = null,
    landmarks: ?[]Landmark = null,
    pose: ?Pose = null,
    quality: ?ImageQuality = null,
    confidence: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bounding_box = "BoundingBox",
            .age_range = "AgeRange",
            .smile = "Smile",
            .eyeglasses = "Eyeglasses",
            .sunglasses = "Sunglasses",
            .gender = "Gender",
            .beard = "Beard",
            .mustache = "Mustache",
            .eyes_open = "EyesOpen",
            .mouth_open = "MouthOpen",
            .emotions = "Emotions",
            .landmarks = "Landmarks",
            .pose = "Pose",
            .quality = "Quality",
            .confidence = "Confidence",
        };
        return @field(mappings, field_name);
    }
};

pub const Emotion = struct {
    type: ?[]const u8 = null,
    confidence: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .confidence = "Confidence",
        };
        return @field(mappings, field_name);
    }
};

pub const MouthOpen = struct {
    value: ?bool = null,
    confidence: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .confidence = "Confidence",
        };
        return @field(mappings, field_name);
    }
};

pub const EyeOpen = struct {
    value: ?bool = null,
    confidence: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .confidence = "Confidence",
        };
        return @field(mappings, field_name);
    }
};

pub const Mustache = struct {
    value: ?bool = null,
    confidence: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .confidence = "Confidence",
        };
        return @field(mappings, field_name);
    }
};

pub const Beard = struct {
    value: ?bool = null,
    confidence: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .confidence = "Confidence",
        };
        return @field(mappings, field_name);
    }
};

pub const Gender = struct {
    value: ?[]const u8 = null,
    confidence: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .confidence = "Confidence",
        };
        return @field(mappings, field_name);
    }
};

pub const Sunglasses = struct {
    value: ?bool = null,
    confidence: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .confidence = "Confidence",
        };
        return @field(mappings, field_name);
    }
};

pub const Eyeglasses = struct {
    value: ?bool = null,
    confidence: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .confidence = "Confidence",
        };
        return @field(mappings, field_name);
    }
};

pub const Smile = struct {
    value: ?bool = null,
    confidence: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "Value",
            .confidence = "Confidence",
        };
        return @field(mappings, field_name);
    }
};

pub const AgeRange = struct {
    low: ?i64 = null,
    high: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .low = "Low",
            .high = "High",
        };
        return @field(mappings, field_name);
    }
};

pub const TextDetection = struct {
    detected_text: ?[]const u8 = null,
    type: ?[]const u8 = null,
    id: ?i64 = null,
    parent_id: ?i64 = null,
    confidence: ?f32 = null,
    geometry: ?Geometry = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .detected_text = "DetectedText",
            .type = "Type",
            .id = "Id",
            .parent_id = "ParentId",
            .confidence = "Confidence",
            .geometry = "Geometry",
        };
        return @field(mappings, field_name);
    }
};

pub const Geometry = struct {
    bounding_box: ?BoundingBox = null,
    polygon: ?[]Point = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bounding_box = "BoundingBox",
            .polygon = "Polygon",
        };
        return @field(mappings, field_name);
    }
};

pub const Point = struct {
    x: ?f32 = null,
    y: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .x = "X",
            .y = "Y",
        };
        return @field(mappings, field_name);
    }
};

pub const VideoMetadata = struct {
    codec: ?[]const u8 = null,
    duration_millis: ?i64 = null,
    format: ?[]const u8 = null,
    frame_rate: ?f32 = null,
    frame_height: ?i64 = null,
    frame_width: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .codec = "Codec",
            .duration_millis = "DurationMillis",
            .format = "Format",
            .frame_rate = "FrameRate",
            .frame_height = "FrameHeight",
            .frame_width = "FrameWidth",
        };
        return @field(mappings, field_name);
    }
};

pub const PersonDetail = struct {
    index: ?i64 = null,
    bounding_box: ?BoundingBox = null,
    face: ?FaceDetail = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .index = "Index",
            .bounding_box = "BoundingBox",
            .face = "Face",
        };
        return @field(mappings, field_name);
    }
};

pub const Label = struct {
    name: ?[]const u8 = null,
    confidence: ?f32 = null,
    instances: ?[]Instance = null,
    parents: ?[]Parent = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .confidence = "Confidence",
            .instances = "Instances",
            .parents = "Parents",
        };
        return @field(mappings, field_name);
    }
};

pub const Parent = struct {
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const Instance = struct {
    bounding_box: ?BoundingBox = null,
    confidence: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bounding_box = "BoundingBox",
            .confidence = "Confidence",
        };
        return @field(mappings, field_name);
    }
};

pub const ModerationLabel = struct {
    confidence: ?f32 = null,
    name: ?[]const u8 = null,
    parent_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .confidence = "Confidence",
            .name = "Name",
            .parent_name = "ParentName",
        };
        return @field(mappings, field_name);
    }
};

pub const StreamProcessorSettings = struct {
    face_search: ?FaceSearchSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .face_search = "FaceSearch",
        };
        return @field(mappings, field_name);
    }
};

pub const FaceSearchSettings = struct {
    collection_id: ?[]const u8 = null,
    face_match_threshold: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .collection_id = "CollectionId",
            .face_match_threshold = "FaceMatchThreshold",
        };
        return @field(mappings, field_name);
    }
};

pub const StreamProcessorOutput = struct {
    kinesis_data_stream: ?KinesisDataStream = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kinesis_data_stream = "KinesisDataStream",
        };
        return @field(mappings, field_name);
    }
};

pub const KinesisDataStream = struct {
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
        };
        return @field(mappings, field_name);
    }
};

pub const StreamProcessorInput = struct {
    kinesis_video_stream: ?KinesisVideoStream = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kinesis_video_stream = "KinesisVideoStream",
        };
        return @field(mappings, field_name);
    }
};

pub const KinesisVideoStream = struct {
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
        };
        return @field(mappings, field_name);
    }
};

pub const GroundTruthManifest = struct {
    s3_object: ?S3Object = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_object = "S3Object",
        };
        return @field(mappings, field_name);
    }
};

pub const ValidationData = struct {
    assets: ?[]Asset = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .assets = "Assets",
        };
        return @field(mappings, field_name);
    }
};

pub const Asset = struct {
    ground_truth_manifest: ?GroundTruthManifest = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ground_truth_manifest = "GroundTruthManifest",
        };
        return @field(mappings, field_name);
    }
};

pub const TestingData = struct {
    assets: ?[]Asset = null,
    auto_create: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .assets = "Assets",
            .auto_create = "AutoCreate",
        };
        return @field(mappings, field_name);
    }
};

pub const TrainingData = struct {
    assets: ?[]Asset = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .assets = "Assets",
        };
        return @field(mappings, field_name);
    }
};

pub const OutputConfig = struct {
    s3_bucket: ?[]const u8 = null,
    s3_key_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket = "S3Bucket",
            .s3_key_prefix = "S3KeyPrefix",
        };
        return @field(mappings, field_name);
    }
};
