const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-08-20";
pub const sdk_id: []const u8 = "S3 Control";
pub const arn_namespace: []const u8 = "s3";
pub const endpoint_prefix: []const u8 = "s3-control";
pub const sigv4_name: []const u8 = "s3";
pub const name: []const u8 = "AWSS3ControlServiceV20180820";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_xml;

pub const service_metadata: struct {
    version: []const u8 = "2018-08-20",
    sdk_id: []const u8 = "S3 Control",
    arn_namespace: []const u8 = "s3",
    endpoint_prefix: []const u8 = "s3-control",
    sigv4_name: []const u8 = "s3",
    name: []const u8 = "AWSS3ControlServiceV20180820",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_xml,
} = .{};
pub const create_access_point: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v20180820/accesspoint/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateAccessPoint",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        bucket: []const u8,
        vpc_configuration: ?VpcConfiguration = null,
        public_access_block_configuration: ?PublicAccessBlockConfiguration = null,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
                .bucket = "Bucket",
                .vpc_configuration = "VpcConfiguration",
                .public_access_block_configuration = "PublicAccessBlockConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_access_point) } {
            return .{ .service_metadata = service_metadata, .action = create_access_point };
        }
    },
    Response: type = struct {
        access_point_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_point_arn = "AccessPointArn",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_access_point_for_object_lambda: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v20180820/accesspointforobjectlambda/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateAccessPointForObjectLambda",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        configuration: ObjectLambdaConfiguration,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
                .configuration = "Configuration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_access_point_for_object_lambda) } {
            return .{ .service_metadata = service_metadata, .action = create_access_point_for_object_lambda };
        }
    },
    Response: type = struct {
        object_lambda_access_point_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .object_lambda_access_point_arn = "ObjectLambdaAccessPointArn",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_bucket: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v20180820/bucket/{Bucket}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateBucket",
    Request: type = struct {
        acl: ?[]const u8 = null,
        bucket: []const u8,
        grant_full_control: ?[]const u8 = null,
        grant_read: ?[]const u8 = null,
        grant_read_acp: ?[]const u8 = null,
        grant_write: ?[]const u8 = null,
        grant_write_acp: ?[]const u8 = null,
        object_lock_enabled_for_bucket: ?bool = null,
        outpost_id: ?[]const u8 = null,
        create_bucket_configuration: ?struct {
            location_constraint: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .location_constraint = "LocationConstraint",
                };
                return @field(mappings, field_name);
            }
        } = null,
        pub const http_header = .{
            .acl = "x-amz-acl",
            .grant_full_control = "x-amz-grant-full-control",
            .grant_read = "x-amz-grant-read",
            .grant_read_acp = "x-amz-grant-read-acp",
            .grant_write = "x-amz-grant-write",
            .grant_write_acp = "x-amz-grant-write-acp",
            .object_lock_enabled_for_bucket = "x-amz-bucket-object-lock-enabled",
            .outpost_id = "x-amz-outpost-id",
        };

        pub const http_payload: []const u8 = "create_bucket_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .acl = "ACL",
                .bucket = "Bucket",
                .grant_full_control = "GrantFullControl",
                .grant_read = "GrantRead",
                .grant_read_acp = "GrantReadACP",
                .grant_write = "GrantWrite",
                .grant_write_acp = "GrantWriteACP",
                .object_lock_enabled_for_bucket = "ObjectLockEnabledForBucket",
                .outpost_id = "OutpostId",
                .create_bucket_configuration = "CreateBucketConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_bucket) } {
            return .{ .service_metadata = service_metadata, .action = create_bucket };
        }
    },
    Response: type = struct {
        location: ?[]const u8 = null,
        bucket_arn: ?[]const u8 = null,
        pub const http_header = .{
            .location = "Location",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .location = "Location",
                .bucket_arn = "BucketArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BucketAlreadyExists,
        BucketAlreadyOwnedByYou,
    },
} = .{};
pub const create_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v20180820/jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateJob",
    Request: type = struct {
        account_id: []const u8,
        confirmation_required: ?bool = null,
        operation: JobOperation,
        report: JobReport,
        client_request_token: []const u8,
        manifest: JobManifest,
        description: ?[]const u8 = null,
        priority: i64,
        role_arn: []const u8,
        tags: ?[]S3Tag = null,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .confirmation_required = "ConfirmationRequired",
                .operation = "Operation",
                .report = "Report",
                .client_request_token = "ClientRequestToken",
                .manifest = "Manifest",
                .description = "Description",
                .priority = "Priority",
                .role_arn = "RoleArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_job) } {
            return .{ .service_metadata = service_metadata, .action = create_job };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Idempotency,
        InternalService,
        TooManyRequests,
    },
} = .{};
pub const delete_access_point: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v20180820/accesspoint/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAccessPoint",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_access_point) } {
            return .{ .service_metadata = service_metadata, .action = delete_access_point };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_access_point_for_object_lambda: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v20180820/accesspointforobjectlambda/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAccessPointForObjectLambda",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_access_point_for_object_lambda) } {
            return .{ .service_metadata = service_metadata, .action = delete_access_point_for_object_lambda };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_access_point_policy: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v20180820/accesspoint/{Name}/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAccessPointPolicy",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_access_point_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_access_point_policy };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_access_point_policy_for_object_lambda: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v20180820/accesspointforobjectlambda/{Name}/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAccessPointPolicyForObjectLambda",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_access_point_policy_for_object_lambda) } {
            return .{ .service_metadata = service_metadata, .action = delete_access_point_policy_for_object_lambda };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_bucket: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v20180820/bucket/{Bucket}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteBucket",
    Request: type = struct {
        account_id: []const u8,
        bucket: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .bucket = "Bucket",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bucket) } {
            return .{ .service_metadata = service_metadata, .action = delete_bucket };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_bucket_lifecycle_configuration: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v20180820/bucket/{Bucket}/lifecycleconfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteBucketLifecycleConfiguration",
    Request: type = struct {
        account_id: []const u8,
        bucket: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .bucket = "Bucket",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bucket_lifecycle_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_bucket_lifecycle_configuration };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_bucket_policy: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v20180820/bucket/{Bucket}/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteBucketPolicy",
    Request: type = struct {
        account_id: []const u8,
        bucket: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .bucket = "Bucket",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bucket_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_bucket_policy };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_bucket_tagging: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v20180820/bucket/{Bucket}/tagging",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteBucketTagging",
    Request: type = struct {
        account_id: []const u8,
        bucket: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .bucket = "Bucket",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bucket_tagging) } {
            return .{ .service_metadata = service_metadata, .action = delete_bucket_tagging };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_job_tagging: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v20180820/jobs/{JobId}/tagging",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteJobTagging",
    Request: type = struct {
        account_id: []const u8,
        job_id: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_job_tagging) } {
            return .{ .service_metadata = service_metadata, .action = delete_job_tagging };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const delete_public_access_block: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v20180820/configuration/publicAccessBlock",
        .success_code = 200,
    };

    action_name: []const u8 = "DeletePublicAccessBlock",
    Request: type = struct {
        account_id: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_public_access_block) } {
            return .{ .service_metadata = service_metadata, .action = delete_public_access_block };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_storage_lens_configuration: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v20180820/storagelens/{ConfigId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteStorageLensConfiguration",
    Request: type = struct {
        config_id: []const u8,
        account_id: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .config_id = "ConfigId",
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_storage_lens_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_storage_lens_configuration };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_storage_lens_configuration_tagging: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v20180820/storagelens/{ConfigId}/tagging",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteStorageLensConfigurationTagging",
    Request: type = struct {
        config_id: []const u8,
        account_id: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .config_id = "ConfigId",
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_storage_lens_configuration_tagging) } {
            return .{ .service_metadata = service_metadata, .action = delete_storage_lens_configuration_tagging };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_job: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/jobs/{JobId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeJob",
    Request: type = struct {
        account_id: []const u8,
        job_id: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_job };
        }
    },
    Response: type = struct {
        job: ?struct {
            job_id: ?[]const u8 = null,
            confirmation_required: ?bool = null,
            description: ?[]const u8 = null,
            job_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            manifest: ?JobManifest = null,
            operation: ?JobOperation = null,
            priority: ?i64 = null,
            progress_summary: ?JobProgressSummary = null,
            status_update_reason: ?[]const u8 = null,
            failure_reasons: ?[]struct {
                failure_code: ?[]const u8 = null,
                failure_reason: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .failure_code = "FailureCode",
                        .failure_reason = "FailureReason",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            report: ?JobReport = null,
            creation_time: ?i64 = null,
            termination_date: ?i64 = null,
            role_arn: ?[]const u8 = null,
            suspended_date: ?i64 = null,
            suspended_cause: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_id = "JobId",
                    .confirmation_required = "ConfirmationRequired",
                    .description = "Description",
                    .job_arn = "JobArn",
                    .status = "Status",
                    .manifest = "Manifest",
                    .operation = "Operation",
                    .priority = "Priority",
                    .progress_summary = "ProgressSummary",
                    .status_update_reason = "StatusUpdateReason",
                    .failure_reasons = "FailureReasons",
                    .report = "Report",
                    .creation_time = "CreationTime",
                    .termination_date = "TerminationDate",
                    .role_arn = "RoleArn",
                    .suspended_date = "SuspendedDate",
                    .suspended_cause = "SuspendedCause",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job = "Job",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalService,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_access_point: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/accesspoint/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAccessPoint",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_access_point) } {
            return .{ .service_metadata = service_metadata, .action = get_access_point };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        bucket: ?[]const u8 = null,
        network_origin: ?[]const u8 = null,
        vpc_configuration: ?VpcConfiguration = null,
        public_access_block_configuration: ?PublicAccessBlockConfiguration = null,
        creation_date: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .bucket = "Bucket",
                .network_origin = "NetworkOrigin",
                .vpc_configuration = "VpcConfiguration",
                .public_access_block_configuration = "PublicAccessBlockConfiguration",
                .creation_date = "CreationDate",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_access_point_configuration_for_object_lambda: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/accesspointforobjectlambda/{Name}/configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAccessPointConfigurationForObjectLambda",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_access_point_configuration_for_object_lambda) } {
            return .{ .service_metadata = service_metadata, .action = get_access_point_configuration_for_object_lambda };
        }
    },
    Response: type = struct {
        configuration: ?ObjectLambdaConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configuration = "Configuration",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_access_point_for_object_lambda: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/accesspointforobjectlambda/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAccessPointForObjectLambda",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_access_point_for_object_lambda) } {
            return .{ .service_metadata = service_metadata, .action = get_access_point_for_object_lambda };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        public_access_block_configuration: ?PublicAccessBlockConfiguration = null,
        creation_date: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .public_access_block_configuration = "PublicAccessBlockConfiguration",
                .creation_date = "CreationDate",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_access_point_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/accesspoint/{Name}/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAccessPointPolicy",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_access_point_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_access_point_policy };
        }
    },
    Response: type = struct {
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_access_point_policy_for_object_lambda: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/accesspointforobjectlambda/{Name}/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAccessPointPolicyForObjectLambda",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_access_point_policy_for_object_lambda) } {
            return .{ .service_metadata = service_metadata, .action = get_access_point_policy_for_object_lambda };
        }
    },
    Response: type = struct {
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_access_point_policy_status: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/accesspoint/{Name}/policyStatus",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAccessPointPolicyStatus",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_access_point_policy_status) } {
            return .{ .service_metadata = service_metadata, .action = get_access_point_policy_status };
        }
    },
    Response: type = struct {
        policy_status: ?PolicyStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_status = "PolicyStatus",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_access_point_policy_status_for_object_lambda: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/accesspointforobjectlambda/{Name}/policyStatus",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAccessPointPolicyStatusForObjectLambda",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_access_point_policy_status_for_object_lambda) } {
            return .{ .service_metadata = service_metadata, .action = get_access_point_policy_status_for_object_lambda };
        }
    },
    Response: type = struct {
        policy_status: ?PolicyStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_status = "PolicyStatus",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_bucket: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/bucket/{Bucket}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBucket",
    Request: type = struct {
        account_id: []const u8,
        bucket: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .bucket = "Bucket",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bucket) } {
            return .{ .service_metadata = service_metadata, .action = get_bucket };
        }
    },
    Response: type = struct {
        bucket: ?[]const u8 = null,
        public_access_block_enabled: ?bool = null,
        creation_date: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bucket = "Bucket",
                .public_access_block_enabled = "PublicAccessBlockEnabled",
                .creation_date = "CreationDate",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_bucket_lifecycle_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/bucket/{Bucket}/lifecycleconfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBucketLifecycleConfiguration",
    Request: type = struct {
        account_id: []const u8,
        bucket: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .bucket = "Bucket",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bucket_lifecycle_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_bucket_lifecycle_configuration };
        }
    },
    Response: type = struct {
        rules: ?[]LifecycleRule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rules = "Rules",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_bucket_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/bucket/{Bucket}/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBucketPolicy",
    Request: type = struct {
        account_id: []const u8,
        bucket: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .bucket = "Bucket",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bucket_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_bucket_policy };
        }
    },
    Response: type = struct {
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_bucket_tagging: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/bucket/{Bucket}/tagging",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBucketTagging",
    Request: type = struct {
        account_id: []const u8,
        bucket: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .bucket = "Bucket",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bucket_tagging) } {
            return .{ .service_metadata = service_metadata, .action = get_bucket_tagging };
        }
    },
    Response: type = struct {
        tag_set: []S3Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tag_set = "TagSet",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_job_tagging: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/jobs/{JobId}/tagging",
        .success_code = 200,
    };

    action_name: []const u8 = "GetJobTagging",
    Request: type = struct {
        account_id: []const u8,
        job_id: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_job_tagging) } {
            return .{ .service_metadata = service_metadata, .action = get_job_tagging };
        }
    },
    Response: type = struct {
        tags: ?[]S3Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const get_public_access_block: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/configuration/publicAccessBlock",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPublicAccessBlock",
    Request: type = struct {
        account_id: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_public_access_block) } {
            return .{ .service_metadata = service_metadata, .action = get_public_access_block };
        }
    },
    Response: type = struct {
        public_access_block_configuration: ?PublicAccessBlockConfiguration = null,

        pub const http_payload: []const u8 = "public_access_block_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .public_access_block_configuration = "PublicAccessBlockConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        NoSuchPublicAccessBlockConfiguration,
    },
} = .{};
pub const get_storage_lens_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/storagelens/{ConfigId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetStorageLensConfiguration",
    Request: type = struct {
        config_id: []const u8,
        account_id: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .config_id = "ConfigId",
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_storage_lens_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_storage_lens_configuration };
        }
    },
    Response: type = struct {
        storage_lens_configuration: ?StorageLensConfiguration = null,

        pub const http_payload: []const u8 = "storage_lens_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .storage_lens_configuration = "StorageLensConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_storage_lens_configuration_tagging: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/storagelens/{ConfigId}/tagging",
        .success_code = 200,
    };

    action_name: []const u8 = "GetStorageLensConfigurationTagging",
    Request: type = struct {
        config_id: []const u8,
        account_id: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .config_id = "ConfigId",
                .account_id = "AccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_storage_lens_configuration_tagging) } {
            return .{ .service_metadata = service_metadata, .action = get_storage_lens_configuration_tagging };
        }
    },
    Response: type = struct {
        tags: ?[]StorageLensTag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_access_points: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/accesspoint",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAccessPoints",
    Request: type = struct {
        account_id: []const u8,
        bucket: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .bucket = "bucket",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .bucket = "Bucket",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_access_points) } {
            return .{ .service_metadata = service_metadata, .action = list_access_points };
        }
    },
    Response: type = struct {
        access_point_list: ?[]struct {
            name: []const u8,
            network_origin: []const u8,
            vpc_configuration: ?VpcConfiguration = null,
            bucket: []const u8,
            access_point_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .network_origin = "NetworkOrigin",
                    .vpc_configuration = "VpcConfiguration",
                    .bucket = "Bucket",
                    .access_point_arn = "AccessPointArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_point_list = "AccessPointList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_access_points_for_object_lambda: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/accesspointforobjectlambda",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAccessPointsForObjectLambda",
    Request: type = struct {
        account_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_access_points_for_object_lambda) } {
            return .{ .service_metadata = service_metadata, .action = list_access_points_for_object_lambda };
        }
    },
    Response: type = struct {
        object_lambda_access_point_list: ?[]struct {
            name: []const u8,
            object_lambda_access_point_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .object_lambda_access_point_arn = "ObjectLambdaAccessPointArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .object_lambda_access_point_list = "ObjectLambdaAccessPointList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_jobs: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/jobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListJobs",
    Request: type = struct {
        account_id: []const u8,
        job_statuses: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .job_statuses = "jobStatuses",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .job_statuses = "JobStatuses",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_jobs };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        jobs: ?[]struct {
            job_id: ?[]const u8 = null,
            description: ?[]const u8 = null,
            operation: ?[]const u8 = null,
            priority: ?i64 = null,
            status: ?[]const u8 = null,
            creation_time: ?i64 = null,
            termination_date: ?i64 = null,
            progress_summary: ?JobProgressSummary = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_id = "JobId",
                    .description = "Description",
                    .operation = "Operation",
                    .priority = "Priority",
                    .status = "Status",
                    .creation_time = "CreationTime",
                    .termination_date = "TerminationDate",
                    .progress_summary = "ProgressSummary",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .jobs = "Jobs",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidNextToken,
        InvalidRequest,
    },
} = .{};
pub const list_regional_buckets: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/bucket",
        .success_code = 200,
    };

    action_name: []const u8 = "ListRegionalBuckets",
    Request: type = struct {
        account_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        outpost_id: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub const http_header = .{
            .account_id = "x-amz-account-id",
            .outpost_id = "x-amz-outpost-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .outpost_id = "OutpostId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_regional_buckets) } {
            return .{ .service_metadata = service_metadata, .action = list_regional_buckets };
        }
    },
    Response: type = struct {
        regional_bucket_list: ?[]struct {
            bucket: []const u8,
            bucket_arn: ?[]const u8 = null,
            public_access_block_enabled: bool,
            creation_date: i64,
            outpost_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bucket = "Bucket",
                    .bucket_arn = "BucketArn",
                    .public_access_block_enabled = "PublicAccessBlockEnabled",
                    .creation_date = "CreationDate",
                    .outpost_id = "OutpostId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .regional_bucket_list = "RegionalBucketList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_storage_lens_configurations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v20180820/storagelens",
        .success_code = 200,
    };

    action_name: []const u8 = "ListStorageLensConfigurations",
    Request: type = struct {
        account_id: []const u8,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
        };

        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_storage_lens_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_storage_lens_configurations };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        storage_lens_configuration_list: ?[]struct {
            id: []const u8,
            storage_lens_arn: []const u8,
            home_region: []const u8,
            is_enabled: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .storage_lens_arn = "StorageLensArn",
                    .home_region = "HomeRegion",
                    .is_enabled = "IsEnabled",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .storage_lens_configuration_list = "StorageLensConfigurationList",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const put_access_point_configuration_for_object_lambda: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v20180820/accesspointforobjectlambda/{Name}/configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "PutAccessPointConfigurationForObjectLambda",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        configuration: ObjectLambdaConfiguration,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
                .configuration = "Configuration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_access_point_configuration_for_object_lambda) } {
            return .{ .service_metadata = service_metadata, .action = put_access_point_configuration_for_object_lambda };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_access_point_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v20180820/accesspoint/{Name}/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "PutAccessPointPolicy",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        policy: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_access_point_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_access_point_policy };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_access_point_policy_for_object_lambda: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v20180820/accesspointforobjectlambda/{Name}/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "PutAccessPointPolicyForObjectLambda",
    Request: type = struct {
        account_id: []const u8,
        name: []const u8,
        policy: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .name = "Name",
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_access_point_policy_for_object_lambda) } {
            return .{ .service_metadata = service_metadata, .action = put_access_point_policy_for_object_lambda };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_bucket_lifecycle_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v20180820/bucket/{Bucket}/lifecycleconfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "PutBucketLifecycleConfiguration",
    Request: type = struct {
        account_id: []const u8,
        bucket: []const u8,
        lifecycle_configuration: ?struct {
            rules: ?[]LifecycleRule = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .rules = "Rules",
                };
                return @field(mappings, field_name);
            }
        } = null,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub const http_payload: []const u8 = "lifecycle_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .bucket = "Bucket",
                .lifecycle_configuration = "LifecycleConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_bucket_lifecycle_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_bucket_lifecycle_configuration };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_bucket_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v20180820/bucket/{Bucket}/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "PutBucketPolicy",
    Request: type = struct {
        account_id: []const u8,
        bucket: []const u8,
        confirm_remove_self_bucket_access: ?bool = null,
        policy: []const u8,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
            .confirm_remove_self_bucket_access = "x-amz-confirm-remove-self-bucket-access",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .bucket = "Bucket",
                .confirm_remove_self_bucket_access = "ConfirmRemoveSelfBucketAccess",
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_bucket_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_bucket_policy };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_bucket_tagging: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v20180820/bucket/{Bucket}/tagging",
        .success_code = 200,
    };

    action_name: []const u8 = "PutBucketTagging",
    Request: type = struct {
        account_id: []const u8,
        bucket: []const u8,
        tagging: struct {
            tag_set: []S3Tag,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .tag_set = "TagSet",
                };
                return @field(mappings, field_name);
            }
        },
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub const http_payload: []const u8 = "tagging";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .bucket = "Bucket",
                .tagging = "Tagging",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_bucket_tagging) } {
            return .{ .service_metadata = service_metadata, .action = put_bucket_tagging };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_job_tagging: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v20180820/jobs/{JobId}/tagging",
        .success_code = 200,
    };

    action_name: []const u8 = "PutJobTagging",
    Request: type = struct {
        account_id: []const u8,
        job_id: []const u8,
        tags: []S3Tag,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .job_id = "JobId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_job_tagging) } {
            return .{ .service_metadata = service_metadata, .action = put_job_tagging };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        NotFound,
        TooManyRequests,
        TooManyTags,
    },
} = .{};
pub const put_public_access_block: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v20180820/configuration/publicAccessBlock",
        .success_code = 200,
    };

    action_name: []const u8 = "PutPublicAccessBlock",
    Request: type = struct {
        account_id: []const u8,
        public_access_block_configuration: PublicAccessBlockConfiguration,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub const http_payload: []const u8 = "public_access_block_configuration";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .public_access_block_configuration = "PublicAccessBlockConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_public_access_block) } {
            return .{ .service_metadata = service_metadata, .action = put_public_access_block };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_storage_lens_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v20180820/storagelens/{ConfigId}",
        .success_code = 200,
    };

    action_name: []const u8 = "PutStorageLensConfiguration",
    Request: type = struct {
        config_id: []const u8,
        account_id: []const u8,
        storage_lens_configuration: StorageLensConfiguration,
        tags: ?[]StorageLensTag = null,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .config_id = "ConfigId",
                .account_id = "AccountId",
                .storage_lens_configuration = "StorageLensConfiguration",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_storage_lens_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_storage_lens_configuration };
        }
    },
    Response: type = struct {},
} = .{};
pub const put_storage_lens_configuration_tagging: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v20180820/storagelens/{ConfigId}/tagging",
        .success_code = 200,
    };

    action_name: []const u8 = "PutStorageLensConfigurationTagging",
    Request: type = struct {
        config_id: []const u8,
        account_id: []const u8,
        tags: []StorageLensTag,
        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .config_id = "ConfigId",
                .account_id = "AccountId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_storage_lens_configuration_tagging) } {
            return .{ .service_metadata = service_metadata, .action = put_storage_lens_configuration_tagging };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const update_job_priority: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v20180820/jobs/{JobId}/priority",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateJobPriority",
    Request: type = struct {
        account_id: []const u8,
        job_id: []const u8,
        priority: i64,

        pub const http_query = .{
            .priority = "priority",
        };

        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .job_id = "JobId",
                .priority = "Priority",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_job_priority) } {
            return .{ .service_metadata = service_metadata, .action = update_job_priority };
        }
    },
    Response: type = struct {
        job_id: []const u8,
        priority: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .priority = "Priority",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalService,
        NotFound,
        TooManyRequests,
    },
} = .{};
pub const update_job_status: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v20180820/jobs/{JobId}/status",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateJobStatus",
    Request: type = struct {
        account_id: []const u8,
        job_id: []const u8,
        requested_job_status: []const u8,
        status_update_reason: ?[]const u8 = null,

        pub const http_query = .{
            .requested_job_status = "requestedJobStatus",
            .status_update_reason = "statusUpdateReason",
        };

        pub const http_header = .{
            .account_id = "x-amz-account-id",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_id = "AccountId",
                .job_id = "JobId",
                .requested_job_status = "RequestedJobStatus",
                .status_update_reason = "StatusUpdateReason",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_job_status) } {
            return .{ .service_metadata = service_metadata, .action = update_job_status };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,
        status: ?[]const u8 = null,
        status_update_reason: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .status = "Status",
                .status_update_reason = "StatusUpdateReason",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalService,
        JobStatus,
        NotFound,
        TooManyRequests,
    },
} = .{};

pub const StorageLensTag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const StorageLensConfiguration = struct {
    id: []const u8,
    account_level: AccountLevel,
    include: ?Include = null,
    exclude: ?Exclude = null,
    data_export: ?StorageLensDataExport = null,
    is_enabled: bool,
    aws_org: ?StorageLensAwsOrg = null,
    storage_lens_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .account_level = "AccountLevel",
            .include = "Include",
            .exclude = "Exclude",
            .data_export = "DataExport",
            .is_enabled = "IsEnabled",
            .aws_org = "AwsOrg",
            .storage_lens_arn = "StorageLensArn",
        };
        return @field(mappings, field_name);
    }
};

pub const StorageLensAwsOrg = struct {
    arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
        };
        return @field(mappings, field_name);
    }
};

pub const StorageLensDataExport = struct {
    s3_bucket_destination: S3BucketDestination,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket_destination = "S3BucketDestination",
        };
        return @field(mappings, field_name);
    }
};

pub const S3BucketDestination = struct {
    format: []const u8,
    output_schema_version: []const u8,
    account_id: []const u8,
    arn: []const u8,
    prefix: ?[]const u8 = null,
    encryption: ?StorageLensDataExportEncryption = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .format = "Format",
            .output_schema_version = "OutputSchemaVersion",
            .account_id = "AccountId",
            .arn = "Arn",
            .prefix = "Prefix",
            .encryption = "Encryption",
        };
        return @field(mappings, field_name);
    }
};

pub const StorageLensDataExportEncryption = struct {
    sses3: ?SSES3 = null,
    ssekms: ?SSEKMS = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sses3 = "SSE-S3",
            .ssekms = "SSE-KMS",
        };
        return @field(mappings, field_name);
    }
};

pub const SSEKMS = struct {
    key_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key_id = "KeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const SSES3 = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const Exclude = struct {
    buckets: ?[][]const u8 = null,
    regions: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .buckets = "Buckets",
            .regions = "Regions",
        };
        return @field(mappings, field_name);
    }
};

pub const Include = struct {
    buckets: ?[][]const u8 = null,
    regions: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .buckets = "Buckets",
            .regions = "Regions",
        };
        return @field(mappings, field_name);
    }
};

pub const AccountLevel = struct {
    activity_metrics: ?ActivityMetrics = null,
    bucket_level: BucketLevel,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .activity_metrics = "ActivityMetrics",
            .bucket_level = "BucketLevel",
        };
        return @field(mappings, field_name);
    }
};

pub const BucketLevel = struct {
    activity_metrics: ?ActivityMetrics = null,
    prefix_level: ?PrefixLevel = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .activity_metrics = "ActivityMetrics",
            .prefix_level = "PrefixLevel",
        };
        return @field(mappings, field_name);
    }
};

pub const PrefixLevel = struct {
    storage_metrics: PrefixLevelStorageMetrics,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .storage_metrics = "StorageMetrics",
        };
        return @field(mappings, field_name);
    }
};

pub const PrefixLevelStorageMetrics = struct {
    is_enabled: ?bool = null,
    selection_criteria: ?SelectionCriteria = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .is_enabled = "IsEnabled",
            .selection_criteria = "SelectionCriteria",
        };
        return @field(mappings, field_name);
    }
};

pub const SelectionCriteria = struct {
    delimiter: ?[]const u8 = null,
    max_depth: ?i64 = null,
    min_storage_bytes_percentage: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .delimiter = "Delimiter",
            .max_depth = "MaxDepth",
            .min_storage_bytes_percentage = "MinStorageBytesPercentage",
        };
        return @field(mappings, field_name);
    }
};

pub const ActivityMetrics = struct {
    is_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .is_enabled = "IsEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const PublicAccessBlockConfiguration = struct {
    block_public_acls: ?bool = null,
    ignore_public_acls: ?bool = null,
    block_public_policy: ?bool = null,
    restrict_public_buckets: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .block_public_acls = "BlockPublicAcls",
            .ignore_public_acls = "IgnorePublicAcls",
            .block_public_policy = "BlockPublicPolicy",
            .restrict_public_buckets = "RestrictPublicBuckets",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const LifecycleRule = struct {
    expiration: ?LifecycleExpiration = null,
    id: ?[]const u8 = null,
    filter: ?LifecycleRuleFilter = null,
    status: []const u8,
    transitions: ?[]Transition = null,
    noncurrent_version_transitions: ?[]NoncurrentVersionTransition = null,
    noncurrent_version_expiration: ?NoncurrentVersionExpiration = null,
    abort_incomplete_multipart_upload: ?AbortIncompleteMultipartUpload = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .expiration = "Expiration",
            .id = "ID",
            .filter = "Filter",
            .status = "Status",
            .transitions = "Transitions",
            .noncurrent_version_transitions = "NoncurrentVersionTransitions",
            .noncurrent_version_expiration = "NoncurrentVersionExpiration",
            .abort_incomplete_multipart_upload = "AbortIncompleteMultipartUpload",
        };
        return @field(mappings, field_name);
    }
};

pub const AbortIncompleteMultipartUpload = struct {
    days_after_initiation: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .days_after_initiation = "DaysAfterInitiation",
        };
        return @field(mappings, field_name);
    }
};

pub const NoncurrentVersionExpiration = struct {
    noncurrent_days: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .noncurrent_days = "NoncurrentDays",
        };
        return @field(mappings, field_name);
    }
};

pub const NoncurrentVersionTransition = struct {
    noncurrent_days: ?i64 = null,
    storage_class: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .noncurrent_days = "NoncurrentDays",
            .storage_class = "StorageClass",
        };
        return @field(mappings, field_name);
    }
};

pub const Transition = struct {
    date: ?i64 = null,
    days: ?i64 = null,
    storage_class: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .date = "Date",
            .days = "Days",
            .storage_class = "StorageClass",
        };
        return @field(mappings, field_name);
    }
};

pub const LifecycleRuleFilter = struct {
    prefix: ?[]const u8 = null,
    tag: ?S3Tag = null,
    @"and": ?LifecycleRuleAndOperator = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prefix = "Prefix",
            .tag = "Tag",
            .@"and" = "And",
        };
        return @field(mappings, field_name);
    }
};

pub const LifecycleRuleAndOperator = struct {
    prefix: ?[]const u8 = null,
    tags: ?[]S3Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prefix = "Prefix",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const LifecycleExpiration = struct {
    date: ?i64 = null,
    days: ?i64 = null,
    expired_object_delete_marker: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .date = "Date",
            .days = "Days",
            .expired_object_delete_marker = "ExpiredObjectDeleteMarker",
        };
        return @field(mappings, field_name);
    }
};

pub const ObjectLambdaConfiguration = struct {
    supporting_access_point: []const u8,
    cloud_watch_metrics_enabled: ?bool = null,
    allowed_features: ?[][]const u8 = null,
    transformation_configurations: []ObjectLambdaTransformationConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .supporting_access_point = "SupportingAccessPoint",
            .cloud_watch_metrics_enabled = "CloudWatchMetricsEnabled",
            .allowed_features = "AllowedFeatures",
            .transformation_configurations = "TransformationConfigurations",
        };
        return @field(mappings, field_name);
    }
};

pub const ObjectLambdaTransformationConfiguration = struct {
    actions: [][]const u8,
    content_transformation: ObjectLambdaContentTransformation,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .actions = "Actions",
            .content_transformation = "ContentTransformation",
        };
        return @field(mappings, field_name);
    }
};

pub const ObjectLambdaContentTransformation = union {
    aws_lambda: ?AwsLambdaTransformation,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .aws_lambda = "AwsLambda",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsLambdaTransformation = struct {
    function_arn: []const u8,
    function_payload: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .function_arn = "FunctionArn",
            .function_payload = "FunctionPayload",
        };
        return @field(mappings, field_name);
    }
};

pub const JobProgressSummary = struct {
    total_number_of_tasks: ?i64 = null,
    number_of_tasks_succeeded: ?i64 = null,
    number_of_tasks_failed: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .total_number_of_tasks = "TotalNumberOfTasks",
            .number_of_tasks_succeeded = "NumberOfTasksSucceeded",
            .number_of_tasks_failed = "NumberOfTasksFailed",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcConfiguration = struct {
    vpc_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_id = "VpcId",
        };
        return @field(mappings, field_name);
    }
};

pub const PolicyStatus = struct {
    is_public: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .is_public = "IsPublic",
        };
        return @field(mappings, field_name);
    }
};

pub const JobReport = struct {
    bucket: ?[]const u8 = null,
    format: ?[]const u8 = null,
    enabled: bool,
    prefix: ?[]const u8 = null,
    report_scope: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .format = "Format",
            .enabled = "Enabled",
            .prefix = "Prefix",
            .report_scope = "ReportScope",
        };
        return @field(mappings, field_name);
    }
};

pub const JobOperation = struct {
    lambda_invoke: ?LambdaInvokeOperation = null,
    s3_put_object_copy: ?S3CopyObjectOperation = null,
    s3_put_object_acl: ?S3SetObjectAclOperation = null,
    s3_put_object_tagging: ?S3SetObjectTaggingOperation = null,
    s3_delete_object_tagging: ?S3DeleteObjectTaggingOperation = null,
    s3_initiate_restore_object: ?S3InitiateRestoreObjectOperation = null,
    s3_put_object_legal_hold: ?S3SetObjectLegalHoldOperation = null,
    s3_put_object_retention: ?S3SetObjectRetentionOperation = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lambda_invoke = "LambdaInvoke",
            .s3_put_object_copy = "S3PutObjectCopy",
            .s3_put_object_acl = "S3PutObjectAcl",
            .s3_put_object_tagging = "S3PutObjectTagging",
            .s3_delete_object_tagging = "S3DeleteObjectTagging",
            .s3_initiate_restore_object = "S3InitiateRestoreObject",
            .s3_put_object_legal_hold = "S3PutObjectLegalHold",
            .s3_put_object_retention = "S3PutObjectRetention",
        };
        return @field(mappings, field_name);
    }
};

pub const S3SetObjectRetentionOperation = struct {
    bypass_governance_retention: ?bool = null,
    retention: S3Retention,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bypass_governance_retention = "BypassGovernanceRetention",
            .retention = "Retention",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Retention = struct {
    retain_until_date: ?i64 = null,
    mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .retain_until_date = "RetainUntilDate",
            .mode = "Mode",
        };
        return @field(mappings, field_name);
    }
};

pub const S3SetObjectLegalHoldOperation = struct {
    legal_hold: S3ObjectLockLegalHold,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .legal_hold = "LegalHold",
        };
        return @field(mappings, field_name);
    }
};

pub const S3ObjectLockLegalHold = struct {
    status: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const S3InitiateRestoreObjectOperation = struct {
    expiration_in_days: ?i64 = null,
    glacier_job_tier: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .expiration_in_days = "ExpirationInDays",
            .glacier_job_tier = "GlacierJobTier",
        };
        return @field(mappings, field_name);
    }
};

pub const S3DeleteObjectTaggingOperation = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const S3SetObjectTaggingOperation = struct {
    tag_set: ?[]S3Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tag_set = "TagSet",
        };
        return @field(mappings, field_name);
    }
};

pub const S3SetObjectAclOperation = struct {
    access_control_policy: ?S3AccessControlPolicy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .access_control_policy = "AccessControlPolicy",
        };
        return @field(mappings, field_name);
    }
};

pub const S3AccessControlPolicy = struct {
    access_control_list: ?S3AccessControlList = null,
    canned_access_control_list: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .access_control_list = "AccessControlList",
            .canned_access_control_list = "CannedAccessControlList",
        };
        return @field(mappings, field_name);
    }
};

pub const S3AccessControlList = struct {
    owner: S3ObjectOwner,
    grants: ?[]S3Grant = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .owner = "Owner",
            .grants = "Grants",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Grant = struct {
    grantee: ?S3Grantee = null,
    permission: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .grantee = "Grantee",
            .permission = "Permission",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Grantee = struct {
    type_identifier: ?[]const u8 = null,
    identifier: ?[]const u8 = null,
    display_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type_identifier = "TypeIdentifier",
            .identifier = "Identifier",
            .display_name = "DisplayName",
        };
        return @field(mappings, field_name);
    }
};

pub const S3ObjectOwner = struct {
    id: ?[]const u8 = null,
    display_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "ID",
            .display_name = "DisplayName",
        };
        return @field(mappings, field_name);
    }
};

pub const S3CopyObjectOperation = struct {
    target_resource: ?[]const u8 = null,
    canned_access_control_list: ?[]const u8 = null,
    access_control_grants: ?[]S3Grant = null,
    metadata_directive: ?[]const u8 = null,
    modified_since_constraint: ?i64 = null,
    new_object_metadata: ?S3ObjectMetadata = null,
    new_object_tagging: ?[]S3Tag = null,
    redirect_location: ?[]const u8 = null,
    requester_pays: ?bool = null,
    storage_class: ?[]const u8 = null,
    un_modified_since_constraint: ?i64 = null,
    sse_aws_kms_key_id: ?[]const u8 = null,
    target_key_prefix: ?[]const u8 = null,
    object_lock_legal_hold_status: ?[]const u8 = null,
    object_lock_mode: ?[]const u8 = null,
    object_lock_retain_until_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_resource = "TargetResource",
            .canned_access_control_list = "CannedAccessControlList",
            .access_control_grants = "AccessControlGrants",
            .metadata_directive = "MetadataDirective",
            .modified_since_constraint = "ModifiedSinceConstraint",
            .new_object_metadata = "NewObjectMetadata",
            .new_object_tagging = "NewObjectTagging",
            .redirect_location = "RedirectLocation",
            .requester_pays = "RequesterPays",
            .storage_class = "StorageClass",
            .un_modified_since_constraint = "UnModifiedSinceConstraint",
            .sse_aws_kms_key_id = "SSEAwsKmsKeyId",
            .target_key_prefix = "TargetKeyPrefix",
            .object_lock_legal_hold_status = "ObjectLockLegalHoldStatus",
            .object_lock_mode = "ObjectLockMode",
            .object_lock_retain_until_date = "ObjectLockRetainUntilDate",
        };
        return @field(mappings, field_name);
    }
};

pub const S3ObjectMetadata = struct {
    cache_control: ?[]const u8 = null,
    content_disposition: ?[]const u8 = null,
    content_encoding: ?[]const u8 = null,
    content_language: ?[]const u8 = null,
    user_metadata: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    content_length: ?i64 = null,
    content_md5: ?[]const u8 = null,
    content_type: ?[]const u8 = null,
    http_expires_date: ?i64 = null,
    requester_charged: ?bool = null,
    sse_algorithm: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cache_control = "CacheControl",
            .content_disposition = "ContentDisposition",
            .content_encoding = "ContentEncoding",
            .content_language = "ContentLanguage",
            .user_metadata = "UserMetadata",
            .content_length = "ContentLength",
            .content_md5 = "ContentMD5",
            .content_type = "ContentType",
            .http_expires_date = "HttpExpiresDate",
            .requester_charged = "RequesterCharged",
            .sse_algorithm = "SSEAlgorithm",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "user_metadata", field_name))
            return try serializeMap(self.user_metadata, self.fieldNameFor("user_metadata"), options, out_stream);
        return false;
    }
};

pub const LambdaInvokeOperation = struct {
    function_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .function_arn = "FunctionArn",
        };
        return @field(mappings, field_name);
    }
};

pub const JobManifest = struct {
    spec: JobManifestSpec,
    location: JobManifestLocation,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .spec = "Spec",
            .location = "Location",
        };
        return @field(mappings, field_name);
    }
};

pub const JobManifestLocation = struct {
    object_arn: []const u8,
    object_version_id: ?[]const u8 = null,
    e_tag: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .object_arn = "ObjectArn",
            .object_version_id = "ObjectVersionId",
            .e_tag = "ETag",
        };
        return @field(mappings, field_name);
    }
};

pub const JobManifestSpec = struct {
    format: []const u8,
    fields: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .format = "Format",
            .fields = "Fields",
        };
        return @field(mappings, field_name);
    }
};
