const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-07-01";
pub const sdk_id: []const u8 = "SageMaker FeatureStore Runtime";
pub const arn_namespace: []const u8 = "sagemaker";
pub const endpoint_prefix: []const u8 = "featurestore-runtime.sagemaker";
pub const sigv4_name: []const u8 = "sagemaker";
pub const name: []const u8 = "AmazonSageMakerFeatureStoreRuntime";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-07-01",
    sdk_id: []const u8 = "SageMaker FeatureStore Runtime",
    arn_namespace: []const u8 = "sagemaker",
    endpoint_prefix: []const u8 = "featurestore-runtime.sagemaker",
    sigv4_name: []const u8 = "sagemaker",
    name: []const u8 = "AmazonSageMakerFeatureStoreRuntime",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const delete_record: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/FeatureGroup/{FeatureGroupName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteRecord",
    Request: type = struct {
        feature_group_name: []const u8,
        record_identifier_value_as_string: []const u8,
        event_time: []const u8,

        pub const http_query = .{
            .record_identifier_value_as_string = "RecordIdentifierValueAsString",
            .event_time = "EventTime",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .feature_group_name = "FeatureGroupName",
                .record_identifier_value_as_string = "RecordIdentifierValueAsString",
                .event_time = "EventTime",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_record) } {
            return .{ .service_metadata = service_metadata, .action = delete_record };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessForbidden,
        InternalFailure,
        ServiceUnavailable,
        ValidationError,
    },
} = .{};
pub const get_record: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/FeatureGroup/{FeatureGroupName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetRecord",
    Request: type = struct {
        feature_group_name: []const u8,
        record_identifier_value_as_string: []const u8,
        feature_names: ?[][]const u8 = null,

        pub const http_query = .{
            .record_identifier_value_as_string = "RecordIdentifierValueAsString",
            .feature_names = "FeatureName",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .feature_group_name = "FeatureGroupName",
                .record_identifier_value_as_string = "RecordIdentifierValueAsString",
                .feature_names = "FeatureNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_record) } {
            return .{ .service_metadata = service_metadata, .action = get_record };
        }
    },
    Response: type = struct {
        record: ?[]FeatureValue = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .record = "Record",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessForbidden,
        InternalFailure,
        ResourceNotFound,
        ServiceUnavailable,
        ValidationError,
    },
} = .{};
pub const put_record: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/FeatureGroup/{FeatureGroupName}",
        .success_code = 200,
    };

    action_name: []const u8 = "PutRecord",
    Request: type = struct {
        feature_group_name: []const u8,
        record: []FeatureValue,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .feature_group_name = "FeatureGroupName",
                .record = "Record",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_record) } {
            return .{ .service_metadata = service_metadata, .action = put_record };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessForbidden,
        InternalFailure,
        ServiceUnavailable,
        ValidationError,
    },
} = .{};

pub const FeatureValue = struct {
    feature_name: []const u8,
    value_as_string: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .feature_name = "FeatureName",
            .value_as_string = "ValueAsString",
        };
        return @field(mappings, field_name);
    }
};
