const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-06-27";
pub const sdk_id: []const u8 = "Textract";
pub const arn_namespace: []const u8 = "textract";
pub const endpoint_prefix: []const u8 = "textract";
pub const sigv4_name: []const u8 = "textract";
pub const name: []const u8 = "Textract";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-06-27",
    sdk_id: []const u8 = "Textract",
    arn_namespace: []const u8 = "textract",
    endpoint_prefix: []const u8 = "textract",
    sigv4_name: []const u8 = "textract",
    name: []const u8 = "Textract",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const analyze_document: struct {
    action_name: []const u8 = "AnalyzeDocument",
    Request: type = struct {
        document: Document,
        feature_types: [][]const u8,
        human_loop_config: ?struct {
            human_loop_name: []const u8,
            flow_definition_arn: []const u8,
            data_attributes: ?struct {
                content_classifiers: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .content_classifiers = "ContentClassifiers",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .human_loop_name = "HumanLoopName",
                    .flow_definition_arn = "FlowDefinitionArn",
                    .data_attributes = "DataAttributes",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document = "Document",
                .feature_types = "FeatureTypes",
                .human_loop_config = "HumanLoopConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(analyze_document) } {
            return .{ .service_metadata = service_metadata, .action = analyze_document };
        }
    },
    Response: type = struct {
        document_metadata: ?DocumentMetadata = null,
        blocks: ?[]Block = null,
        human_loop_activation_output: ?struct {
            human_loop_arn: ?[]const u8 = null,
            human_loop_activation_reasons: ?[][]const u8 = null,
            human_loop_activation_conditions_evaluation_results: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .human_loop_arn = "HumanLoopArn",
                    .human_loop_activation_reasons = "HumanLoopActivationReasons",
                    .human_loop_activation_conditions_evaluation_results = "HumanLoopActivationConditionsEvaluationResults",
                };
                return @field(mappings, field_name);
            }
        } = null,
        analyze_document_model_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document_metadata = "DocumentMetadata",
                .blocks = "Blocks",
                .human_loop_activation_output = "HumanLoopActivationOutput",
                .analyze_document_model_version = "AnalyzeDocumentModelVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadDocument,
        DocumentTooLarge,
        HumanLoopQuotaExceeded,
        InternalServerError,
        InvalidParameter,
        InvalidS3Object,
        ProvisionedThroughputExceeded,
        Throttling,
        UnsupportedDocument,
    },
} = .{};
pub const detect_document_text: struct {
    action_name: []const u8 = "DetectDocumentText",
    Request: type = struct {
        document: Document,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document = "Document",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(detect_document_text) } {
            return .{ .service_metadata = service_metadata, .action = detect_document_text };
        }
    },
    Response: type = struct {
        document_metadata: ?DocumentMetadata = null,
        blocks: ?[]Block = null,
        detect_document_text_model_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document_metadata = "DocumentMetadata",
                .blocks = "Blocks",
                .detect_document_text_model_version = "DetectDocumentTextModelVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadDocument,
        DocumentTooLarge,
        InternalServerError,
        InvalidParameter,
        InvalidS3Object,
        ProvisionedThroughputExceeded,
        Throttling,
        UnsupportedDocument,
    },
} = .{};
pub const get_document_analysis: struct {
    action_name: []const u8 = "GetDocumentAnalysis",
    Request: type = struct {
        job_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_document_analysis) } {
            return .{ .service_metadata = service_metadata, .action = get_document_analysis };
        }
    },
    Response: type = struct {
        document_metadata: ?DocumentMetadata = null,
        job_status: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        blocks: ?[]Block = null,
        warnings: ?[]Warning = null,
        status_message: ?[]const u8 = null,
        analyze_document_model_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document_metadata = "DocumentMetadata",
                .job_status = "JobStatus",
                .next_token = "NextToken",
                .blocks = "Blocks",
                .warnings = "Warnings",
                .status_message = "StatusMessage",
                .analyze_document_model_version = "AnalyzeDocumentModelVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidJobId,
        InvalidParameter,
        InvalidS3Object,
        ProvisionedThroughputExceeded,
        Throttling,
    },
} = .{};
pub const get_document_text_detection: struct {
    action_name: []const u8 = "GetDocumentTextDetection",
    Request: type = struct {
        job_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_document_text_detection) } {
            return .{ .service_metadata = service_metadata, .action = get_document_text_detection };
        }
    },
    Response: type = struct {
        document_metadata: ?DocumentMetadata = null,
        job_status: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        blocks: ?[]Block = null,
        warnings: ?[]Warning = null,
        status_message: ?[]const u8 = null,
        detect_document_text_model_version: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document_metadata = "DocumentMetadata",
                .job_status = "JobStatus",
                .next_token = "NextToken",
                .blocks = "Blocks",
                .warnings = "Warnings",
                .status_message = "StatusMessage",
                .detect_document_text_model_version = "DetectDocumentTextModelVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServerError,
        InvalidJobId,
        InvalidParameter,
        InvalidS3Object,
        ProvisionedThroughputExceeded,
        Throttling,
    },
} = .{};
pub const start_document_analysis: struct {
    action_name: []const u8 = "StartDocumentAnalysis",
    Request: type = struct {
        document_location: DocumentLocation,
        feature_types: [][]const u8,
        client_request_token: ?[]const u8 = null,
        job_tag: ?[]const u8 = null,
        notification_channel: ?NotificationChannel = null,
        output_config: ?OutputConfig = null,
        kms_key_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document_location = "DocumentLocation",
                .feature_types = "FeatureTypes",
                .client_request_token = "ClientRequestToken",
                .job_tag = "JobTag",
                .notification_channel = "NotificationChannel",
                .output_config = "OutputConfig",
                .kms_key_id = "KMSKeyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_document_analysis) } {
            return .{ .service_metadata = service_metadata, .action = start_document_analysis };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadDocument,
        DocumentTooLarge,
        IdempotentParameterMismatch,
        InternalServerError,
        InvalidKMSKey,
        InvalidParameter,
        InvalidS3Object,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        Throttling,
        UnsupportedDocument,
    },
} = .{};
pub const start_document_text_detection: struct {
    action_name: []const u8 = "StartDocumentTextDetection",
    Request: type = struct {
        document_location: DocumentLocation,
        client_request_token: ?[]const u8 = null,
        job_tag: ?[]const u8 = null,
        notification_channel: ?NotificationChannel = null,
        output_config: ?OutputConfig = null,
        kms_key_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .document_location = "DocumentLocation",
                .client_request_token = "ClientRequestToken",
                .job_tag = "JobTag",
                .notification_channel = "NotificationChannel",
                .output_config = "OutputConfig",
                .kms_key_id = "KMSKeyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_document_text_detection) } {
            return .{ .service_metadata = service_metadata, .action = start_document_text_detection };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadDocument,
        DocumentTooLarge,
        IdempotentParameterMismatch,
        InternalServerError,
        InvalidKMSKey,
        InvalidParameter,
        InvalidS3Object,
        LimitExceeded,
        ProvisionedThroughputExceeded,
        Throttling,
        UnsupportedDocument,
    },
} = .{};

pub const OutputConfig = struct {
    s3_bucket: []const u8,
    s3_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket = "S3Bucket",
            .s3_prefix = "S3Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const NotificationChannel = struct {
    sns_topic_arn: []const u8,
    role_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sns_topic_arn = "SNSTopicArn",
            .role_arn = "RoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const DocumentLocation = struct {
    s3_object: ?S3Object = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_object = "S3Object",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Object = struct {
    bucket: ?[]const u8 = null,
    name: ?[]const u8 = null,
    version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .name = "Name",
            .version = "Version",
        };
        return @field(mappings, field_name);
    }
};

pub const Warning = struct {
    error_code: ?[]const u8 = null,
    pages: ?[]i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_code = "ErrorCode",
            .pages = "Pages",
        };
        return @field(mappings, field_name);
    }
};

pub const Block = struct {
    block_type: ?[]const u8 = null,
    confidence: ?f32 = null,
    text: ?[]const u8 = null,
    text_type: ?[]const u8 = null,
    row_index: ?i64 = null,
    column_index: ?i64 = null,
    row_span: ?i64 = null,
    column_span: ?i64 = null,
    geometry: ?Geometry = null,
    id: ?[]const u8 = null,
    relationships: ?[]Relationship = null,
    entity_types: ?[][]const u8 = null,
    selection_status: ?[]const u8 = null,
    page: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .block_type = "BlockType",
            .confidence = "Confidence",
            .text = "Text",
            .text_type = "TextType",
            .row_index = "RowIndex",
            .column_index = "ColumnIndex",
            .row_span = "RowSpan",
            .column_span = "ColumnSpan",
            .geometry = "Geometry",
            .id = "Id",
            .relationships = "Relationships",
            .entity_types = "EntityTypes",
            .selection_status = "SelectionStatus",
            .page = "Page",
        };
        return @field(mappings, field_name);
    }
};

pub const Relationship = struct {
    type: ?[]const u8 = null,
    ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .ids = "Ids",
        };
        return @field(mappings, field_name);
    }
};

pub const Geometry = struct {
    bounding_box: ?BoundingBox = null,
    polygon: ?[]Point = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bounding_box = "BoundingBox",
            .polygon = "Polygon",
        };
        return @field(mappings, field_name);
    }
};

pub const Point = struct {
    x: ?f32 = null,
    y: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .x = "X",
            .y = "Y",
        };
        return @field(mappings, field_name);
    }
};

pub const BoundingBox = struct {
    width: ?f32 = null,
    height: ?f32 = null,
    left: ?f32 = null,
    top: ?f32 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .width = "Width",
            .height = "Height",
            .left = "Left",
            .top = "Top",
        };
        return @field(mappings, field_name);
    }
};

pub const DocumentMetadata = struct {
    pages: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pages = "Pages",
        };
        return @field(mappings, field_name);
    }
};

pub const Document = struct {
    bytes: ?[]const u8 = null,
    s3_object: ?S3Object = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bytes = "Bytes",
            .s3_object = "S3Object",
        };
        return @field(mappings, field_name);
    }
};
