const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2019-07-29";
pub const sdk_id: []const u8 = "WAFV2";
pub const arn_namespace: []const u8 = "wafv2";
pub const endpoint_prefix: []const u8 = "wafv2";
pub const sigv4_name: []const u8 = "wafv2";
pub const name: []const u8 = "AWSWAF_20190729";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2019-07-29",
    sdk_id: []const u8 = "WAFV2",
    arn_namespace: []const u8 = "wafv2",
    endpoint_prefix: []const u8 = "wafv2",
    sigv4_name: []const u8 = "wafv2",
    name: []const u8 = "AWSWAF_20190729",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const associate_web_acl: struct {
    action_name: []const u8 = "AssociateWebACL",
    Request: type = struct {
        web_acl_arn: []const u8,
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .web_acl_arn = "WebACLArn",
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_web_acl) } {
            return .{ .service_metadata = service_metadata, .action = associate_web_acl };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
        WAFUnavailableEntity,
    },
} = .{};
pub const check_capacity: struct {
    action_name: []const u8 = "CheckCapacity",
    Request: type = struct {
        scope: []const u8,
        rules: []Rule,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scope = "Scope",
                .rules = "Rules",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(check_capacity) } {
            return .{ .service_metadata = service_metadata, .action = check_capacity };
        }
    },
    Response: type = struct {
        capacity: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .capacity = "Capacity",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidParameter,
        WAFInvalidResource,
        WAFLimitsExceeded,
        WAFNonexistentItem,
        WAFSubscriptionNotFound,
        WAFUnavailableEntity,
    },
} = .{};
pub const create_ip_set: struct {
    action_name: []const u8 = "CreateIPSet",
    Request: type = struct {
        name: []const u8,
        scope: []const u8,
        description: ?[]const u8 = null,
        ip_address_version: []const u8,
        addresses: [][]const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .scope = "Scope",
                .description = "Description",
                .ip_address_version = "IPAddressVersion",
                .addresses = "Addresses",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_ip_set) } {
            return .{ .service_metadata = service_metadata, .action = create_ip_set };
        }
    },
    Response: type = struct {
        summary: ?IPSetSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .summary = "Summary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFDuplicateItem,
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFOptimisticLock,
        WAFTagOperation,
        WAFTagOperationInternalError,
    },
} = .{};
pub const create_regex_pattern_set: struct {
    action_name: []const u8 = "CreateRegexPatternSet",
    Request: type = struct {
        name: []const u8,
        scope: []const u8,
        description: ?[]const u8 = null,
        regular_expression_list: []Regex,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .scope = "Scope",
                .description = "Description",
                .regular_expression_list = "RegularExpressionList",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_regex_pattern_set) } {
            return .{ .service_metadata = service_metadata, .action = create_regex_pattern_set };
        }
    },
    Response: type = struct {
        summary: ?RegexPatternSetSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .summary = "Summary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFDuplicateItem,
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFOptimisticLock,
        WAFTagOperation,
        WAFTagOperationInternalError,
    },
} = .{};
pub const create_rule_group: struct {
    action_name: []const u8 = "CreateRuleGroup",
    Request: type = struct {
        name: []const u8,
        scope: []const u8,
        capacity: i64,
        description: ?[]const u8 = null,
        rules: ?[]Rule = null,
        visibility_config: VisibilityConfig,
        tags: ?[]Tag = null,
        custom_response_bodies: ?[]struct {
            key: ?[]const u8 = null,
            value: ?CustomResponseBody = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .scope = "Scope",
                .capacity = "Capacity",
                .description = "Description",
                .rules = "Rules",
                .visibility_config = "VisibilityConfig",
                .tags = "Tags",
                .custom_response_bodies = "CustomResponseBodies",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "custom_response_bodies", field_name))
                return try serializeMap(self.custom_response_bodies, self.fieldNameFor("custom_response_bodies"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_rule_group) } {
            return .{ .service_metadata = service_metadata, .action = create_rule_group };
        }
    },
    Response: type = struct {
        summary: ?RuleGroupSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .summary = "Summary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFDuplicateItem,
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFNonexistentItem,
        WAFOptimisticLock,
        WAFSubscriptionNotFound,
        WAFTagOperation,
        WAFTagOperationInternalError,
        WAFUnavailableEntity,
    },
} = .{};
pub const create_web_acl: struct {
    action_name: []const u8 = "CreateWebACL",
    Request: type = struct {
        name: []const u8,
        scope: []const u8,
        default_action: DefaultAction,
        description: ?[]const u8 = null,
        rules: ?[]Rule = null,
        visibility_config: VisibilityConfig,
        tags: ?[]Tag = null,
        custom_response_bodies: ?[]struct {
            key: ?[]const u8 = null,
            value: ?CustomResponseBody = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .scope = "Scope",
                .default_action = "DefaultAction",
                .description = "Description",
                .rules = "Rules",
                .visibility_config = "VisibilityConfig",
                .tags = "Tags",
                .custom_response_bodies = "CustomResponseBodies",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "custom_response_bodies", field_name))
                return try serializeMap(self.custom_response_bodies, self.fieldNameFor("custom_response_bodies"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_web_acl) } {
            return .{ .service_metadata = service_metadata, .action = create_web_acl };
        }
    },
    Response: type = struct {
        summary: ?WebACLSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .summary = "Summary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFDuplicateItem,
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFInvalidResource,
        WAFLimitsExceeded,
        WAFNonexistentItem,
        WAFOptimisticLock,
        WAFSubscriptionNotFound,
        WAFTagOperation,
        WAFTagOperationInternalError,
        WAFUnavailableEntity,
    },
} = .{};
pub const delete_firewall_manager_rule_groups: struct {
    action_name: []const u8 = "DeleteFirewallManagerRuleGroups",
    Request: type = struct {
        web_acl_arn: []const u8,
        web_acl_lock_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .web_acl_arn = "WebACLArn",
                .web_acl_lock_token = "WebACLLockToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_firewall_manager_rule_groups) } {
            return .{ .service_metadata = service_metadata, .action = delete_firewall_manager_rule_groups };
        }
    },
    Response: type = struct {
        next_web_acl_lock_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_web_acl_lock_token = "NextWebACLLockToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
        WAFOptimisticLock,
    },
} = .{};
pub const delete_ip_set: struct {
    action_name: []const u8 = "DeleteIPSet",
    Request: type = struct {
        name: []const u8,
        scope: []const u8,
        id: []const u8,
        lock_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .scope = "Scope",
                .id = "Id",
                .lock_token = "LockToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_ip_set) } {
            return .{ .service_metadata = service_metadata, .action = delete_ip_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFAssociatedItem,
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
        WAFOptimisticLock,
        WAFTagOperation,
        WAFTagOperationInternalError,
    },
} = .{};
pub const delete_logging_configuration: struct {
    action_name: []const u8 = "DeleteLoggingConfiguration",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_logging_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_logging_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
        WAFOptimisticLock,
    },
} = .{};
pub const delete_permission_policy: struct {
    action_name: []const u8 = "DeletePermissionPolicy",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_permission_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_permission_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidParameter,
        WAFNonexistentItem,
    },
} = .{};
pub const delete_regex_pattern_set: struct {
    action_name: []const u8 = "DeleteRegexPatternSet",
    Request: type = struct {
        name: []const u8,
        scope: []const u8,
        id: []const u8,
        lock_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .scope = "Scope",
                .id = "Id",
                .lock_token = "LockToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_regex_pattern_set) } {
            return .{ .service_metadata = service_metadata, .action = delete_regex_pattern_set };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFAssociatedItem,
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
        WAFOptimisticLock,
        WAFTagOperation,
        WAFTagOperationInternalError,
    },
} = .{};
pub const delete_rule_group: struct {
    action_name: []const u8 = "DeleteRuleGroup",
    Request: type = struct {
        name: []const u8,
        scope: []const u8,
        id: []const u8,
        lock_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .scope = "Scope",
                .id = "Id",
                .lock_token = "LockToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_rule_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_rule_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFAssociatedItem,
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
        WAFOptimisticLock,
        WAFTagOperation,
        WAFTagOperationInternalError,
    },
} = .{};
pub const delete_web_acl: struct {
    action_name: []const u8 = "DeleteWebACL",
    Request: type = struct {
        name: []const u8,
        scope: []const u8,
        id: []const u8,
        lock_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .scope = "Scope",
                .id = "Id",
                .lock_token = "LockToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_web_acl) } {
            return .{ .service_metadata = service_metadata, .action = delete_web_acl };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFAssociatedItem,
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
        WAFOptimisticLock,
        WAFTagOperation,
        WAFTagOperationInternalError,
    },
} = .{};
pub const describe_managed_rule_group: struct {
    action_name: []const u8 = "DescribeManagedRuleGroup",
    Request: type = struct {
        vendor_name: []const u8,
        name: []const u8,
        scope: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .vendor_name = "VendorName",
                .name = "Name",
                .scope = "Scope",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_managed_rule_group) } {
            return .{ .service_metadata = service_metadata, .action = describe_managed_rule_group };
        }
    },
    Response: type = struct {
        capacity: ?i64 = null,
        rules: ?[]struct {
            name: ?[]const u8 = null,
            action: ?RuleAction = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .action = "Action",
                };
                return @field(mappings, field_name);
            }
        } = null,
        label_namespace: ?[]const u8 = null,
        available_labels: ?[]LabelSummary = null,
        consumed_labels: ?[]LabelSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .capacity = "Capacity",
                .rules = "Rules",
                .label_namespace = "LabelNamespace",
                .available_labels = "AvailableLabels",
                .consumed_labels = "ConsumedLabels",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFInvalidResource,
        WAFNonexistentItem,
    },
} = .{};
pub const disassociate_web_acl: struct {
    action_name: []const u8 = "DisassociateWebACL",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_web_acl) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_web_acl };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
    },
} = .{};
pub const get_ip_set: struct {
    action_name: []const u8 = "GetIPSet",
    Request: type = struct {
        name: []const u8,
        scope: []const u8,
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .scope = "Scope",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ip_set) } {
            return .{ .service_metadata = service_metadata, .action = get_ip_set };
        }
    },
    Response: type = struct {
        ip_set: ?struct {
            name: []const u8,
            id: []const u8,
            arn: []const u8,
            description: ?[]const u8 = null,
            ip_address_version: []const u8,
            addresses: [][]const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .id = "Id",
                    .arn = "ARN",
                    .description = "Description",
                    .ip_address_version = "IPAddressVersion",
                    .addresses = "Addresses",
                };
                return @field(mappings, field_name);
            }
        } = null,
        lock_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ip_set = "IPSet",
                .lock_token = "LockToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
    },
} = .{};
pub const get_logging_configuration: struct {
    action_name: []const u8 = "GetLoggingConfiguration",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_logging_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_logging_configuration };
        }
    },
    Response: type = struct {
        logging_configuration: ?LoggingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .logging_configuration = "LoggingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
    },
} = .{};
pub const get_permission_policy: struct {
    action_name: []const u8 = "GetPermissionPolicy",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_permission_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_permission_policy };
        }
    },
    Response: type = struct {
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidParameter,
        WAFNonexistentItem,
    },
} = .{};
pub const get_rate_based_statement_managed_keys: struct {
    action_name: []const u8 = "GetRateBasedStatementManagedKeys",
    Request: type = struct {
        scope: []const u8,
        web_acl_name: []const u8,
        web_acl_id: []const u8,
        rule_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scope = "Scope",
                .web_acl_name = "WebACLName",
                .web_acl_id = "WebACLId",
                .rule_name = "RuleName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_rate_based_statement_managed_keys) } {
            return .{ .service_metadata = service_metadata, .action = get_rate_based_statement_managed_keys };
        }
    },
    Response: type = struct {
        managed_keys_ipv4: ?RateBasedStatementManagedKeysIPSet = null,
        managed_keys_ipv6: ?RateBasedStatementManagedKeysIPSet = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .managed_keys_ipv4 = "ManagedKeysIPV4",
                .managed_keys_ipv6 = "ManagedKeysIPV6",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
    },
} = .{};
pub const get_regex_pattern_set: struct {
    action_name: []const u8 = "GetRegexPatternSet",
    Request: type = struct {
        name: []const u8,
        scope: []const u8,
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .scope = "Scope",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_regex_pattern_set) } {
            return .{ .service_metadata = service_metadata, .action = get_regex_pattern_set };
        }
    },
    Response: type = struct {
        regex_pattern_set: ?struct {
            name: ?[]const u8 = null,
            id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            description: ?[]const u8 = null,
            regular_expression_list: ?[]Regex = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .id = "Id",
                    .arn = "ARN",
                    .description = "Description",
                    .regular_expression_list = "RegularExpressionList",
                };
                return @field(mappings, field_name);
            }
        } = null,
        lock_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .regex_pattern_set = "RegexPatternSet",
                .lock_token = "LockToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
    },
} = .{};
pub const get_rule_group: struct {
    action_name: []const u8 = "GetRuleGroup",
    Request: type = struct {
        name: []const u8,
        scope: []const u8,
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .scope = "Scope",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_rule_group) } {
            return .{ .service_metadata = service_metadata, .action = get_rule_group };
        }
    },
    Response: type = struct {
        rule_group: ?struct {
            name: []const u8,
            id: []const u8,
            capacity: i64,
            arn: []const u8,
            description: ?[]const u8 = null,
            rules: ?[]Rule = null,
            visibility_config: VisibilityConfig,
            label_namespace: ?[]const u8 = null,
            custom_response_bodies: ?[]struct {
                key: ?[]const u8 = null,
                value: ?CustomResponseBody = null,
            } = null,
            available_labels: ?[]LabelSummary = null,
            consumed_labels: ?[]LabelSummary = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .id = "Id",
                    .capacity = "Capacity",
                    .arn = "ARN",
                    .description = "Description",
                    .rules = "Rules",
                    .visibility_config = "VisibilityConfig",
                    .label_namespace = "LabelNamespace",
                    .custom_response_bodies = "CustomResponseBodies",
                    .available_labels = "AvailableLabels",
                    .consumed_labels = "ConsumedLabels",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "custom_response_bodies", field_name))
                    return try serializeMap(self.custom_response_bodies, self.fieldNameFor("custom_response_bodies"), options, out_stream);
                return false;
            }
        } = null,
        lock_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rule_group = "RuleGroup",
                .lock_token = "LockToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
    },
} = .{};
pub const get_sampled_requests: struct {
    action_name: []const u8 = "GetSampledRequests",
    Request: type = struct {
        web_acl_arn: []const u8,
        rule_metric_name: []const u8,
        scope: []const u8,
        time_window: TimeWindow,
        max_items: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .web_acl_arn = "WebAclArn",
                .rule_metric_name = "RuleMetricName",
                .scope = "Scope",
                .time_window = "TimeWindow",
                .max_items = "MaxItems",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sampled_requests) } {
            return .{ .service_metadata = service_metadata, .action = get_sampled_requests };
        }
    },
    Response: type = struct {
        sampled_requests: ?[]struct {
            request: struct {
                client_ip: ?[]const u8 = null,
                country: ?[]const u8 = null,
                uri: ?[]const u8 = null,
                method: ?[]const u8 = null,
                http_version: ?[]const u8 = null,
                headers: ?[]HTTPHeader = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .client_ip = "ClientIP",
                        .country = "Country",
                        .uri = "URI",
                        .method = "Method",
                        .http_version = "HTTPVersion",
                        .headers = "Headers",
                    };
                    return @field(mappings, field_name);
                }
            },
            weight: i64,
            timestamp: ?i64 = null,
            action: ?[]const u8 = null,
            rule_name_within_rule_group: ?[]const u8 = null,
            request_headers_inserted: ?[]HTTPHeader = null,
            response_code_sent: ?i64 = null,
            labels: ?[]Label = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .request = "Request",
                    .weight = "Weight",
                    .timestamp = "Timestamp",
                    .action = "Action",
                    .rule_name_within_rule_group = "RuleNameWithinRuleGroup",
                    .request_headers_inserted = "RequestHeadersInserted",
                    .response_code_sent = "ResponseCodeSent",
                    .labels = "Labels",
                };
                return @field(mappings, field_name);
            }
        } = null,
        population_size: ?i64 = null,
        time_window: ?TimeWindow = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sampled_requests = "SampledRequests",
                .population_size = "PopulationSize",
                .time_window = "TimeWindow",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidParameter,
        WAFNonexistentItem,
    },
} = .{};
pub const get_web_acl: struct {
    action_name: []const u8 = "GetWebACL",
    Request: type = struct {
        name: []const u8,
        scope: []const u8,
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .scope = "Scope",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_web_acl) } {
            return .{ .service_metadata = service_metadata, .action = get_web_acl };
        }
    },
    Response: type = struct {
        web_acl: ?WebACL = null,
        lock_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .web_acl = "WebACL",
                .lock_token = "LockToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
    },
} = .{};
pub const get_web_acl_for_resource: struct {
    action_name: []const u8 = "GetWebACLForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_web_acl_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = get_web_acl_for_resource };
        }
    },
    Response: type = struct {
        web_acl: ?WebACL = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .web_acl = "WebACL",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
        WAFUnavailableEntity,
    },
} = .{};
pub const list_available_managed_rule_groups: struct {
    action_name: []const u8 = "ListAvailableManagedRuleGroups",
    Request: type = struct {
        scope: []const u8,
        next_marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scope = "Scope",
                .next_marker = "NextMarker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_available_managed_rule_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_available_managed_rule_groups };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        managed_rule_groups: ?[]struct {
            vendor_name: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .vendor_name = "VendorName",
                    .name = "Name",
                    .description = "Description",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .managed_rule_groups = "ManagedRuleGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
    },
} = .{};
pub const list_ip_sets: struct {
    action_name: []const u8 = "ListIPSets",
    Request: type = struct {
        scope: []const u8,
        next_marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scope = "Scope",
                .next_marker = "NextMarker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_ip_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_ip_sets };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        ip_sets: ?[]IPSetSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .ip_sets = "IPSets",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
    },
} = .{};
pub const list_logging_configurations: struct {
    action_name: []const u8 = "ListLoggingConfigurations",
    Request: type = struct {
        scope: ?[]const u8 = null,
        next_marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scope = "Scope",
                .next_marker = "NextMarker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_logging_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_logging_configurations };
        }
    },
    Response: type = struct {
        logging_configurations: ?[]LoggingConfiguration = null,
        next_marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .logging_configurations = "LoggingConfigurations",
                .next_marker = "NextMarker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
    },
} = .{};
pub const list_regex_pattern_sets: struct {
    action_name: []const u8 = "ListRegexPatternSets",
    Request: type = struct {
        scope: []const u8,
        next_marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scope = "Scope",
                .next_marker = "NextMarker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_regex_pattern_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_regex_pattern_sets };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        regex_pattern_sets: ?[]RegexPatternSetSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .regex_pattern_sets = "RegexPatternSets",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
    },
} = .{};
pub const list_resources_for_web_acl: struct {
    action_name: []const u8 = "ListResourcesForWebACL",
    Request: type = struct {
        web_acl_arn: []const u8,
        resource_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .web_acl_arn = "WebACLArn",
                .resource_type = "ResourceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_resources_for_web_acl) } {
            return .{ .service_metadata = service_metadata, .action = list_resources_for_web_acl };
        }
    },
    Response: type = struct {
        resource_arns: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arns = "ResourceArns",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
    },
} = .{};
pub const list_rule_groups: struct {
    action_name: []const u8 = "ListRuleGroups",
    Request: type = struct {
        scope: []const u8,
        next_marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scope = "Scope",
                .next_marker = "NextMarker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_rule_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_rule_groups };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        rule_groups: ?[]RuleGroupSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .rule_groups = "RuleGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        next_marker: ?[]const u8 = null,
        limit: ?i64 = null,
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .limit = "Limit",
                .resource_arn = "ResourceARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        tag_info_for_resource: ?struct {
            resource_arn: ?[]const u8 = null,
            tag_list: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_arn = "ResourceARN",
                    .tag_list = "TagList",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .tag_info_for_resource = "TagInfoForResource",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
        WAFTagOperation,
        WAFTagOperationInternalError,
    },
} = .{};
pub const list_web_ac_ls: struct {
    action_name: []const u8 = "ListWebACLs",
    Request: type = struct {
        scope: []const u8,
        next_marker: ?[]const u8 = null,
        limit: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .scope = "Scope",
                .next_marker = "NextMarker",
                .limit = "Limit",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_web_ac_ls) } {
            return .{ .service_metadata = service_metadata, .action = list_web_ac_ls };
        }
    },
    Response: type = struct {
        next_marker: ?[]const u8 = null,
        web_ac_ls: ?[]WebACLSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_marker = "NextMarker",
                .web_ac_ls = "WebACLs",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
    },
} = .{};
pub const put_logging_configuration: struct {
    action_name: []const u8 = "PutLoggingConfiguration",
    Request: type = struct {
        logging_configuration: LoggingConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .logging_configuration = "LoggingConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_logging_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_logging_configuration };
        }
    },
    Response: type = struct {
        logging_configuration: ?LoggingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .logging_configuration = "LoggingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFNonexistentItem,
        WAFOptimisticLock,
        WAFServiceLinkedRoleError,
    },
} = .{};
pub const put_permission_policy: struct {
    action_name: []const u8 = "PutPermissionPolicy",
    Request: type = struct {
        resource_arn: []const u8,
        policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_permission_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_permission_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidParameter,
        WAFInvalidPermissionPolicy,
        WAFNonexistentItem,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFNonexistentItem,
        WAFTagOperation,
        WAFTagOperationInternalError,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceARN",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFNonexistentItem,
        WAFTagOperation,
        WAFTagOperationInternalError,
    },
} = .{};
pub const update_ip_set: struct {
    action_name: []const u8 = "UpdateIPSet",
    Request: type = struct {
        name: []const u8,
        scope: []const u8,
        id: []const u8,
        description: ?[]const u8 = null,
        addresses: [][]const u8,
        lock_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .scope = "Scope",
                .id = "Id",
                .description = "Description",
                .addresses = "Addresses",
                .lock_token = "LockToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_ip_set) } {
            return .{ .service_metadata = service_metadata, .action = update_ip_set };
        }
    },
    Response: type = struct {
        next_lock_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_lock_token = "NextLockToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFDuplicateItem,
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFNonexistentItem,
        WAFOptimisticLock,
    },
} = .{};
pub const update_regex_pattern_set: struct {
    action_name: []const u8 = "UpdateRegexPatternSet",
    Request: type = struct {
        name: []const u8,
        scope: []const u8,
        id: []const u8,
        description: ?[]const u8 = null,
        regular_expression_list: []Regex,
        lock_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .scope = "Scope",
                .id = "Id",
                .description = "Description",
                .regular_expression_list = "RegularExpressionList",
                .lock_token = "LockToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_regex_pattern_set) } {
            return .{ .service_metadata = service_metadata, .action = update_regex_pattern_set };
        }
    },
    Response: type = struct {
        next_lock_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_lock_token = "NextLockToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFDuplicateItem,
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFNonexistentItem,
        WAFOptimisticLock,
    },
} = .{};
pub const update_rule_group: struct {
    action_name: []const u8 = "UpdateRuleGroup",
    Request: type = struct {
        name: []const u8,
        scope: []const u8,
        id: []const u8,
        description: ?[]const u8 = null,
        rules: ?[]Rule = null,
        visibility_config: VisibilityConfig,
        lock_token: []const u8,
        custom_response_bodies: ?[]struct {
            key: ?[]const u8 = null,
            value: ?CustomResponseBody = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .scope = "Scope",
                .id = "Id",
                .description = "Description",
                .rules = "Rules",
                .visibility_config = "VisibilityConfig",
                .lock_token = "LockToken",
                .custom_response_bodies = "CustomResponseBodies",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "custom_response_bodies", field_name))
                return try serializeMap(self.custom_response_bodies, self.fieldNameFor("custom_response_bodies"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_rule_group) } {
            return .{ .service_metadata = service_metadata, .action = update_rule_group };
        }
    },
    Response: type = struct {
        next_lock_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_lock_token = "NextLockToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFDuplicateItem,
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFLimitsExceeded,
        WAFNonexistentItem,
        WAFOptimisticLock,
        WAFSubscriptionNotFound,
        WAFUnavailableEntity,
    },
} = .{};
pub const update_web_acl: struct {
    action_name: []const u8 = "UpdateWebACL",
    Request: type = struct {
        name: []const u8,
        scope: []const u8,
        id: []const u8,
        default_action: DefaultAction,
        description: ?[]const u8 = null,
        rules: ?[]Rule = null,
        visibility_config: VisibilityConfig,
        lock_token: []const u8,
        custom_response_bodies: ?[]struct {
            key: ?[]const u8 = null,
            value: ?CustomResponseBody = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .scope = "Scope",
                .id = "Id",
                .default_action = "DefaultAction",
                .description = "Description",
                .rules = "Rules",
                .visibility_config = "VisibilityConfig",
                .lock_token = "LockToken",
                .custom_response_bodies = "CustomResponseBodies",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "custom_response_bodies", field_name))
                return try serializeMap(self.custom_response_bodies, self.fieldNameFor("custom_response_bodies"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_web_acl) } {
            return .{ .service_metadata = service_metadata, .action = update_web_acl };
        }
    },
    Response: type = struct {
        next_lock_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_lock_token = "NextLockToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        WAFDuplicateItem,
        WAFInternalError,
        WAFInvalidOperation,
        WAFInvalidParameter,
        WAFInvalidResource,
        WAFLimitsExceeded,
        WAFNonexistentItem,
        WAFOptimisticLock,
        WAFSubscriptionNotFound,
        WAFUnavailableEntity,
    },
} = .{};

pub const CustomResponseBody = struct {
    content_type: []const u8,
    content: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .content_type = "ContentType",
            .content = "Content",
        };
        return @field(mappings, field_name);
    }
};

pub const VisibilityConfig = struct {
    sampled_requests_enabled: bool,
    cloud_watch_metrics_enabled: bool,
    metric_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sampled_requests_enabled = "SampledRequestsEnabled",
            .cloud_watch_metrics_enabled = "CloudWatchMetricsEnabled",
            .metric_name = "MetricName",
        };
        return @field(mappings, field_name);
    }
};

pub const Rule = struct {
    name: []const u8,
    priority: i64,
    statement: Statement,
    action: ?RuleAction = null,
    override_action: ?OverrideAction = null,
    rule_labels: ?[]Label = null,
    visibility_config: VisibilityConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .priority = "Priority",
            .statement = "Statement",
            .action = "Action",
            .override_action = "OverrideAction",
            .rule_labels = "RuleLabels",
            .visibility_config = "VisibilityConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const Label = struct {
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const OverrideAction = struct {
    count: ?CountAction = null,
    none: ?NoneAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .count = "Count",
            .none = "None",
        };
        return @field(mappings, field_name);
    }
};

pub const NoneAction = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const CountAction = struct {
    custom_request_handling: ?CustomRequestHandling = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom_request_handling = "CustomRequestHandling",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomRequestHandling = struct {
    insert_headers: []CustomHTTPHeader,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .insert_headers = "InsertHeaders",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomHTTPHeader = struct {
    name: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleAction = struct {
    block: ?BlockAction = null,
    allow: ?AllowAction = null,
    count: ?CountAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .block = "Block",
            .allow = "Allow",
            .count = "Count",
        };
        return @field(mappings, field_name);
    }
};

pub const AllowAction = struct {
    custom_request_handling: ?CustomRequestHandling = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom_request_handling = "CustomRequestHandling",
        };
        return @field(mappings, field_name);
    }
};

pub const BlockAction = struct {
    custom_response: ?CustomResponse = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .custom_response = "CustomResponse",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomResponse = struct {
    response_code: i64,
    custom_response_body_key: ?[]const u8 = null,
    response_headers: ?[]CustomHTTPHeader = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .response_code = "ResponseCode",
            .custom_response_body_key = "CustomResponseBodyKey",
            .response_headers = "ResponseHeaders",
        };
        return @field(mappings, field_name);
    }
};

pub const Statement = struct {
    byte_match_statement: ?ByteMatchStatement = null,
    sqli_match_statement: ?SqliMatchStatement = null,
    xss_match_statement: ?XssMatchStatement = null,
    size_constraint_statement: ?SizeConstraintStatement = null,
    geo_match_statement: ?GeoMatchStatement = null,
    rule_group_reference_statement: ?RuleGroupReferenceStatement = null,
    ip_set_reference_statement: ?IPSetReferenceStatement = null,
    regex_pattern_set_reference_statement: ?RegexPatternSetReferenceStatement = null,
    rate_based_statement: ?RateBasedStatement = null,
    and_statement: ?AndStatement = null,
    or_statement: ?OrStatement = null,
    not_statement: ?NotStatement = null,
    managed_rule_group_statement: ?ManagedRuleGroupStatement = null,
    label_match_statement: ?LabelMatchStatement = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .byte_match_statement = "ByteMatchStatement",
            .sqli_match_statement = "SqliMatchStatement",
            .xss_match_statement = "XssMatchStatement",
            .size_constraint_statement = "SizeConstraintStatement",
            .geo_match_statement = "GeoMatchStatement",
            .rule_group_reference_statement = "RuleGroupReferenceStatement",
            .ip_set_reference_statement = "IPSetReferenceStatement",
            .regex_pattern_set_reference_statement = "RegexPatternSetReferenceStatement",
            .rate_based_statement = "RateBasedStatement",
            .and_statement = "AndStatement",
            .or_statement = "OrStatement",
            .not_statement = "NotStatement",
            .managed_rule_group_statement = "ManagedRuleGroupStatement",
            .label_match_statement = "LabelMatchStatement",
        };
        return @field(mappings, field_name);
    }
};

pub const LabelMatchStatement = struct {
    scope: []const u8,
    key: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .scope = "Scope",
            .key = "Key",
        };
        return @field(mappings, field_name);
    }
};

pub const ManagedRuleGroupStatement = struct {
    vendor_name: []const u8,
    name: []const u8,
    excluded_rules: ?[]ExcludedRule = null,
    scope_down_statement: ?Statement = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vendor_name = "VendorName",
            .name = "Name",
            .excluded_rules = "ExcludedRules",
            .scope_down_statement = "ScopeDownStatement",
        };
        return @field(mappings, field_name);
    }
};

pub const ExcludedRule = struct {
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const NotStatement = struct {
    statement: Statement,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .statement = "Statement",
        };
        return @field(mappings, field_name);
    }
};

pub const OrStatement = struct {
    statements: []Statement,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .statements = "Statements",
        };
        return @field(mappings, field_name);
    }
};

pub const AndStatement = struct {
    statements: []Statement,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .statements = "Statements",
        };
        return @field(mappings, field_name);
    }
};

pub const RateBasedStatement = struct {
    limit: i64,
    aggregate_key_type: []const u8,
    scope_down_statement: ?Statement = null,
    forwarded_ip_config: ?ForwardedIPConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .limit = "Limit",
            .aggregate_key_type = "AggregateKeyType",
            .scope_down_statement = "ScopeDownStatement",
            .forwarded_ip_config = "ForwardedIPConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const ForwardedIPConfig = struct {
    header_name: []const u8,
    fallback_behavior: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .header_name = "HeaderName",
            .fallback_behavior = "FallbackBehavior",
        };
        return @field(mappings, field_name);
    }
};

pub const RegexPatternSetReferenceStatement = struct {
    arn: []const u8,
    field_to_match: FieldToMatch,
    text_transformations: []TextTransformation,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "ARN",
            .field_to_match = "FieldToMatch",
            .text_transformations = "TextTransformations",
        };
        return @field(mappings, field_name);
    }
};

pub const TextTransformation = struct {
    priority: i64,
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .priority = "Priority",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const FieldToMatch = struct {
    single_header: ?SingleHeader = null,
    single_query_argument: ?SingleQueryArgument = null,
    all_query_arguments: ?AllQueryArguments = null,
    uri_path: ?UriPath = null,
    query_string: ?QueryString = null,
    body: ?Body = null,
    method: ?Method = null,
    json_body: ?JsonBody = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .single_header = "SingleHeader",
            .single_query_argument = "SingleQueryArgument",
            .all_query_arguments = "AllQueryArguments",
            .uri_path = "UriPath",
            .query_string = "QueryString",
            .body = "Body",
            .method = "Method",
            .json_body = "JsonBody",
        };
        return @field(mappings, field_name);
    }
};

pub const JsonBody = struct {
    match_pattern: JsonMatchPattern,
    match_scope: []const u8,
    invalid_fallback_behavior: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .match_pattern = "MatchPattern",
            .match_scope = "MatchScope",
            .invalid_fallback_behavior = "InvalidFallbackBehavior",
        };
        return @field(mappings, field_name);
    }
};

pub const JsonMatchPattern = struct {
    all: ?All = null,
    included_paths: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .all = "All",
            .included_paths = "IncludedPaths",
        };
        return @field(mappings, field_name);
    }
};

pub const All = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const Method = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const Body = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const QueryString = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const UriPath = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const AllQueryArguments = struct {

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{};
        return @field(mappings, field_name);
    }
};

pub const SingleQueryArgument = struct {
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const SingleHeader = struct {
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const IPSetReferenceStatement = struct {
    arn: []const u8,
    ip_set_forwarded_ip_config: ?IPSetForwardedIPConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "ARN",
            .ip_set_forwarded_ip_config = "IPSetForwardedIPConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const IPSetForwardedIPConfig = struct {
    header_name: []const u8,
    fallback_behavior: []const u8,
    position: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .header_name = "HeaderName",
            .fallback_behavior = "FallbackBehavior",
            .position = "Position",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleGroupReferenceStatement = struct {
    arn: []const u8,
    excluded_rules: ?[]ExcludedRule = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "ARN",
            .excluded_rules = "ExcludedRules",
        };
        return @field(mappings, field_name);
    }
};

pub const GeoMatchStatement = struct {
    country_codes: ?[][]const u8 = null,
    forwarded_ip_config: ?ForwardedIPConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .country_codes = "CountryCodes",
            .forwarded_ip_config = "ForwardedIPConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const SizeConstraintStatement = struct {
    field_to_match: FieldToMatch,
    comparison_operator: []const u8,
    size: i64,
    text_transformations: []TextTransformation,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_to_match = "FieldToMatch",
            .comparison_operator = "ComparisonOperator",
            .size = "Size",
            .text_transformations = "TextTransformations",
        };
        return @field(mappings, field_name);
    }
};

pub const XssMatchStatement = struct {
    field_to_match: FieldToMatch,
    text_transformations: []TextTransformation,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_to_match = "FieldToMatch",
            .text_transformations = "TextTransformations",
        };
        return @field(mappings, field_name);
    }
};

pub const SqliMatchStatement = struct {
    field_to_match: FieldToMatch,
    text_transformations: []TextTransformation,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_to_match = "FieldToMatch",
            .text_transformations = "TextTransformations",
        };
        return @field(mappings, field_name);
    }
};

pub const ByteMatchStatement = struct {
    search_string: []const u8,
    field_to_match: FieldToMatch,
    text_transformations: []TextTransformation,
    positional_constraint: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .search_string = "SearchString",
            .field_to_match = "FieldToMatch",
            .text_transformations = "TextTransformations",
            .positional_constraint = "PositionalConstraint",
        };
        return @field(mappings, field_name);
    }
};

pub const DefaultAction = struct {
    block: ?BlockAction = null,
    allow: ?AllowAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .block = "Block",
            .allow = "Allow",
        };
        return @field(mappings, field_name);
    }
};

pub const Regex = struct {
    regex_string: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .regex_string = "RegexString",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const LoggingConfiguration = struct {
    resource_arn: []const u8,
    log_destination_configs: [][]const u8,
    redacted_fields: ?[]FieldToMatch = null,
    managed_by_firewall_manager: ?bool = null,
    logging_filter: ?LoggingFilter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_arn = "ResourceArn",
            .log_destination_configs = "LogDestinationConfigs",
            .redacted_fields = "RedactedFields",
            .managed_by_firewall_manager = "ManagedByFirewallManager",
            .logging_filter = "LoggingFilter",
        };
        return @field(mappings, field_name);
    }
};

pub const LoggingFilter = struct {
    filters: []Filter,
    default_behavior: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filters = "Filters",
            .default_behavior = "DefaultBehavior",
        };
        return @field(mappings, field_name);
    }
};

pub const Filter = struct {
    behavior: []const u8,
    requirement: []const u8,
    conditions: []Condition,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .behavior = "Behavior",
            .requirement = "Requirement",
            .conditions = "Conditions",
        };
        return @field(mappings, field_name);
    }
};

pub const Condition = struct {
    action_condition: ?ActionCondition = null,
    label_name_condition: ?LabelNameCondition = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action_condition = "ActionCondition",
            .label_name_condition = "LabelNameCondition",
        };
        return @field(mappings, field_name);
    }
};

pub const LabelNameCondition = struct {
    label_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .label_name = "LabelName",
        };
        return @field(mappings, field_name);
    }
};

pub const ActionCondition = struct {
    action: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action = "Action",
        };
        return @field(mappings, field_name);
    }
};

pub const WebACLSummary = struct {
    name: ?[]const u8 = null,
    id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    lock_token: ?[]const u8 = null,
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .id = "Id",
            .description = "Description",
            .lock_token = "LockToken",
            .arn = "ARN",
        };
        return @field(mappings, field_name);
    }
};

pub const RuleGroupSummary = struct {
    name: ?[]const u8 = null,
    id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    lock_token: ?[]const u8 = null,
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .id = "Id",
            .description = "Description",
            .lock_token = "LockToken",
            .arn = "ARN",
        };
        return @field(mappings, field_name);
    }
};

pub const RegexPatternSetSummary = struct {
    name: ?[]const u8 = null,
    id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    lock_token: ?[]const u8 = null,
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .id = "Id",
            .description = "Description",
            .lock_token = "LockToken",
            .arn = "ARN",
        };
        return @field(mappings, field_name);
    }
};

pub const IPSetSummary = struct {
    name: ?[]const u8 = null,
    id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    lock_token: ?[]const u8 = null,
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .id = "Id",
            .description = "Description",
            .lock_token = "LockToken",
            .arn = "ARN",
        };
        return @field(mappings, field_name);
    }
};

pub const WebACL = struct {
    name: []const u8,
    id: []const u8,
    arn: []const u8,
    default_action: DefaultAction,
    description: ?[]const u8 = null,
    rules: ?[]Rule = null,
    visibility_config: VisibilityConfig,
    capacity: ?i64 = null,
    pre_process_firewall_manager_rule_groups: ?[]FirewallManagerRuleGroup = null,
    post_process_firewall_manager_rule_groups: ?[]FirewallManagerRuleGroup = null,
    managed_by_firewall_manager: ?bool = null,
    label_namespace: ?[]const u8 = null,
    custom_response_bodies: ?[]struct {
        key: ?[]const u8 = null,
        value: ?CustomResponseBody = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .id = "Id",
            .arn = "ARN",
            .default_action = "DefaultAction",
            .description = "Description",
            .rules = "Rules",
            .visibility_config = "VisibilityConfig",
            .capacity = "Capacity",
            .pre_process_firewall_manager_rule_groups = "PreProcessFirewallManagerRuleGroups",
            .post_process_firewall_manager_rule_groups = "PostProcessFirewallManagerRuleGroups",
            .managed_by_firewall_manager = "ManagedByFirewallManager",
            .label_namespace = "LabelNamespace",
            .custom_response_bodies = "CustomResponseBodies",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "custom_response_bodies", field_name))
            return try serializeMap(self.custom_response_bodies, self.fieldNameFor("custom_response_bodies"), options, out_stream);
        return false;
    }
};

pub const FirewallManagerRuleGroup = struct {
    name: []const u8,
    priority: i64,
    firewall_manager_statement: FirewallManagerStatement,
    override_action: OverrideAction,
    visibility_config: VisibilityConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .priority = "Priority",
            .firewall_manager_statement = "FirewallManagerStatement",
            .override_action = "OverrideAction",
            .visibility_config = "VisibilityConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const FirewallManagerStatement = struct {
    managed_rule_group_statement: ?ManagedRuleGroupStatement = null,
    rule_group_reference_statement: ?RuleGroupReferenceStatement = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .managed_rule_group_statement = "ManagedRuleGroupStatement",
            .rule_group_reference_statement = "RuleGroupReferenceStatement",
        };
        return @field(mappings, field_name);
    }
};

pub const TimeWindow = struct {
    start_time: i64,
    end_time: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .start_time = "StartTime",
            .end_time = "EndTime",
        };
        return @field(mappings, field_name);
    }
};

pub const HTTPHeader = struct {
    name: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const LabelSummary = struct {
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const RateBasedStatementManagedKeysIPSet = struct {
    ip_address_version: ?[]const u8 = null,
    addresses: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ip_address_version = "IPAddressVersion",
            .addresses = "Addresses",
        };
        return @field(mappings, field_name);
    }
};
